/*
 * Copyright 2019 Mike Penz
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.mikepenz.iconics.typeface.library.fontawesome

import com.mikepenz.iconics.typeface.IIcon
import com.mikepenz.iconics.typeface.ITypeface
import java.util.LinkedList

@Suppress("EnumEntryName")
object FontAwesome : ITypeface {

    override val fontRes: Int
        get() = R.font.fontawesome_font_v5_9_0

    override val characters: Map<String, Char> by lazy {
        Icon.values().associate { it.name to it.character }
    }

    override val mappingPrefix: String
        get() = "faw"

    override val fontName: String
        get() = "FontAwesome"

    override val version: String
        get() = "5.9.0.0"

    override val iconCount: Int
        get() = characters.size

    override val icons: List<String>
        get() = characters.keys.toCollection(LinkedList())

    override val author: String
        get() = "Dave Gandy"

    override val url: String
        get() = "https://fontawesome.com/"

    override val description: String
        get() = "Get vector icons and social logos on your website with Font Awesome, the webs " +
                "most popular icon set and toolkit."

    override val license: String
        get() = "SIL OFL 1.1"

    override val licenseUrl: String
        get() = "http://scripts.sil.org/OFL"

    override fun getIcon(key: String): IIcon = Icon.valueOf(key)

    enum class Icon constructor(override val character: Char) : IIcon {
        faw_twitter_square('\uf081'),
        faw_facebook_square('\uf082'),
        faw_linkedin('\uf08c'),
        faw_github_square('\uf092'),
        faw_twitter('\uf099'),
        faw_facebook('\uf09a'),
        faw_github('\uf09b'),
        faw_pinterest('\uf0d2'),
        faw_pinterest_square('\uf0d3'),
        faw_google_plus_square('\uf0d4'),
        faw_google_plus_g('\uf0d5'),
        faw_linkedin_in('\uf0e1'),
        faw_github_alt('\uf113'),
        faw_maxcdn('\uf136'),
        faw_html5('\uf13b'),
        faw_css3('\uf13c'),
        faw_btc('\uf15a'),
        faw_youtube('\uf167'),
        faw_xing('\uf168'),
        faw_xing_square('\uf169'),
        faw_dropbox('\uf16b'),
        faw_stack_overflow('\uf16c'),
        faw_instagram('\uf16d'),
        faw_flickr('\uf16e'),
        faw_adn('\uf170'),
        faw_bitbucket('\uf171'),
        faw_tumblr('\uf173'),
        faw_tumblr_square('\uf174'),
        faw_apple('\uf179'),
        faw_windows('\uf17a'),
        faw_android('\uf17b'),
        faw_linux('\uf17c'),
        faw_dribbble('\uf17d'),
        faw_skype('\uf17e'),
        faw_foursquare('\uf180'),
        faw_trello('\uf181'),
        faw_gratipay('\uf184'),
        faw_vk('\uf189'),
        faw_weibo('\uf18a'),
        faw_renren('\uf18b'),
        faw_pagelines('\uf18c'),
        faw_stack_exchange('\uf18d'),
        faw_vimeo_square('\uf194'),
        faw_slack('\uf198'),
        faw_wordpress('\uf19a'),
        faw_openid('\uf19b'),
        faw_yahoo('\uf19e'),
        faw_google('\uf1a0'),
        faw_reddit('\uf1a1'),
        faw_reddit_square('\uf1a2'),
        faw_stumbleupon_circle('\uf1a3'),
        faw_stumbleupon('\uf1a4'),
        faw_delicious('\uf1a5'),
        faw_digg('\uf1a6'),
        faw_pied_piper_pp('\uf1a7'),
        faw_pied_piper_alt('\uf1a8'),
        faw_drupal('\uf1a9'),
        faw_joomla('\uf1aa'),
        faw_behance('\uf1b4'),
        faw_behance_square('\uf1b5'),
        faw_steam('\uf1b6'),
        faw_steam_square('\uf1b7'),
        faw_spotify('\uf1bc'),
        faw_deviantart('\uf1bd'),
        faw_soundcloud('\uf1be'),
        faw_vine('\uf1ca'),
        faw_codepen('\uf1cb'),
        faw_jsfiddle('\uf1cc'),
        faw_rebel('\uf1d0'),
        faw_empire('\uf1d1'),
        faw_git_square('\uf1d2'),
        faw_git('\uf1d3'),
        faw_hacker_news('\uf1d4'),
        faw_tencent_weibo('\uf1d5'),
        faw_qq('\uf1d6'),
        faw_weixin('\uf1d7'),
        faw_slideshare('\uf1e7'),
        faw_twitch('\uf1e8'),
        faw_yelp('\uf1e9'),
        faw_paypal('\uf1ed'),
        faw_google_wallet('\uf1ee'),
        faw_cc_visa('\uf1f0'),
        faw_cc_mastercard('\uf1f1'),
        faw_cc_discover('\uf1f2'),
        faw_cc_amex('\uf1f3'),
        faw_cc_paypal('\uf1f4'),
        faw_cc_stripe('\uf1f5'),
        faw_lastfm('\uf202'),
        faw_lastfm_square('\uf203'),
        faw_ioxhost('\uf208'),
        faw_angellist('\uf209'),
        faw_buysellads('\uf20d'),
        faw_connectdevelop('\uf20e'),
        faw_dashcube('\uf210'),
        faw_forumbee('\uf211'),
        faw_leanpub('\uf212'),
        faw_sellsy('\uf213'),
        faw_shirtsinbulk('\uf214'),
        faw_simplybuilt('\uf215'),
        faw_skyatlas('\uf216'),
        faw_pinterest_p('\uf231'),
        faw_whatsapp('\uf232'),
        faw_viacoin('\uf237'),
        faw_medium('\uf23a'),
        faw_y_combinator('\uf23b'),
        faw_optin_monster('\uf23c'),
        faw_opencart('\uf23d'),
        faw_expeditedssl('\uf23e'),
        faw_cc_jcb('\uf24b'),
        faw_cc_diners_club('\uf24c'),
        faw_creative_commons('\uf25e'),
        faw_gg('\uf260'),
        faw_gg_circle('\uf261'),
        faw_tripadvisor('\uf262'),
        faw_odnoklassniki('\uf263'),
        faw_odnoklassniki_square('\uf264'),
        faw_get_pocket('\uf265'),
        faw_wikipedia_w('\uf266'),
        faw_safari('\uf267'),
        faw_chrome('\uf268'),
        faw_firefox('\uf269'),
        faw_opera('\uf26a'),
        faw_internet_explorer('\uf26b'),
        faw_contao('\uf26d'),
        faw_500px('\uf26e'),
        faw_amazon('\uf270'),
        faw_houzz('\uf27c'),
        faw_vimeo_v('\uf27d'),
        faw_black_tie('\uf27e'),
        faw_fonticons('\uf280'),
        faw_reddit_alien('\uf281'),
        faw_edge('\uf282'),
        faw_codiepie('\uf284'),
        faw_modx('\uf285'),
        faw_fort_awesome('\uf286'),
        faw_usb('\uf287'),
        faw_product_hunt('\uf288'),
        faw_mixcloud('\uf289'),
        faw_scribd('\uf28a'),
        faw_bluetooth('\uf293'),
        faw_bluetooth_b('\uf294'),
        faw_gitlab('\uf296'),
        faw_wpbeginner('\uf297'),
        faw_wpforms('\uf298'),
        faw_envira('\uf299'),
        faw_glide('\uf2a5'),
        faw_glide_g('\uf2a6'),
        faw_viadeo('\uf2a9'),
        faw_viadeo_square('\uf2aa'),
        faw_snapchat('\uf2ab'),
        faw_snapchat_ghost('\uf2ac'),
        faw_snapchat_square('\uf2ad'),
        faw_pied_piper('\uf2ae'),
        faw_first_order('\uf2b0'),
        faw_yoast('\uf2b1'),
        faw_themeisle('\uf2b2'),
        faw_google_plus('\uf2b3'),
        faw_font_awesome('\uf2b4'),
        faw_linode('\uf2b8'),
        faw_quora('\uf2c4'),
        faw_free_code_camp('\uf2c5'),
        faw_telegram('\uf2c6'),
        faw_bandcamp('\uf2d5'),
        faw_grav('\uf2d6'),
        faw_etsy('\uf2d7'),
        faw_imdb('\uf2d8'),
        faw_ravelry('\uf2d9'),
        faw_sellcast('\uf2da'),
        faw_superpowers('\uf2dd'),
        faw_wpexplorer('\uf2de'),
        faw_meetup('\uf2e0'),
        faw_font_awesome_alt('\uf35c'),
        faw_accessible_icon('\uf368'),
        faw_accusoft('\uf369'),
        faw_adversal('\uf36a'),
        faw_affiliatetheme('\uf36b'),
        faw_algolia('\uf36c'),
        faw_amilia('\uf36d'),
        faw_angrycreative('\uf36e'),
        faw_app_store('\uf36f'),
        faw_app_store_ios('\uf370'),
        faw_apper('\uf371'),
        faw_asymmetrik('\uf372'),
        faw_audible('\uf373'),
        faw_avianex('\uf374'),
        faw_aws('\uf375'),
        faw_bimobject('\uf378'),
        faw_bitcoin('\uf379'),
        faw_bity('\uf37a'),
        faw_blackberry('\uf37b'),
        faw_blogger('\uf37c'),
        faw_blogger_b('\uf37d'),
        faw_buromobelexperte('\uf37f'),
        faw_centercode('\uf380'),
        faw_cloudscale('\uf383'),
        faw_cloudsmith('\uf384'),
        faw_cloudversify('\uf385'),
        faw_cpanel('\uf388'),
        faw_css3_alt('\uf38b'),
        faw_cuttlefish('\uf38c'),
        faw_d_and_d('\uf38d'),
        faw_deploydog('\uf38e'),
        faw_deskpro('\uf38f'),
        faw_digital_ocean('\uf391'),
        faw_discord('\uf392'),
        faw_discourse('\uf393'),
        faw_dochub('\uf394'),
        faw_docker('\uf395'),
        faw_draft2digital('\uf396'),
        faw_dribbble_square('\uf397'),
        faw_dyalog('\uf399'),
        faw_earlybirds('\uf39a'),
        faw_erlang('\uf39d'),
        faw_facebook_f('\uf39e'),
        faw_facebook_messenger('\uf39f'),
        faw_firstdraft('\uf3a1'),
        faw_fonticons_fi('\uf3a2'),
        faw_fort_awesome_alt('\uf3a3'),
        faw_freebsd('\uf3a4'),
        faw_gitkraken('\uf3a6'),
        faw_gofore('\uf3a7'),
        faw_goodreads('\uf3a8'),
        faw_goodreads_g('\uf3a9'),
        faw_google_drive('\uf3aa'),
        faw_google_play('\uf3ab'),
        faw_gripfire('\uf3ac'),
        faw_grunt('\uf3ad'),
        faw_gulp('\uf3ae'),
        faw_hacker_news_square('\uf3af'),
        faw_hire_a_helper('\uf3b0'),
        faw_hotjar('\uf3b1'),
        faw_hubspot('\uf3b2'),
        faw_itunes('\uf3b4'),
        faw_itunes_note('\uf3b5'),
        faw_jenkins('\uf3b6'),
        faw_joget('\uf3b7'),
        faw_js('\uf3b8'),
        faw_js_square('\uf3b9'),
        faw_keycdn('\uf3ba'),
        faw_kickstarter('\uf3bb'),
        faw_kickstarter_k('\uf3bc'),
        faw_laravel('\uf3bd'),
        faw_line('\uf3c0'),
        faw_lyft('\uf3c3'),
        faw_magento('\uf3c4'),
        faw_medapps('\uf3c6'),
        faw_medium_m('\uf3c7'),
        faw_medrt('\uf3c8'),
        faw_microsoft('\uf3ca'),
        faw_mix('\uf3cb'),
        faw_mizuni('\uf3cc'),
        faw_monero('\uf3d0'),
        faw_napster('\uf3d2'),
        faw_node_js('\uf3d3'),
        faw_npm('\uf3d4'),
        faw_ns8('\uf3d5'),
        faw_nutritionix('\uf3d6'),
        faw_page4('\uf3d7'),
        faw_palfed('\uf3d8'),
        faw_patreon('\uf3d9'),
        faw_periscope('\uf3da'),
        faw_phabricator('\uf3db'),
        faw_phoenix_framework('\uf3dc'),
        faw_playstation('\uf3df'),
        faw_pushed('\uf3e1'),
        faw_python('\uf3e2'),
        faw_red_river('\uf3e3'),
        faw_wpressr('\uf3e4'),
        faw_replyd('\uf3e6'),
        faw_resolving('\uf3e7'),
        faw_rocketchat('\uf3e8'),
        faw_rockrms('\uf3e9'),
        faw_schlix('\uf3ea'),
        faw_searchengin('\uf3eb'),
        faw_servicestack('\uf3ec'),
        faw_sistrix('\uf3ee'),
        faw_slack_hash('\uf3ef'),
        faw_speakap('\uf3f3'),
        faw_staylinked('\uf3f5'),
        faw_steam_symbol('\uf3f6'),
        faw_sticker_mule('\uf3f7'),
        faw_studiovinari('\uf3f8'),
        faw_supple('\uf3f9'),
        faw_telegram_plane('\uf3fe'),
        faw_uber('\uf402'),
        faw_uikit('\uf403'),
        faw_uniregistry('\uf404'),
        faw_untappd('\uf405'),
        faw_ussunnah('\uf407'),
        faw_vaadin('\uf408'),
        faw_viber('\uf409'),
        faw_vimeo('\uf40a'),
        faw_vnv('\uf40b'),
        faw_whatsapp_square('\uf40c'),
        faw_whmcs('\uf40d'),
        faw_wordpress_simple('\uf411'),
        faw_xbox('\uf412'),
        faw_yandex('\uf413'),
        faw_yandex_international('\uf414'),
        faw_apple_pay('\uf415'),
        faw_cc_apple_pay('\uf416'),
        faw_fly('\uf417'),
        faw_node('\uf419'),
        faw_osi('\uf41a'),
        faw_react('\uf41b'),
        faw_autoprefixer('\uf41c'),
        faw_less('\uf41d'),
        faw_sass('\uf41e'),
        faw_vuejs('\uf41f'),
        faw_angular('\uf420'),
        faw_aviato('\uf421'),
        faw_ember('\uf423'),
        faw_font_awesome_flag('\uf425'),
        faw_gitter('\uf426'),
        faw_hooli('\uf427'),
        faw_strava('\uf428'),
        faw_stripe('\uf429'),
        faw_stripe_s('\uf42a'),
        faw_typo3('\uf42b'),
        faw_amazon_pay('\uf42c'),
        faw_cc_amazon_pay('\uf42d'),
        faw_ethereum('\uf42e'),
        faw_korvue('\uf42f'),
        faw_elementor('\uf430'),
        faw_youtube_square('\uf431'),
        faw_flipboard('\uf44d'),
        faw_hips('\uf452'),
        faw_php('\uf457'),
        faw_quinscape('\uf459'),
        faw_readme('\uf4d5'),
        faw_java('\uf4e4'),
        faw_pied_piper_hat('\uf4e5'),
        faw_creative_commons_by('\uf4e7'),
        faw_creative_commons_nc('\uf4e8'),
        faw_creative_commons_nc_eu('\uf4e9'),
        faw_creative_commons_nc_jp('\uf4ea'),
        faw_creative_commons_nd('\uf4eb'),
        faw_creative_commons_pd('\uf4ec'),
        faw_creative_commons_pd_alt('\uf4ed'),
        faw_creative_commons_remix('\uf4ee'),
        faw_creative_commons_sa('\uf4ef'),
        faw_creative_commons_sampling('\uf4f0'),
        faw_creative_commons_sampling_plus('\uf4f1'),
        faw_creative_commons_share('\uf4f2'),
        faw_creative_commons_zero('\uf4f3'),
        faw_ebay('\uf4f4'),
        faw_keybase('\uf4f5'),
        faw_mastodon('\uf4f6'),
        faw_r_project('\uf4f7'),
        faw_researchgate('\uf4f8'),
        faw_teamspeak('\uf4f9'),
        faw_first_order_alt('\uf50a'),
        faw_fulcrum('\uf50b'),
        faw_galactic_republic('\uf50c'),
        faw_galactic_senate('\uf50d'),
        faw_jedi_order('\uf50e'),
        faw_mandalorian('\uf50f'),
        faw_old_republic('\uf510'),
        faw_phoenix_squadron('\uf511'),
        faw_sith('\uf512'),
        faw_trade_federation('\uf513'),
        faw_wolf_pack_battalion('\uf514'),
        faw_hornbill('\uf592'),
        faw_mailchimp('\uf59e'),
        faw_megaport('\uf5a3'),
        faw_nimblr('\uf5a8'),
        faw_rev('\uf5b2'),
        faw_shopware('\uf5b5'),
        faw_squarespace('\uf5be'),
        faw_themeco('\uf5c6'),
        faw_weebly('\uf5cc'),
        faw_wix('\uf5cf'),
        faw_ello('\uf5f1'),
        faw_hackerrank('\uf5f7'),
        faw_kaggle('\uf5fa'),
        faw_markdown('\uf60f'),
        faw_neos('\uf612'),
        faw_zhihu('\uf63f'),
        faw_alipay('\uf642'),
        faw_the_red_yeti('\uf69d'),
        faw_acquisitions_incorporated('\uf6af'),
        faw_critical_role('\uf6c9'),
        faw_d_and_d_beyond('\uf6ca'),
        faw_dev('\uf6cc'),
        faw_fantasy_flight_games('\uf6dc'),
        faw_penny_arcade('\uf704'),
        faw_wizards_of_the_coast('\uf730'),
        faw_think_peaks('\uf731'),
        faw_reacteurope('\uf75d'),
        faw_adobe('\uf778'),
        faw_artstation('\uf77a'),
        faw_atlassian('\uf77b'),
        faw_canadian_maple_leaf('\uf785'),
        faw_centos('\uf789'),
        faw_confluence('\uf78d'),
        faw_dhl('\uf790'),
        faw_diaspora('\uf791'),
        faw_fedex('\uf797'),
        faw_fedora('\uf798'),
        faw_figma('\uf799'),
        faw_intercom('\uf7af'),
        faw_invision('\uf7b0'),
        faw_jira('\uf7b1'),
        faw_mendeley('\uf7b3'),
        faw_raspberry_pi('\uf7bb'),
        faw_redhat('\uf7bc'),
        faw_sketch('\uf7c6'),
        faw_sourcetree('\uf7d3'),
        faw_suse('\uf7d6'),
        faw_ubuntu('\uf7df'),
        faw_ups('\uf7e0'),
        faw_usps('\uf7e1'),
        faw_yarn('\uf7e3'),
        faw_airbnb('\uf834'),
        faw_battle_net('\uf835'),
        faw_bootstrap('\uf836'),
        faw_buffer('\uf837'),
        faw_chromecast('\uf838'),
        faw_evernote('\uf839'),
        faw_itch_io('\uf83a'),
        faw_salesforce('\uf83b'),
        faw_speaker_deck('\uf83c'),
        faw_symfony('\uf83d'),
        faw_waze('\uf83f'),
        faw_yammer('\uf840'),
        faw_git_alt('\uf841'),
        faw_stackpath('\uf842'),
        faw_heart('\uf004'),
        faw_star('\uf005'),
        faw_user('\uf007'),
        faw_clock('\uf017'),
        faw_list_alt('\uf022'),
        faw_flag('\uf024'),
        faw_bookmark('\uf02e'),
        faw_image('\uf03e'),
        faw_edit('\uf044'),
        faw_times_circle('\uf057'),
        faw_check_circle('\uf058'),
        faw_question_circle('\uf059'),
        faw_eye('\uf06e'),
        faw_eye_slash('\uf070'),
        faw_calendar_alt('\uf073'),
        faw_comment('\uf075'),
        faw_folder('\uf07b'),
        faw_folder_open('\uf07c'),
        faw_chart_bar('\uf080'),
        faw_comments('\uf086'),
        faw_star_half('\uf089'),
        faw_lemon('\uf094'),
        faw_credit_card('\uf09d'),
        faw_hdd('\uf0a0'),
        faw_hand_point_right('\uf0a4'),
        faw_hand_point_left('\uf0a5'),
        faw_hand_point_up('\uf0a6'),
        faw_hand_point_down('\uf0a7'),
        faw_copy('\uf0c5'),
        faw_save('\uf0c7'),
        faw_square('\uf0c8'),
        faw_envelope('\uf0e0'),
        faw_lightbulb('\uf0eb'),
        faw_bell('\uf0f3'),
        faw_hospital('\uf0f8'),
        faw_plus_square('\uf0fe'),
        faw_circle('\uf111'),
        faw_smile('\uf118'),
        faw_frown('\uf119'),
        faw_meh('\uf11a'),
        faw_keyboard('\uf11c'),
        faw_calendar('\uf133'),
        faw_play_circle('\uf144'),
        faw_minus_square('\uf146'),
        faw_check_square('\uf14a'),
        faw_share_square('\uf14d'),
        faw_compass('\uf14e'),
        faw_caret_square_down('\uf150'),
        faw_caret_square_up('\uf151'),
        faw_caret_square_right('\uf152'),
        faw_file('\uf15b'),
        faw_file_alt('\uf15c'),
        faw_thumbs_up('\uf164'),
        faw_thumbs_down('\uf165'),
        faw_sun('\uf185'),
        faw_moon('\uf186'),
        faw_caret_square_left('\uf191'),
        faw_dot_circle('\uf192'),
        faw_building('\uf1ad'),
        faw_file_pdf('\uf1c1'),
        faw_file_word('\uf1c2'),
        faw_file_excel('\uf1c3'),
        faw_file_powerpoint('\uf1c4'),
        faw_file_image('\uf1c5'),
        faw_file_archive('\uf1c6'),
        faw_file_audio('\uf1c7'),
        faw_file_video('\uf1c8'),
        faw_file_code('\uf1c9'),
        faw_life_ring('\uf1cd'),
        faw_paper_plane('\uf1d8'),
        faw_futbol('\uf1e3'),
        faw_newspaper('\uf1ea'),
        faw_bell_slash('\uf1f6'),
        faw_copyright('\uf1f9'),
        faw_closed_captioning('\uf20a'),
        faw_object_group('\uf247'),
        faw_object_ungroup('\uf248'),
        faw_sticky_note('\uf249'),
        faw_clone('\uf24d'),
        faw_hourglass('\uf254'),
        faw_hand_rock('\uf255'),
        faw_hand_paper('\uf256'),
        faw_hand_scissors('\uf257'),
        faw_hand_lizard('\uf258'),
        faw_hand_spock('\uf259'),
        faw_hand_pointer('\uf25a'),
        faw_hand_peace('\uf25b'),
        faw_registered('\uf25d'),
        faw_calendar_plus('\uf271'),
        faw_calendar_minus('\uf272'),
        faw_calendar_times('\uf273'),
        faw_calendar_check('\uf274'),
        faw_map('\uf279'),
        faw_comment_alt('\uf27a'),
        faw_pause_circle('\uf28b'),
        faw_stop_circle('\uf28d'),
        faw_handshake('\uf2b5'),
        faw_envelope_open('\uf2b6'),
        faw_address_book('\uf2b9'),
        faw_address_card('\uf2bb'),
        faw_user_circle('\uf2bd'),
        faw_id_badge('\uf2c1'),
        faw_id_card('\uf2c2'),
        faw_window_maximize('\uf2d0'),
        faw_window_minimize('\uf2d1'),
        faw_window_restore('\uf2d2'),
        faw_snowflake('\uf2dc'),
        faw_trash_alt('\uf2ed'),
        faw_images('\uf302'),
        faw_clipboard('\uf328'),
        faw_arrow_alt_circle_down('\uf358'),
        faw_arrow_alt_circle_left('\uf359'),
        faw_arrow_alt_circle_right('\uf35a'),
        faw_arrow_alt_circle_up('\uf35b'),
        faw_gem('\uf3a5'),
        faw_money_bill_alt('\uf3d1'),
        faw_window_close('\uf410'),
        faw_comment_dots('\uf4ad'),
        faw_smile_wink('\uf4da'),
        faw_angry('\uf556'),
        faw_dizzy('\uf567'),
        faw_flushed('\uf579'),
        faw_frown_open('\uf57a'),
        faw_grimace('\uf57f'),
        faw_grin('\uf580'),
        faw_grin_alt('\uf581'),
        faw_grin_beam('\uf582'),
        faw_grin_beam_sweat('\uf583'),
        faw_grin_hearts('\uf584'),
        faw_grin_squint('\uf585'),
        faw_grin_squint_tears('\uf586'),
        faw_grin_stars('\uf587'),
        faw_grin_tears('\uf588'),
        faw_grin_tongue('\uf589'),
        faw_grin_tongue_squint('\uf58a'),
        faw_grin_tongue_wink('\uf58b'),
        faw_grin_wink('\uf58c'),
        faw_kiss('\uf596'),
        faw_kiss_beam('\uf597'),
        faw_kiss_wink_heart('\uf598'),
        faw_laugh('\uf599'),
        faw_laugh_beam('\uf59a'),
        faw_laugh_squint('\uf59b'),
        faw_laugh_wink('\uf59c'),
        faw_meh_blank('\uf5a4'),
        faw_meh_rolling_eyes('\uf5a5'),
        faw_sad_cry('\uf5b3'),
        faw_sad_tear('\uf5b4'),
        faw_smile_beam('\uf5b8'),
        faw_surprise('\uf5c2'),
        faw_tired('\uf5c8'),
        faw_glass_martini('\uf000'),
        faw_music('\uf001'),
        faw_search('\uf002'),
        faw_heart1('\uf006'),
        faw_star1('\uf008'),
        faw_user1('\uf009'),
        faw_film('\uf00a'),
        faw_th_large('\uf00b'),
        faw_th('\uf00c'),
        faw_th_list('\uf00d'),
        faw_check('\uf00e'),
        faw_times('\uf00f'),
        faw_search_plus('\uf010'),
        faw_search_minus('\uf011'),
        faw_power_off('\uf012'),
        faw_signal('\uf013'),
        faw_cog('\uf014'),
        faw_home('\uf015'),
        faw_clock1('\uf018'),
        faw_road('\uf019'),
        faw_download('\uf01a'),
        faw_inbox('\uf01c'),
        faw_redo('\uf01e'),
        faw_sync('\uf021'),
        faw_list_alt1('\uf023'),
        faw_lock('\uf025'),
        faw_flag1('\uf026'),
        faw_headphones('\uf027'),
        faw_volume_off('\uf028'),
        faw_volume_down('\uf029'),
        faw_volume_up('\uf02a'),
        faw_qrcode('\uf02b'),
        faw_barcode('\uf02c'),
        faw_tag('\uf02d'),
        faw_tags('\uf02f'),
        faw_book('\uf030'),
        faw_bookmark1('\uf031'),
        faw_print('\uf032'),
        faw_camera('\uf033'),
        faw_font('\uf034'),
        faw_bold('\uf035'),
        faw_italic('\uf036'),
        faw_text_height('\uf037'),
        faw_text_width('\uf038'),
        faw_align_left('\uf039'),
        faw_align_center('\uf03a'),
        faw_align_right('\uf03b'),
        faw_align_justify('\uf03c'),
        faw_list('\uf03d'),
        faw_outdent('\uf03f'),
        faw_indent('\uf040'),
        faw_video('\uf041'),
        faw_image1('\uf042'),
        faw_map_marker('\uf043'),
        faw_adjust('\uf045'),
        faw_tint('\uf046'),
        faw_edit1('\uf047'),
        faw_step_backward('\uf048'),
        faw_fast_backward('\uf049'),
        faw_backward('\uf04a'),
        faw_play('\uf04b'),
        faw_pause('\uf04c'),
        faw_stop('\uf04d'),
        faw_forward('\uf04e'),
        faw_fast_forward('\uf050'),
        faw_step_forward('\uf051'),
        faw_eject('\uf052'),
        faw_chevron_left('\uf053'),
        faw_chevron_right('\uf054'),
        faw_plus_circle('\uf055'),
        faw_minus_circle('\uf056'),
        faw_times_circle1('\uf05a'),
        faw_check_circle1('\uf05b'),
        faw_question_circle1('\uf05c'),
        faw_info_circle('\uf05d'),
        faw_crosshairs('\uf05e'),
        faw_ban('\uf05f'),
        faw_arrow_left('\uf060'),
        faw_arrow_right('\uf061'),
        faw_arrow_up('\uf062'),
        faw_arrow_down('\uf063'),
        faw_share('\uf064'),
        faw_expand('\uf065'),
        faw_compress('\uf066'),
        faw_plus('\uf067'),
        faw_minus('\uf068'),
        faw_asterisk('\uf069'),
        faw_exclamation_circle('\uf06a'),
        faw_gift('\uf06b'),
        faw_leaf('\uf06c'),
        faw_fire('\uf06d'),
        faw_eye1('\uf06f'),
        faw_eye_slash1('\uf071'),
        faw_exclamation_triangle('\uf072'),
        faw_plane('\uf074'),
        faw_calendar_alt1('\uf076'),
        faw_random('\uf077'),
        faw_comment1('\uf078'),
        faw_magnet('\uf079'),
        faw_chevron_up('\uf07a'),
        faw_chevron_down('\uf07d'),
        faw_retweet('\uf07e'),
        faw_shopping_cart('\uf07f'),
        faw_folder1('\uf083'),
        faw_folder_open1('\uf084'),
        faw_chart_bar1('\uf085'),
        faw_camera_retro('\uf087'),
        faw_key('\uf088'),
        faw_cogs('\uf08a'),
        faw_comments1('\uf08b'),
        faw_star_half1('\uf08d'),
        faw_thumbtack('\uf08e'),
        faw_trophy('\uf091'),
        faw_upload('\uf093'),
        faw_lemon1('\uf095'),
        faw_phone('\uf096'),
        faw_phone_square('\uf098'),
        faw_unlock('\uf09c'),
        faw_credit_card1('\uf09e'),
        faw_rss('\uf09f'),
        faw_hdd1('\uf0a1'),
        faw_bullhorn('\uf0a2'),
        faw_certificate('\uf0a3'),
        faw_hand_point_right1('\uf0a8'),
        faw_hand_point_left1('\uf0a9'),
        faw_hand_point_up1('\uf0aa'),
        faw_hand_point_down1('\uf0ab'),
        faw_arrow_circle_left('\uf0ac'),
        faw_arrow_circle_right('\uf0ad'),
        faw_arrow_circle_up('\uf0ae'),
        faw_arrow_circle_down('\uf0af'),
        faw_globe('\uf0b0'),
        faw_wrench('\uf0b1'),
        faw_tasks('\uf0b2'),
        faw_filter('\uf0b3'),
        faw_briefcase('\uf0b4'),
        faw_arrows_alt('\uf0b5'),
        faw_users('\uf0c0'),
        faw_link('\uf0c1'),
        faw_cloud('\uf0c2'),
        faw_flask('\uf0c3'),
        faw_cut('\uf0c4'),
        faw_copy1('\uf0c6'),
        faw_paperclip('\uf0c9'),
        faw_save1('\uf0ca'),
        faw_square1('\uf0cb'),
        faw_bars('\uf0cc'),
        faw_list_ul('\uf0cd'),
        faw_list_ol('\uf0ce'),
        faw_strikethrough('\uf0cf'),
        faw_underline('\uf0d0'),
        faw_table('\uf0d1'),
        faw_magic('\uf0d6'),
        faw_truck('\uf0d7'),
        faw_money_bill('\uf0d8'),
        faw_caret_down('\uf0d9'),
        faw_caret_up('\uf0da'),
        faw_caret_left('\uf0db'),
        faw_caret_right('\uf0dc'),
        faw_columns('\uf0dd'),
        faw_sort('\uf0de'),
        faw_sort_down('\uf0df'),
        faw_sort_up('\uf0e2'),
        faw_envelope1('\uf0e3'),
        faw_undo('\uf0e4'),
        faw_gavel('\uf0e5'),
        faw_bolt('\uf0e7'),
        faw_sitemap('\uf0e8'),
        faw_umbrella('\uf0e9'),
        faw_paste('\uf0ea'),
        faw_lightbulb1('\uf0ec'),
        faw_user_md('\uf0f0'),
        faw_stethoscope('\uf0f1'),
        faw_suitcase('\uf0f2'),
        faw_bell1('\uf0f4'),
        faw_coffee('\uf0f5'),
        faw_hospital1('\uf0f9'),
        faw_ambulance('\uf0fa'),
        faw_medkit('\uf0fb'),
        faw_fighter_jet('\uf0fc'),
        faw_beer('\uf0fd'),
        faw_h_square('\uf0ff'),
        faw_plus_square1('\uf100'),
        faw_angle_double_left('\uf101'),
        faw_angle_double_right('\uf102'),
        faw_angle_double_up('\uf103'),
        faw_angle_double_down('\uf104'),
        faw_angle_left('\uf105'),
        faw_angle_right('\uf106'),
        faw_angle_up('\uf107'),
        faw_angle_down('\uf108'),
        faw_desktop('\uf109'),
        faw_laptop('\uf10a'),
        faw_tablet('\uf10b'),
        faw_mobile('\uf10c'),
        faw_quote_left('\uf10d'),
        faw_quote_right('\uf10e'),
        faw_spinner('\uf110'),
        faw_circle1('\uf112'),
        faw_smile1('\uf11b'),
        faw_frown1('\uf11d'),
        faw_meh1('\uf11e'),
        faw_gamepad('\uf11f'),
        faw_keyboard1('\uf120'),
        faw_flag_checkered('\uf121'),
        faw_terminal('\uf122'),
        faw_code('\uf123'),
        faw_reply_all('\uf124'),
        faw_location_arrow('\uf125'),
        faw_crop('\uf126'),
        faw_code_branch('\uf127'),
        faw_unlink('\uf128'),
        faw_question('\uf129'),
        faw_info('\uf12a'),
        faw_exclamation('\uf12b'),
        faw_superscript('\uf12c'),
        faw_subscript('\uf12d'),
        faw_eraser('\uf12e'),
        faw_puzzle_piece('\uf12f'),
        faw_microphone('\uf130'),
        faw_microphone_slash('\uf131'),
        faw_calendar1('\uf134'),
        faw_fire_extinguisher('\uf135'),
        faw_rocket('\uf137'),
        faw_chevron_circle_left('\uf138'),
        faw_chevron_circle_right('\uf139'),
        faw_chevron_circle_up('\uf13a'),
        faw_chevron_circle_down('\uf13d'),
        faw_anchor('\uf13e'),
        faw_unlock_alt('\uf13f'),
        faw_bullseye('\uf140'),
        faw_ellipsis_h('\uf141'),
        faw_ellipsis_v('\uf142'),
        faw_rss_square('\uf143'),
        faw_play_circle1('\uf145'),
        faw_minus_square1('\uf147'),
        faw_check_square1('\uf14b'),
        faw_pen_square('\uf14c'),
        faw_share_square1('\uf14f'),
        faw_compass1('\uf153'),
        faw_caret_square_down1('\uf154'),
        faw_caret_square_up1('\uf155'),
        faw_caret_square_right1('\uf156'),
        faw_euro_sign('\uf157'),
        faw_pound_sign('\uf158'),
        faw_dollar_sign('\uf159'),
        faw_rupee_sign('\uf15d'),
        faw_yen_sign('\uf15e'),
        faw_ruble_sign('\uf15f'),
        faw_won_sign('\uf160'),
        faw_file1('\uf161'),
        faw_file_alt1('\uf162'),
        faw_sort_alpha_down('\uf163'),
        faw_sort_alpha_up('\uf166'),
        faw_sort_amount_down('\uf16a'),
        faw_sort_amount_up('\uf16f'),
        faw_sort_numeric_down('\uf172'),
        faw_sort_numeric_up('\uf175'),
        faw_thumbs_up1('\uf176'),
        faw_thumbs_down1('\uf177'),
        faw_female('\uf182'),
        faw_male('\uf183'),
        faw_sun1('\uf187'),
        faw_moon1('\uf188'),
        faw_archive('\uf18e'),
        faw_bug('\uf18f'),
        faw_caret_square_left1('\uf193'),
        faw_dot_circle1('\uf195'),
        faw_wheelchair('\uf196'),
        faw_lira_sign('\uf197'),
        faw_space_shuttle('\uf199'),
        faw_envelope_square('\uf19c'),
        faw_university('\uf19d'),
        faw_graduation_cap('\uf19f'),
        faw_language('\uf1ab'),
        faw_fax('\uf1ac'),
        faw_building1('\uf1ae'),
        faw_child('\uf1af'),
        faw_paw('\uf1b0'),
        faw_cube('\uf1b2'),
        faw_cubes('\uf1b3'),
        faw_recycle('\uf1b8'),
        faw_car('\uf1b9'),
        faw_taxi('\uf1ba'),
        faw_tree('\uf1bb'),
        faw_database('\uf1c0'),
        faw_file_pdf1('\uf1ce'),
        faw_file_word1('\uf1cf'),
        faw_file_excel1('\uf1d9'),
        faw_file_powerpoint1('\uf1da'),
        faw_file_image1('\uf1db'),
        faw_file_archive1('\uf1dc'),
        faw_file_audio1('\uf1dd'),
        faw_file_video1('\uf1de'),
        faw_file_code1('\uf1df'),
        faw_life_ring1('\uf1e0'),
        faw_circle_notch('\uf1e1'),
        faw_paper_plane1('\uf1e2'),
        faw_history('\uf1e4'),
        faw_heading('\uf1e5'),
        faw_paragraph('\uf1e6'),
        faw_sliders_h('\uf1eb'),
        faw_share_alt('\uf1ec'),
        faw_share_alt_square('\uf1ef'),
        faw_bomb('\uf1f7'),
        faw_futbol1('\uf1f8'),
        faw_tty('\uf1fa'),
        faw_binoculars('\uf1fb'),
        faw_plug('\uf1fc'),
        faw_newspaper1('\uf1fd'),
        faw_wifi('\uf1fe'),
        faw_calculator('\uf1ff'),
        faw_bell_slash1('\uf200'),
        faw_trash('\uf201'),
        faw_copyright1('\uf204'),
        faw_at('\uf205'),
        faw_eye_dropper('\uf206'),
        faw_paint_brush('\uf207'),
        faw_birthday_cake('\uf20b'),
        faw_chart_area('\uf20c'),
        faw_chart_pie('\uf20f'),
        faw_chart_line('\uf217'),
        faw_toggle_off('\uf218'),
        faw_toggle_on('\uf219'),
        faw_bicycle('\uf21a'),
        faw_bus('\uf21b'),
        faw_closed_captioning1('\uf21c'),
        faw_shekel_sign('\uf21d'),
        faw_cart_plus('\uf21e'),
        faw_cart_arrow_down('\uf21f'),
        faw_ship('\uf220'),
        faw_user_secret('\uf221'),
        faw_motorcycle('\uf222'),
        faw_street_view('\uf223'),
        faw_heartbeat('\uf224'),
        faw_venus('\uf225'),
        faw_mars('\uf226'),
        faw_mercury('\uf227'),
        faw_transgender('\uf228'),
        faw_transgender_alt('\uf229'),
        faw_venus_double('\uf22a'),
        faw_mars_double('\uf22b'),
        faw_venus_mars('\uf22c'),
        faw_mars_stroke('\uf22d'),
        faw_mars_stroke_v('\uf22e'),
        faw_mars_stroke_h('\uf22f'),
        faw_neuter('\uf230'),
        faw_genderless('\uf233'),
        faw_server('\uf234'),
        faw_user_plus('\uf235'),
        faw_user_times('\uf236'),
        faw_bed('\uf238'),
        faw_train('\uf239'),
        faw_subway('\uf23f'),
        faw_battery_full('\uf240'),
        faw_battery_three_quarters('\uf241'),
        faw_battery_half('\uf242'),
        faw_battery_quarter('\uf243'),
        faw_battery_empty('\uf244'),
        faw_mouse_pointer('\uf245'),
        faw_i_cursor('\uf246'),
        faw_object_group1('\uf24a'),
        faw_object_ungroup1('\uf24e'),
        faw_sticky_note1('\uf24f'),
        faw_clone1('\uf250'),
        faw_balance_scale('\uf251'),
        faw_hourglass_start('\uf252'),
        faw_hourglass_half('\uf253'),
        faw_hourglass_end('\uf25c'),
        faw_hourglass1('\uf25f'),
        faw_hand_rock1('\uf26c'),
        faw_hand_paper1('\uf26f'),
        faw_hand_scissors1('\uf275'),
        faw_hand_lizard1('\uf276'),
        faw_hand_spock1('\uf277'),
        faw_hand_pointer1('\uf278'),
        faw_hand_peace1('\uf27b'),
        faw_trademark('\uf27f'),
        faw_registered1('\uf283'),
        faw_tv('\uf28c'),
        faw_calendar_plus1('\uf28e'),
        faw_calendar_minus1('\uf28f'),
        faw_calendar_times1('\uf290'),
        faw_calendar_check1('\uf291'),
        faw_industry('\uf292'),
        faw_map_pin('\uf295'),
        faw_map_signs('\uf29a'),
        faw_map1('\uf29b'),
        faw_comment_alt1('\uf29c'),
        faw_pause_circle1('\uf29d'),
        faw_stop_circle1('\uf29e'),
        faw_shopping_bag('\uf29f'),
        faw_shopping_basket('\uf2a0'),
        faw_hashtag('\uf2a1'),
        faw_percent('\uf2a2'),
        faw_universal_access('\uf2a3'),
        faw_blind('\uf2a4'),
        faw_audio_description('\uf2a7'),
        faw_phone_volume('\uf2a8'),
        faw_braille('\uf2af'),
        faw_assistive_listening_systems('\uf2b7'),
        faw_american_sign_language_interpreting('\uf2ba'),
        faw_deaf('\uf2bc'),
        faw_sign_language('\uf2be'),
        faw_low_vision('\uf2bf'),
        faw_handshake1('\uf2c0'),
        faw_envelope_open1('\uf2c3'),
        faw_address_book1('\uf2c7'),
        faw_address_card1('\uf2c8'),
        faw_user_circle1('\uf2c9'),
        faw_id_badge1('\uf2ca'),
        faw_id_card1('\uf2cb'),
        faw_thermometer_full('\uf2cc'),
        faw_thermometer_three_quarters('\uf2cd'),
        faw_thermometer_half('\uf2ce'),
        faw_thermometer_quarter('\uf2cf'),
        faw_thermometer_empty('\uf2d3'),
        faw_shower('\uf2d4'),
        faw_bath('\uf2db'),
        faw_podcast('\uf2df'),
        faw_window_maximize1('\uf2e1'),
        faw_window_minimize1('\uf2e2'),
        faw_window_restore1('\uf2e3'),
        faw_microchip('\uf2e4'),
        faw_snowflake1('\uf2e5'),
        faw_utensil_spoon('\uf2e6'),
        faw_utensils('\uf2e7'),
        faw_undo_alt('\uf2ea'),
        faw_trash_alt1('\uf2ee'),
        faw_sync_alt('\uf2f1'),
        faw_stopwatch('\uf2f2'),
        faw_sign_out_alt('\uf2f5'),
        faw_sign_in_alt('\uf2f6'),
        faw_redo_alt('\uf2f9'),
        faw_poo('\uf2fe'),
        faw_images1('\uf303'),
        faw_pencil_alt('\uf304'),
        faw_pen('\uf305'),
        faw_pen_alt('\uf306'),
        faw_long_arrow_alt_down('\uf309'),
        faw_long_arrow_alt_left('\uf30a'),
        faw_long_arrow_alt_right('\uf30b'),
        faw_long_arrow_alt_up('\uf30c'),
        faw_expand_arrows_alt('\uf31e'),
        faw_clipboard1('\uf329'),
        faw_arrows_alt_h('\uf337'),
        faw_arrows_alt_v('\uf338'),
        faw_arrow_alt_circle_down1('\uf35d'),
        faw_arrow_alt_circle_left1('\uf35e'),
        faw_arrow_alt_circle_right1('\uf35f'),
        faw_arrow_alt_circle_up1('\uf360'),
        faw_external_link_alt('\uf361'),
        faw_external_link_square_alt('\uf362'),
        faw_exchange_alt('\uf363'),
        faw_cloud_download_alt('\uf381'),
        faw_cloud_upload_alt('\uf382'),
        faw_gem1('\uf3b3'),
        faw_level_down_alt('\uf3be'),
        faw_level_up_alt('\uf3bf'),
        faw_lock_open('\uf3c1'),
        faw_map_marker_alt('\uf3c5'),
        faw_microphone_alt('\uf3c9'),
        faw_mobile_alt('\uf3cd'),
        faw_money_bill_alt1('\uf3dd'),
        faw_phone_slash('\uf3de'),
        faw_portrait('\uf3e0'),
        faw_reply('\uf3e5'),
        faw_shield_alt('\uf3ed'),
        faw_tablet_alt('\uf3fa'),
        faw_tachometer_alt('\uf3fd'),
        faw_ticket_alt('\uf3ff'),
        faw_user_alt('\uf406'),
        faw_window_close1('\uf418'),
        faw_baseball_ball('\uf433'),
        faw_basketball_ball('\uf434'),
        faw_bowling_ball('\uf436'),
        faw_chess('\uf439'),
        faw_chess_bishop('\uf43a'),
        faw_chess_board('\uf43c'),
        faw_chess_king('\uf43f'),
        faw_chess_knight('\uf441'),
        faw_chess_pawn('\uf443'),
        faw_chess_queen('\uf445'),
        faw_chess_rook('\uf447'),
        faw_dumbbell('\uf44b'),
        faw_football_ball('\uf44e'),
        faw_golf_ball('\uf450'),
        faw_hockey_puck('\uf453'),
        faw_quidditch('\uf458'),
        faw_square_full('\uf45c'),
        faw_table_tennis('\uf45d'),
        faw_volleyball_ball('\uf45f'),
        faw_allergies('\uf461'),
        faw_band_aid('\uf462'),
        faw_box('\uf466'),
        faw_boxes('\uf468'),
        faw_briefcase_medical('\uf469'),
        faw_burn('\uf46a'),
        faw_capsules('\uf46b'),
        faw_clipboard_check('\uf46c'),
        faw_clipboard_list('\uf46d'),
        faw_diagnoses('\uf470'),
        faw_dna('\uf471'),
        faw_dolly('\uf472'),
        faw_dolly_flatbed('\uf474'),
        faw_file_medical('\uf477'),
        faw_file_medical_alt('\uf478'),
        faw_first_aid('\uf479'),
        faw_hospital_alt('\uf47d'),
        faw_hospital_symbol('\uf47e'),
        faw_id_card_alt('\uf47f'),
        faw_notes_medical('\uf481'),
        faw_pallet('\uf482'),
        faw_pills('\uf484'),
        faw_prescription_bottle('\uf485'),
        faw_prescription_bottle_alt('\uf486'),
        faw_procedures('\uf487'),
        faw_shipping_fast('\uf48b'),
        faw_smoking('\uf48d'),
        faw_syringe('\uf48e'),
        faw_tablets('\uf490'),
        faw_thermometer('\uf491'),
        faw_vial('\uf492'),
        faw_vials('\uf493'),
        faw_warehouse('\uf494'),
        faw_weight('\uf496'),
        faw_x_ray('\uf497'),
        faw_box_open('\uf49e'),
        faw_comment_dots1('\uf4ae'),
        faw_comment_slash('\uf4b3'),
        faw_couch('\uf4b8'),
        faw_donate('\uf4b9'),
        faw_dove('\uf4ba'),
        faw_hand_holding('\uf4bd'),
        faw_hand_holding_heart('\uf4be'),
        faw_hand_holding_usd('\uf4c0'),
        faw_hands('\uf4c2'),
        faw_hands_helping('\uf4c4'),
        faw_parachute_box('\uf4cd'),
        faw_people_carry('\uf4ce'),
        faw_piggy_bank('\uf4d3'),
        faw_ribbon('\uf4d6'),
        faw_route('\uf4d7'),
        faw_seedling('\uf4d8'),
        faw_sign('\uf4d9'),
        faw_smile_wink1('\uf4db'),
        faw_tape('\uf4dc'),
        faw_truck_loading('\uf4de'),
        faw_truck_moving('\uf4df'),
        faw_video_slash('\uf4e2'),
        faw_wine_glass('\uf4e3'),
        faw_user_alt_slash('\uf4fa'),
        faw_user_astronaut('\uf4fb'),
        faw_user_check('\uf4fc'),
        faw_user_clock('\uf4fd'),
        faw_user_cog('\uf4fe'),
        faw_user_edit('\uf4ff'),
        faw_user_friends('\uf500'),
        faw_user_graduate('\uf501'),
        faw_user_lock('\uf502'),
        faw_user_minus('\uf503'),
        faw_user_ninja('\uf504'),
        faw_user_shield('\uf505'),
        faw_user_slash('\uf506'),
        faw_user_tag('\uf507'),
        faw_user_tie('\uf508'),
        faw_users_cog('\uf509'),
        faw_balance_scale_left('\uf515'),
        faw_balance_scale_right('\uf516'),
        faw_blender('\uf517'),
        faw_book_open('\uf518'),
        faw_broadcast_tower('\uf519'),
        faw_broom('\uf51a'),
        faw_chalkboard('\uf51b'),
        faw_chalkboard_teacher('\uf51c'),
        faw_church('\uf51d'),
        faw_coins('\uf51e'),
        faw_compact_disc('\uf51f'),
        faw_crow('\uf520'),
        faw_crown('\uf521'),
        faw_dice('\uf522'),
        faw_dice_five('\uf523'),
        faw_dice_four('\uf524'),
        faw_dice_one('\uf525'),
        faw_dice_six('\uf526'),
        faw_dice_three('\uf527'),
        faw_dice_two('\uf528'),
        faw_divide('\uf529'),
        faw_door_closed('\uf52a'),
        faw_door_open('\uf52b'),
        faw_equals('\uf52c'),
        faw_feather('\uf52d'),
        faw_frog('\uf52e'),
        faw_gas_pump('\uf52f'),
        faw_glasses('\uf530'),
        faw_greater_than('\uf531'),
        faw_greater_than_equal('\uf532'),
        faw_helicopter('\uf533'),
        faw_infinity('\uf534'),
        faw_kiwi_bird('\uf535'),
        faw_less_than('\uf536'),
        faw_less_than_equal('\uf537'),
        faw_memory('\uf538'),
        faw_microphone_alt_slash('\uf539'),
        faw_money_bill_wave('\uf53a'),
        faw_money_bill_wave_alt('\uf53b'),
        faw_money_check('\uf53c'),
        faw_money_check_alt('\uf53d'),
        faw_not_equal('\uf53e'),
        faw_palette('\uf53f'),
        faw_parking('\uf540'),
        faw_percentage('\uf541'),
        faw_project_diagram('\uf542'),
        faw_receipt('\uf543'),
        faw_robot('\uf544'),
        faw_ruler('\uf545'),
        faw_ruler_combined('\uf546'),
        faw_ruler_horizontal('\uf547'),
        faw_ruler_vertical('\uf548'),
        faw_school('\uf549'),
        faw_screwdriver('\uf54a'),
        faw_shoe_prints('\uf54b'),
        faw_skull('\uf54c'),
        faw_smoking_ban('\uf54d'),
        faw_store('\uf54e'),
        faw_store_alt('\uf54f'),
        faw_stream('\uf550'),
        faw_stroopwafel('\uf551'),
        faw_toolbox('\uf552'),
        faw_tshirt('\uf553'),
        faw_walking('\uf554'),
        faw_wallet('\uf555'),
        faw_angry1('\uf557'),
        faw_archway('\uf558'),
        faw_atlas('\uf559'),
        faw_award('\uf55a'),
        faw_backspace('\uf55b'),
        faw_bezier_curve('\uf55c'),
        faw_bong('\uf55d'),
        faw_brush('\uf55e'),
        faw_bus_alt('\uf55f'),
        faw_cannabis('\uf560'),
        faw_check_double('\uf561'),
        faw_cocktail('\uf562'),
        faw_concierge_bell('\uf563'),
        faw_cookie('\uf564'),
        faw_cookie_bite('\uf565'),
        faw_crop_alt('\uf566'),
        faw_digital_tachograph('\uf568'),
        faw_dizzy1('\uf569'),
        faw_drafting_compass('\uf56a'),
        faw_drum('\uf56b'),
        faw_drum_steelpan('\uf56c'),
        faw_feather_alt('\uf56d'),
        faw_file_contract('\uf56e'),
        faw_file_download('\uf56f'),
        faw_file_export('\uf570'),
        faw_file_import('\uf571'),
        faw_file_invoice('\uf572'),
        faw_file_invoice_dollar('\uf573'),
        faw_file_prescription('\uf574'),
        faw_file_signature('\uf575'),
        faw_file_upload('\uf576'),
        faw_fill('\uf577'),
        faw_fill_drip('\uf578'),
        faw_fingerprint('\uf57b'),
        faw_fish('\uf57c'),
        faw_flushed1('\uf57d'),
        faw_frown_open1('\uf57e'),
        faw_glass_martini_alt('\uf58d'),
        faw_globe_africa('\uf58e'),
        faw_globe_americas('\uf58f'),
        faw_globe_asia('\uf590'),
        faw_grimace1('\uf591'),
        faw_grin1('\uf593'),
        faw_grin_alt1('\uf594'),
        faw_grin_beam1('\uf595'),
        faw_grin_beam_sweat1('\uf59d'),
        faw_grin_hearts1('\uf59f'),
        faw_grin_squint1('\uf5a0'),
        faw_grin_squint_tears1('\uf5a1'),
        faw_grin_stars1('\uf5a2'),
        faw_grin_tears1('\uf5a6'),
        faw_grin_tongue1('\uf5a7'),
        faw_grin_tongue_squint1('\uf5a9'),
        faw_grin_tongue_wink1('\uf5aa'),
        faw_grin_wink1('\uf5ab'),
        faw_grip_horizontal('\uf5ac'),
        faw_grip_vertical('\uf5ad'),
        faw_headphones_alt('\uf5ae'),
        faw_headset('\uf5af'),
        faw_highlighter('\uf5b0'),
        faw_hot_tub('\uf5b1'),
        faw_hotel('\uf5b6'),
        faw_joint('\uf5b7'),
        faw_kiss1('\uf5b9'),
        faw_kiss_beam1('\uf5ba'),
        faw_kiss_wink_heart1('\uf5bb'),
        faw_laugh1('\uf5bc'),
        faw_laugh_beam1('\uf5bd'),
        faw_laugh_squint1('\uf5bf'),
        faw_laugh_wink1('\uf5c0'),
        faw_luggage_cart('\uf5c1'),
        faw_map_marked('\uf5c3'),
        faw_map_marked_alt('\uf5c4'),
        faw_marker('\uf5c5'),
        faw_medal('\uf5c7'),
        faw_meh_blank1('\uf5c9'),
        faw_meh_rolling_eyes1('\uf5ca'),
        faw_monument('\uf5cb'),
        faw_mortar_pestle('\uf5cd'),
        faw_paint_roller('\uf5ce'),
        faw_passport('\uf5d0'),
        faw_pen_fancy('\uf5d1'),
        faw_pen_nib('\uf5d2'),
        faw_pencil_ruler('\uf5d3'),
        faw_plane_arrival('\uf5d4'),
        faw_plane_departure('\uf5d5'),
        faw_prescription('\uf5d6'),
        faw_sad_cry1('\uf5d7'),
        faw_sad_tear1('\uf5d8'),
        faw_shuttle_van('\uf5d9'),
        faw_signature('\uf5da'),
        faw_smile_beam1('\uf5db'),
        faw_solar_panel('\uf5dc'),
        faw_spa('\uf5dd'),
        faw_splotch('\uf5de'),
        faw_spray_can('\uf5df'),
        faw_stamp('\uf5e0'),
        faw_star_half_alt('\uf5e1'),
        faw_suitcase_rolling('\uf5e2'),
        faw_surprise1('\uf5e3'),
        faw_swatchbook('\uf5e4'),
        faw_swimmer('\uf5e5'),
        faw_swimming_pool('\uf5e6'),
        faw_tint_slash('\uf5e7'),
        faw_tired1('\uf5e8'),
        faw_tooth('\uf5e9'),
        faw_umbrella_beach('\uf5ea'),
        faw_vector_square('\uf5eb'),
        faw_weight_hanging('\uf5ec'),
        faw_wine_glass_alt('\uf5ed'),
        faw_air_freshener('\uf5ee'),
        faw_apple_alt('\uf5ef'),
        faw_atom('\uf5f0'),
        faw_bone('\uf5f2'),
        faw_book_reader('\uf5f3'),
        faw_brain('\uf5f4'),
        faw_car_alt('\uf5f5'),
        faw_car_battery('\uf5f6'),
        faw_car_crash('\uf5f8'),
        faw_car_side('\uf5f9'),
        faw_charging_station('\uf5fb'),
        faw_directions('\uf5fc'),
        faw_draw_polygon('\uf5fd'),
        faw_laptop_code('\uf5fe'),
        faw_layer_group('\uf5ff'),
        faw_microscope('\uf610'),
        faw_oil_can('\uf613'),
        faw_poop('\uf619'),
        faw_shapes('\uf61f'),
        faw_star_of_life('\uf621'),
        faw_teeth('\uf62e'),
        faw_teeth_open('\uf62f'),
        faw_theater_masks('\uf630'),
        faw_traffic_light('\uf637'),
        faw_truck_monster('\uf63b'),
        faw_truck_pickup('\uf63c'),
        faw_ad('\uf641'),
        faw_ankh('\uf644'),
        faw_bible('\uf647'),
        faw_business_time('\uf64a'),
        faw_city('\uf64f'),
        faw_comment_dollar('\uf651'),
        faw_comments_dollar('\uf653'),
        faw_cross('\uf654'),
        faw_dharmachakra('\uf655'),
        faw_envelope_open_text('\uf658'),
        faw_folder_minus('\uf65d'),
        faw_folder_plus('\uf65e'),
        faw_funnel_dollar('\uf662'),
        faw_gopuram('\uf664'),
        faw_hamsa('\uf665'),
        faw_haykal('\uf666'),
        faw_jedi('\uf669'),
        faw_journal_whills('\uf66a'),
        faw_kaaba('\uf66b'),
        faw_khanda('\uf66d'),
        faw_landmark('\uf66f'),
        faw_mail_bulk('\uf674'),
        faw_menorah('\uf676'),
        faw_mosque('\uf678'),
        faw_om('\uf679'),
        faw_pastafarianism('\uf67b'),
        faw_peace('\uf67c'),
        faw_place_of_worship('\uf67f'),
        faw_poll('\uf681'),
        faw_poll_h('\uf682'),
        faw_pray('\uf683'),
        faw_praying_hands('\uf684'),
        faw_quran('\uf687'),
        faw_search_dollar('\uf688'),
        faw_search_location('\uf689'),
        faw_socks('\uf696'),
        faw_square_root_alt('\uf698'),
        faw_star_and_crescent('\uf699'),
        faw_star_of_david('\uf69a'),
        faw_synagogue('\uf69b'),
        faw_torah('\uf6a0'),
        faw_torii_gate('\uf6a1'),
        faw_vihara('\uf6a7'),
        faw_volume_mute('\uf6a9'),
        faw_yin_yang('\uf6ad'),
        faw_blender_phone('\uf6b6'),
        faw_book_dead('\uf6b7'),
        faw_campground('\uf6bb'),
        faw_cat('\uf6be'),
        faw_chair('\uf6c0'),
        faw_cloud_moon('\uf6c3'),
        faw_cloud_sun('\uf6c4'),
        faw_dice_d20('\uf6cf'),
        faw_dice_d6('\uf6d1'),
        faw_dog('\uf6d3'),
        faw_dragon('\uf6d5'),
        faw_drumstick_bite('\uf6d7'),
        faw_dungeon('\uf6d9'),
        faw_file_csv('\uf6dd'),
        faw_fist_raised('\uf6de'),
        faw_ghost('\uf6e2'),
        faw_hammer('\uf6e3'),
        faw_hanukiah('\uf6e6'),
        faw_hat_wizard('\uf6e8'),
        faw_hiking('\uf6ec'),
        faw_hippo('\uf6ed'),
        faw_horse('\uf6f0'),
        faw_house_damage('\uf6f1'),
        faw_hryvnia('\uf6f2'),
        faw_mask('\uf6fa'),
        faw_mountain('\uf6fc'),
        faw_network_wired('\uf6ff'),
        faw_otter('\uf700'),
        faw_ring('\uf70b'),
        faw_running('\uf70c'),
        faw_scroll('\uf70e'),
        faw_skull_crossbones('\uf714'),
        faw_slash('\uf715'),
        faw_spider('\uf717'),
        faw_toilet_paper('\uf71e'),
        faw_tractor('\uf722'),
        faw_user_injured('\uf728'),
        faw_vr_cardboard('\uf729'),
        faw_wind('\uf72e'),
        faw_wine_bottle('\uf72f'),
        faw_cloud_meatball('\uf73b'),
        faw_cloud_moon_rain('\uf73c'),
        faw_cloud_rain('\uf73d'),
        faw_cloud_showers_heavy('\uf740'),
        faw_cloud_sun_rain('\uf743'),
        faw_democrat('\uf747'),
        faw_flag_usa('\uf74d'),
        faw_meteor('\uf753'),
        faw_person_booth('\uf756'),
        faw_poo_storm('\uf75a'),
        faw_rainbow('\uf75b'),
        faw_republican('\uf75e'),
        faw_smog('\uf75f'),
        faw_temperature_high('\uf769'),
        faw_temperature_low('\uf76b'),
        faw_vote_yea('\uf772'),
        faw_water('\uf773'),
        faw_baby('\uf77c'),
        faw_baby_carriage('\uf77d'),
        faw_biohazard('\uf780'),
        faw_blog('\uf781'),
        faw_calendar_day('\uf783'),
        faw_calendar_week('\uf784'),
        faw_candy_cane('\uf786'),
        faw_carrot('\uf787'),
        faw_cash_register('\uf788'),
        faw_compress_arrows_alt('\uf78c'),
        faw_dumpster('\uf793'),
        faw_dumpster_fire('\uf794'),
        faw_ethernet('\uf796'),
        faw_gifts('\uf79c'),
        faw_glass_cheers('\uf79f'),
        faw_glass_whiskey('\uf7a0'),
        faw_globe_europe('\uf7a2'),
        faw_grip_lines('\uf7a4'),
        faw_grip_lines_vertical('\uf7a5'),
        faw_guitar('\uf7a6'),
        faw_heart_broken('\uf7a9'),
        faw_holly_berry('\uf7aa'),
        faw_horse_head('\uf7ab'),
        faw_icicles('\uf7ad'),
        faw_igloo('\uf7ae'),
        faw_mitten('\uf7b5'),
        faw_mug_hot('\uf7b6'),
        faw_radiation('\uf7b9'),
        faw_radiation_alt('\uf7ba'),
        faw_restroom('\uf7bd'),
        faw_satellite('\uf7bf'),
        faw_satellite_dish('\uf7c0'),
        faw_sd_card('\uf7c2'),
        faw_sim_card('\uf7c4'),
        faw_skating('\uf7c5'),
        faw_skiing('\uf7c9'),
        faw_skiing_nordic('\uf7ca'),
        faw_sleigh('\uf7cc'),
        faw_sms('\uf7cd'),
        faw_snowboarding('\uf7ce'),
        faw_snowman('\uf7d0'),
        faw_snowplow('\uf7d2'),
        faw_tenge('\uf7d7'),
        faw_toilet('\uf7d8'),
        faw_tools('\uf7d9'),
        faw_tram('\uf7da'),
        faw_fire_alt('\uf7e4'),
        faw_bacon('\uf7e5'),
        faw_book_medical('\uf7e6'),
        faw_bread_slice('\uf7ec'),
        faw_cheese('\uf7ef'),
        faw_clinic_medical('\uf7f2'),
        faw_comment_medical('\uf7f5'),
        faw_crutch('\uf7f7'),
        faw_egg('\uf7fb'),
        faw_hamburger('\uf805'),
        faw_hand_middle_finger('\uf806'),
        faw_hard_hat('\uf807'),
        faw_hotdog('\uf80f'),
        faw_ice_cream('\uf810'),
        faw_laptop_medical('\uf812'),
        faw_pager('\uf815'),
        faw_pepper_hot('\uf816'),
        faw_pizza_slice('\uf818'),
        faw_trash_restore('\uf829'),
        faw_trash_restore_alt('\uf82a'),
        faw_user_nurse('\uf82f'),
        faw_wave_square('\uf83e'),
        faw_biking('\uf84a'),
        faw_border_all('\uf84c'),
        faw_border_none('\uf850'),
        faw_border_style('\uf853'),
        faw_fan('\uf863'),
        faw_icons('\uf86d'),
        faw_phone_alt('\uf879'),
        faw_phone_square_alt('\uf87b'),
        faw_photo_video('\uf87c'),
        faw_remove_format('\uf87d'),
        faw_sort_alpha_down_alt('\uf881'),
        faw_sort_alpha_up_alt('\uf882'),
        faw_sort_amount_down_alt('\uf884'),
        faw_sort_amount_up_alt('\uf885'),
        faw_sort_numeric_down_alt('\uf886'),
        faw_sort_numeric_up_alt('\uf887'),
        faw_spell_check('\uf891'),
        faw_voicemail('\uf897');

        override val typeface: ITypeface by lazy { FontAwesome }
    }
}