/*
 * Copyright 2019 Mike Penz
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.mikepenz.iconics.typeface.library.ionicons

import com.mikepenz.iconics.typeface.IIcon
import com.mikepenz.iconics.typeface.ITypeface
import java.util.LinkedList

@Suppress("EnumEntryName")
object Ionicons : ITypeface {

    override val fontRes: Int
        get() = R.font.ionicons_font_v2_0_1_1

    override val characters: Map<String, Char> by lazy {
        Icon.values().associate { it.name to it.character }
    }

    override val mappingPrefix: String
        get() = "ion"

    override val fontName: String
        get() = "Ionicons"

    override val version: String
        get() = "2.0.1.1"

    override val iconCount: Int
        get() = characters.size

    override val icons: List<String>
        get() = characters.keys.toCollection(LinkedList())

    override val author: String
        get() = "Benjsperry"

    override val url: String
        get() = "http://ionicons.com/"

    override val description: String
        get() = "The premium icon font for Ionic Framework."

    override val license: String
        get() = "MIT Licensed"

    override val licenseUrl: String
        get() = "https://github.com/driftyco/ionicons/blob/master/LICENSE"

    override fun getIcon(key: String): IIcon = Icon.valueOf(key)

    enum class Icon constructor(override val character: Char) : IIcon {
        ion_alert('\uf101'),
        ion_alert_circled('\uf100'),
        ion_android_add('\uf2c7'),
        ion_android_add_circle('\uf359'),
        ion_android_alarm_clock('\uf35a'),
        ion_android_alert('\uf35b'),
        ion_android_apps('\uf35c'),
        ion_android_archive('\uf2c9'),
        ion_android_arrow_back('\uf2ca'),
        ion_android_arrow_down('\uf35d'),
        ion_android_arrow_dropdown('\uf35f'),
        ion_android_arrow_dropdown_circle('\uf35e'),
        ion_android_arrow_dropleft('\uf361'),
        ion_android_arrow_dropleft_circle('\uf360'),
        ion_android_arrow_dropright('\uf363'),
        ion_android_arrow_dropright_circle('\uf362'),
        ion_android_arrow_dropup('\uf365'),
        ion_android_arrow_dropup_circle('\uf364'),
        ion_android_arrow_forward('\uf30f'),
        ion_android_arrow_up('\uf366'),
        ion_android_attach('\uf367'),
        ion_android_bar('\uf368'),
        ion_android_bicycle('\uf369'),
        ion_android_boat('\uf36a'),
        ion_android_bookmark('\uf36b'),
        ion_android_bulb('\uf36c'),
        ion_android_bus('\uf36d'),
        ion_android_calendar('\uf2d1'),
        ion_android_call('\uf2d2'),
        ion_android_camera('\uf2d3'),
        ion_android_cancel('\uf36e'),
        ion_android_car('\uf36f'),
        ion_android_cart('\uf370'),
        ion_android_chat('\uf2d4'),
        ion_android_checkbox('\uf374'),
        ion_android_checkbox_blank('\uf371'),
        ion_android_checkbox_outline('\uf373'),
        ion_android_checkbox_outline_blank('\uf372'),
        ion_android_checkmark_circle('\uf375'),
        ion_android_clipboard('\uf376'),
        ion_android_close('\uf2d7'),
        ion_android_cloud('\uf37a'),
        ion_android_cloud_circle('\uf377'),
        ion_android_cloud_done('\uf378'),
        ion_android_cloud_outline('\uf379'),
        ion_android_color_palette('\uf37b'),
        ion_android_compass('\uf37c'),
        ion_android_contact('\uf2d8'),
        ion_android_contacts('\uf2d9'),
        ion_android_contract('\uf37d'),
        ion_android_create('\uf37e'),
        ion_android_delete('\uf37f'),
        ion_android_desktop('\uf380'),
        ion_android_document('\uf381'),
        ion_android_done('\uf383'),
        ion_android_done_all('\uf382'),
        ion_android_download('\uf2dd'),
        ion_android_drafts('\uf384'),
        ion_android_exit('\uf385'),
        ion_android_expand('\uf386'),
        ion_android_favorite('\uf388'),
        ion_android_favorite_outline('\uf387'),
        ion_android_film('\uf389'),
        ion_android_folder('\uf2e0'),
        ion_android_folder_open('\uf38a'),
        ion_android_funnel('\uf38b'),
        ion_android_globe('\uf38c'),
        ion_android_hand('\uf2e3'),
        ion_android_hangout('\uf38d'),
        ion_android_happy('\uf38e'),
        ion_android_home('\uf38f'),
        ion_android_image('\uf2e4'),
        ion_android_laptop('\uf390'),
        ion_android_list('\uf391'),
        ion_android_locate('\uf2e9'),
        ion_android_lock('\uf392'),
        ion_android_mail('\uf2eb'),
        ion_android_map('\uf393'),
        ion_android_menu('\uf394'),
        ion_android_microphone('\uf2ec'),
        ion_android_microphone_off('\uf395'),
        ion_android_more_horizontal('\uf396'),
        ion_android_more_vertical('\uf397'),
        ion_android_navigate('\uf398'),
        ion_android_notifications('\uf39b'),
        ion_android_notifications_none('\uf399'),
        ion_android_notifications_off('\uf39a'),
        ion_android_open('\uf39c'),
        ion_android_options('\uf39d'),
        ion_android_people('\uf39e'),
        ion_android_person('\uf3a0'),
        ion_android_person_add('\uf39f'),
        ion_android_phone_landscape('\uf3a1'),
        ion_android_phone_portrait('\uf3a2'),
        ion_android_pin('\uf3a3'),
        ion_android_plane('\uf3a4'),
        ion_android_playstore('\uf2f0'),
        ion_android_print('\uf3a5'),
        ion_android_radio_button_off('\uf3a6'),
        ion_android_radio_button_on('\uf3a7'),
        ion_android_refresh('\uf3a8'),
        ion_android_remove('\uf2f4'),
        ion_android_remove_circle('\uf3a9'),
        ion_android_restaurant('\uf3aa'),
        ion_android_sad('\uf3ab'),
        ion_android_search('\uf2f5'),
        ion_android_send('\uf2f6'),
        ion_android_settings('\uf2f7'),
        ion_android_share('\uf2f8'),
        ion_android_share_alt('\uf3ac'),
        ion_android_star('\uf2fc'),
        ion_android_star_half('\uf3ad'),
        ion_android_star_outline('\uf3ae'),
        ion_android_stopwatch('\uf2fd'),
        ion_android_subway('\uf3af'),
        ion_android_sunny('\uf3b0'),
        ion_android_sync('\uf3b1'),
        ion_android_textsms('\uf3b2'),
        ion_android_time('\uf3b3'),
        ion_android_train('\uf3b4'),
        ion_android_unlock('\uf3b5'),
        ion_android_upload('\uf3b6'),
        ion_android_volume_down('\uf3b7'),
        ion_android_volume_mute('\uf3b8'),
        ion_android_volume_off('\uf3b9'),
        ion_android_volume_up('\uf3ba'),
        ion_android_walk('\uf3bb'),
        ion_android_warning('\uf3bc'),
        ion_android_watch('\uf3bd'),
        ion_android_wifi('\uf305'),
        ion_aperture('\uf313'),
        ion_archive('\uf102'),
        ion_arrow_down_a('\uf103'),
        ion_arrow_down_b('\uf104'),
        ion_arrow_down_c('\uf105'),
        ion_arrow_expand('\uf25e'),
        ion_arrow_graph_down_left('\uf25f'),
        ion_arrow_graph_down_right('\uf260'),
        ion_arrow_graph_up_left('\uf261'),
        ion_arrow_graph_up_right('\uf262'),
        ion_arrow_left_a('\uf106'),
        ion_arrow_left_b('\uf107'),
        ion_arrow_left_c('\uf108'),
        ion_arrow_move('\uf263'),
        ion_arrow_resize('\uf264'),
        ion_arrow_return_left('\uf265'),
        ion_arrow_return_right('\uf266'),
        ion_arrow_right_a('\uf109'),
        ion_arrow_right_b('\uf10a'),
        ion_arrow_right_c('\uf10b'),
        ion_arrow_shrink('\uf267'),
        ion_arrow_swap('\uf268'),
        ion_arrow_up_a('\uf10c'),
        ion_arrow_up_b('\uf10d'),
        ion_arrow_up_c('\uf10e'),
        ion_asterisk('\uf314'),
        ion_at('\uf10f'),
        ion_backspace('\uf3bf'),
        ion_backspace_outline('\uf3be'),
        ion_bag('\uf110'),
        ion_battery_charging('\uf111'),
        ion_battery_empty('\uf112'),
        ion_battery_full('\uf113'),
        ion_battery_half('\uf114'),
        ion_battery_low('\uf115'),
        ion_beaker('\uf269'),
        ion_beer('\uf26a'),
        ion_bluetooth('\uf116'),
        ion_bonfire('\uf315'),
        ion_bookmark('\uf26b'),
        ion_bowtie('\uf3c0'),
        ion_briefcase('\uf26c'),
        ion_bug('\uf2be'),
        ion_calculator('\uf26d'),
        ion_calendar('\uf117'),
        ion_camera('\uf118'),
        ion_card('\uf119'),
        ion_cash('\uf316'),
        ion_chatbox('\uf11b'),
        ion_chatbox_working('\uf11a'),
        ion_chatboxes('\uf11c'),
        ion_chatbubble('\uf11e'),
        ion_chatbubble_working('\uf11d'),
        ion_chatbubbles('\uf11f'),
        ion_checkmark('\uf122'),
        ion_checkmark_circled('\uf120'),
        ion_checkmark_round('\uf121'),
        ion_chevron_down('\uf123'),
        ion_chevron_left('\uf124'),
        ion_chevron_right('\uf125'),
        ion_chevron_up('\uf126'),
        ion_clipboard('\uf127'),
        ion_clock('\uf26e'),
        ion_close('\uf12a'),
        ion_close_circled('\uf128'),
        ion_close_round('\uf129'),
        ion_closed_captioning('\uf317'),
        ion_cloud('\uf12b'),
        ion_code('\uf271'),
        ion_code_download('\uf26f'),
        ion_code_working('\uf270'),
        ion_coffee('\uf272'),
        ion_compass('\uf273'),
        ion_compose('\uf12c'),
        ion_connection_bars('\uf274'),
        ion_contrast('\uf275'),
        ion_crop('\uf3c1'),
        ion_cube('\uf318'),
        ion_disc('\uf12d'),
        ion_document('\uf12f'),
        ion_document_text('\uf12e'),
        ion_drag('\uf130'),
        ion_earth('\uf276'),
        ion_easel('\uf3c2'),
        ion_edit('\uf2bf'),
        ion_egg('\uf277'),
        ion_eject('\uf131'),
        ion_email('\uf132'),
        ion_email_unread('\uf3c3'),
        ion_erlenmeyer_flask('\uf3c5'),
        ion_erlenmeyer_flask_bubbles('\uf3c4'),
        ion_eye('\uf133'),
        ion_eye_disabled('\uf306'),
        ion_female('\uf278'),
        ion_filing('\uf134'),
        ion_film_marker('\uf135'),
        ion_fireball('\uf319'),
        ion_flag('\uf279'),
        ion_flame('\uf31a'),
        ion_flash('\uf137'),
        ion_flash_off('\uf136'),
        ion_folder('\uf139'),
        ion_fork('\uf27a'),
        ion_fork_repo('\uf2c0'),
        ion_forward('\uf13a'),
        ion_funnel('\uf31b'),
        ion_gear_a('\uf13d'),
        ion_gear_b('\uf13e'),
        ion_grid('\uf13f'),
        ion_hammer('\uf27b'),
        ion_happy('\uf31c'),
        ion_happy_outline('\uf3c6'),
        ion_headphone('\uf140'),
        ion_heart('\uf141'),
        ion_heart_broken('\uf31d'),
        ion_help('\uf143'),
        ion_help_buoy('\uf27c'),
        ion_help_circled('\uf142'),
        ion_home('\uf144'),
        ion_icecream('\uf27d'),
        ion_image('\uf147'),
        ion_images('\uf148'),
        ion_information('\uf14a'),
        ion_information_circled('\uf149'),
        ion_ionic('\uf14b'),
        ion_ios_alarm('\uf3c8'),
        ion_ios_alarm_outline('\uf3c7'),
        ion_ios_albums('\uf3ca'),
        ion_ios_albums_outline('\uf3c9'),
        ion_ios_americanfootball('\uf3cc'),
        ion_ios_americanfootball_outline('\uf3cb'),
        ion_ios_analytics('\uf3ce'),
        ion_ios_analytics_outline('\uf3cd'),
        ion_ios_arrow_back('\uf3cf'),
        ion_ios_arrow_down('\uf3d0'),
        ion_ios_arrow_forward('\uf3d1'),
        ion_ios_arrow_left('\uf3d2'),
        ion_ios_arrow_right('\uf3d3'),
        ion_ios_arrow_thin_down('\uf3d4'),
        ion_ios_arrow_thin_left('\uf3d5'),
        ion_ios_arrow_thin_right('\uf3d6'),
        ion_ios_arrow_thin_up('\uf3d7'),
        ion_ios_arrow_up('\uf3d8'),
        ion_ios_at('\uf3da'),
        ion_ios_at_outline('\uf3d9'),
        ion_ios_barcode('\uf3dc'),
        ion_ios_barcode_outline('\uf3db'),
        ion_ios_baseball('\uf3de'),
        ion_ios_baseball_outline('\uf3dd'),
        ion_ios_basketball('\uf3e0'),
        ion_ios_basketball_outline('\uf3df'),
        ion_ios_bell('\uf3e2'),
        ion_ios_bell_outline('\uf3e1'),
        ion_ios_body('\uf3e4'),
        ion_ios_body_outline('\uf3e3'),
        ion_ios_bolt('\uf3e6'),
        ion_ios_bolt_outline('\uf3e5'),
        ion_ios_book('\uf3e8'),
        ion_ios_book_outline('\uf3e7'),
        ion_ios_bookmarks('\uf3ea'),
        ion_ios_bookmarks_outline('\uf3e9'),
        ion_ios_box('\uf3ec'),
        ion_ios_box_outline('\uf3eb'),
        ion_ios_briefcase('\uf3ee'),
        ion_ios_briefcase_outline('\uf3ed'),
        ion_ios_browsers('\uf3f0'),
        ion_ios_browsers_outline('\uf3ef'),
        ion_ios_calculator('\uf3f2'),
        ion_ios_calculator_outline('\uf3f1'),
        ion_ios_calendar('\uf3f4'),
        ion_ios_calendar_outline('\uf3f3'),
        ion_ios_camera('\uf3f6'),
        ion_ios_camera_outline('\uf3f5'),
        ion_ios_cart('\uf3f8'),
        ion_ios_cart_outline('\uf3f7'),
        ion_ios_chatboxes('\uf3fa'),
        ion_ios_chatboxes_outline('\uf3f9'),
        ion_ios_chatbubble('\uf3fc'),
        ion_ios_chatbubble_outline('\uf3fb'),
        ion_ios_checkmark('\uf3ff'),
        ion_ios_checkmark_empty('\uf3fd'),
        ion_ios_checkmark_outline('\uf3fe'),
        ion_ios_circle_filled('\uf400'),
        ion_ios_circle_outline('\uf401'),
        ion_ios_clock('\uf403'),
        ion_ios_clock_outline('\uf402'),
        ion_ios_close('\uf406'),
        ion_ios_close_empty('\uf404'),
        ion_ios_close_outline('\uf405'),
        ion_ios_cloud('\uf40c'),
        ion_ios_cloud_download('\uf408'),
        ion_ios_cloud_download_outline('\uf407'),
        ion_ios_cloud_outline('\uf409'),
        ion_ios_cloud_upload('\uf40b'),
        ion_ios_cloud_upload_outline('\uf40a'),
        ion_ios_cloudy('\uf410'),
        ion_ios_cloudy_night('\uf40e'),
        ion_ios_cloudy_night_outline('\uf40d'),
        ion_ios_cloudy_outline('\uf40f'),
        ion_ios_cog('\uf412'),
        ion_ios_cog_outline('\uf411'),
        ion_ios_color_filter('\uf414'),
        ion_ios_color_filter_outline('\uf413'),
        ion_ios_color_wand('\uf416'),
        ion_ios_color_wand_outline('\uf415'),
        ion_ios_compose('\uf418'),
        ion_ios_compose_outline('\uf417'),
        ion_ios_contact('\uf41a'),
        ion_ios_contact_outline('\uf419'),
        ion_ios_copy('\uf41c'),
        ion_ios_copy_outline('\uf41b'),
        ion_ios_crop('\uf41e'),
        ion_ios_crop_strong('\uf41d'),
        ion_ios_download('\uf420'),
        ion_ios_download_outline('\uf41f'),
        ion_ios_drag('\uf421'),
        ion_ios_email('\uf423'),
        ion_ios_email_outline('\uf422'),
        ion_ios_eye('\uf425'),
        ion_ios_eye_outline('\uf424'),
        ion_ios_fastforward('\uf427'),
        ion_ios_fastforward_outline('\uf426'),
        ion_ios_filing('\uf429'),
        ion_ios_filing_outline('\uf428'),
        ion_ios_film('\uf42b'),
        ion_ios_film_outline('\uf42a'),
        ion_ios_flag('\uf42d'),
        ion_ios_flag_outline('\uf42c'),
        ion_ios_flame('\uf42f'),
        ion_ios_flame_outline('\uf42e'),
        ion_ios_flask('\uf431'),
        ion_ios_flask_outline('\uf430'),
        ion_ios_flower('\uf433'),
        ion_ios_flower_outline('\uf432'),
        ion_ios_folder('\uf435'),
        ion_ios_folder_outline('\uf434'),
        ion_ios_football('\uf437'),
        ion_ios_football_outline('\uf436'),
        ion_ios_game_controller_a('\uf439'),
        ion_ios_game_controller_a_outline('\uf438'),
        ion_ios_game_controller_b('\uf43b'),
        ion_ios_game_controller_b_outline('\uf43a'),
        ion_ios_gear('\uf43d'),
        ion_ios_gear_outline('\uf43c'),
        ion_ios_glasses('\uf43f'),
        ion_ios_glasses_outline('\uf43e'),
        ion_ios_grid_view('\uf441'),
        ion_ios_grid_view_outline('\uf440'),
        ion_ios_heart('\uf443'),
        ion_ios_heart_outline('\uf442'),
        ion_ios_help('\uf446'),
        ion_ios_help_empty('\uf444'),
        ion_ios_help_outline('\uf445'),
        ion_ios_home('\uf448'),
        ion_ios_home_outline('\uf447'),
        ion_ios_infinite('\uf44a'),
        ion_ios_infinite_outline('\uf449'),
        ion_ios_information('\uf44d'),
        ion_ios_information_empty('\uf44b'),
        ion_ios_information_outline('\uf44c'),
        ion_ios_ionic_outline('\uf44e'),
        ion_ios_keypad('\uf450'),
        ion_ios_keypad_outline('\uf44f'),
        ion_ios_lightbulb('\uf452'),
        ion_ios_lightbulb_outline('\uf451'),
        ion_ios_list('\uf454'),
        ion_ios_list_outline('\uf453'),
        ion_ios_location('\uf456'),
        ion_ios_location_outline('\uf455'),
        ion_ios_locked('\uf458'),
        ion_ios_locked_outline('\uf457'),
        ion_ios_loop('\uf45a'),
        ion_ios_loop_strong('\uf459'),
        ion_ios_medical('\uf45c'),
        ion_ios_medical_outline('\uf45b'),
        ion_ios_medkit('\uf45e'),
        ion_ios_medkit_outline('\uf45d'),
        ion_ios_mic('\uf461'),
        ion_ios_mic_off('\uf45f'),
        ion_ios_mic_outline('\uf460'),
        ion_ios_minus('\uf464'),
        ion_ios_minus_empty('\uf462'),
        ion_ios_minus_outline('\uf463'),
        ion_ios_monitor('\uf466'),
        ion_ios_monitor_outline('\uf465'),
        ion_ios_moon('\uf468'),
        ion_ios_moon_outline('\uf467'),
        ion_ios_more('\uf46a'),
        ion_ios_more_outline('\uf469'),
        ion_ios_musical_note('\uf46b'),
        ion_ios_musical_notes('\uf46c'),
        ion_ios_navigate('\uf46e'),
        ion_ios_navigate_outline('\uf46d'),
        ion_ios_nutrition('\uf470'),
        ion_ios_nutrition_outline('\uf46f'),
        ion_ios_paper('\uf472'),
        ion_ios_paper_outline('\uf471'),
        ion_ios_paperplane('\uf474'),
        ion_ios_paperplane_outline('\uf473'),
        ion_ios_partlysunny('\uf476'),
        ion_ios_partlysunny_outline('\uf475'),
        ion_ios_pause('\uf478'),
        ion_ios_pause_outline('\uf477'),
        ion_ios_paw('\uf47a'),
        ion_ios_paw_outline('\uf479'),
        ion_ios_people('\uf47c'),
        ion_ios_people_outline('\uf47b'),
        ion_ios_person('\uf47e'),
        ion_ios_person_outline('\uf47d'),
        ion_ios_personadd('\uf480'),
        ion_ios_personadd_outline('\uf47f'),
        ion_ios_photos('\uf482'),
        ion_ios_photos_outline('\uf481'),
        ion_ios_pie('\uf484'),
        ion_ios_pie_outline('\uf483'),
        ion_ios_pint('\uf486'),
        ion_ios_pint_outline('\uf485'),
        ion_ios_play('\uf488'),
        ion_ios_play_outline('\uf487'),
        ion_ios_plus('\uf48b'),
        ion_ios_plus_empty('\uf489'),
        ion_ios_plus_outline('\uf48a'),
        ion_ios_pricetag('\uf48d'),
        ion_ios_pricetag_outline('\uf48c'),
        ion_ios_pricetags('\uf48f'),
        ion_ios_pricetags_outline('\uf48e'),
        ion_ios_printer('\uf491'),
        ion_ios_printer_outline('\uf490'),
        ion_ios_pulse('\uf493'),
        ion_ios_pulse_strong('\uf492'),
        ion_ios_rainy('\uf495'),
        ion_ios_rainy_outline('\uf494'),
        ion_ios_recording('\uf497'),
        ion_ios_recording_outline('\uf496'),
        ion_ios_redo('\uf499'),
        ion_ios_redo_outline('\uf498'),
        ion_ios_refresh('\uf49c'),
        ion_ios_refresh_empty('\uf49a'),
        ion_ios_refresh_outline('\uf49b'),
        ion_ios_reload('\uf49d'),
        ion_ios_reverse_camera('\uf49f'),
        ion_ios_reverse_camera_outline('\uf49e'),
        ion_ios_rewind('\uf4a1'),
        ion_ios_rewind_outline('\uf4a0'),
        ion_ios_rose('\uf4a3'),
        ion_ios_rose_outline('\uf4a2'),
        ion_ios_search('\uf4a5'),
        ion_ios_search_strong('\uf4a4'),
        ion_ios_settings('\uf4a7'),
        ion_ios_settings_strong('\uf4a6'),
        ion_ios_shuffle('\uf4a9'),
        ion_ios_shuffle_strong('\uf4a8'),
        ion_ios_skipbackward('\uf4ab'),
        ion_ios_skipbackward_outline('\uf4aa'),
        ion_ios_skipforward('\uf4ad'),
        ion_ios_skipforward_outline('\uf4ac'),
        ion_ios_snowy('\uf4ae'),
        ion_ios_speedometer('\uf4b0'),
        ion_ios_speedometer_outline('\uf4af'),
        ion_ios_star('\uf4b3'),
        ion_ios_star_half('\uf4b1'),
        ion_ios_star_outline('\uf4b2'),
        ion_ios_stopwatch('\uf4b5'),
        ion_ios_stopwatch_outline('\uf4b4'),
        ion_ios_sunny('\uf4b7'),
        ion_ios_sunny_outline('\uf4b6'),
        ion_ios_telephone('\uf4b9'),
        ion_ios_telephone_outline('\uf4b8'),
        ion_ios_tennisball('\uf4bb'),
        ion_ios_tennisball_outline('\uf4ba'),
        ion_ios_thunderstorm('\uf4bd'),
        ion_ios_thunderstorm_outline('\uf4bc'),
        ion_ios_time('\uf4bf'),
        ion_ios_time_outline('\uf4be'),
        ion_ios_timer('\uf4c1'),
        ion_ios_timer_outline('\uf4c0'),
        ion_ios_toggle('\uf4c3'),
        ion_ios_toggle_outline('\uf4c2'),
        ion_ios_trash('\uf4c5'),
        ion_ios_trash_outline('\uf4c4'),
        ion_ios_undo('\uf4c7'),
        ion_ios_undo_outline('\uf4c6'),
        ion_ios_unlocked('\uf4c9'),
        ion_ios_unlocked_outline('\uf4c8'),
        ion_ios_upload('\uf4cb'),
        ion_ios_upload_outline('\uf4ca'),
        ion_ios_videocam('\uf4cd'),
        ion_ios_videocam_outline('\uf4cc'),
        ion_ios_volume_high('\uf4ce'),
        ion_ios_volume_low('\uf4cf'),
        ion_ios_wineglass('\uf4d1'),
        ion_ios_wineglass_outline('\uf4d0'),
        ion_ios_world('\uf4d3'),
        ion_ios_world_outline('\uf4d2'),
        ion_ipad('\uf1f9'),
        ion_iphone('\uf1fa'),
        ion_ipod('\uf1fb'),
        ion_jet('\uf295'),
        ion_key('\uf296'),
        ion_knife('\uf297'),
        ion_laptop('\uf1fc'),
        ion_leaf('\uf1fd'),
        ion_levels('\uf298'),
        ion_lightbulb('\uf299'),
        ion_link('\uf1fe'),
        ion_load_a('\uf29a'),
        ion_load_b('\uf29b'),
        ion_load_c('\uf29c'),
        ion_load_d('\uf29d'),
        ion_location('\uf1ff'),
        ion_lock_combination('\uf4d4'),
        ion_locked('\uf200'),
        ion_log_in('\uf29e'),
        ion_log_out('\uf29f'),
        ion_loop('\uf201'),
        ion_magnet('\uf2a0'),
        ion_male('\uf2a1'),
        ion_man('\uf202'),
        ion_map('\uf203'),
        ion_medkit('\uf2a2'),
        ion_merge('\uf33f'),
        ion_mic_a('\uf204'),
        ion_mic_b('\uf205'),
        ion_mic_c('\uf206'),
        ion_minus('\uf209'),
        ion_minus_circled('\uf207'),
        ion_minus_round('\uf208'),
        ion_model_s('\uf2c1'),
        ion_monitor('\uf20a'),
        ion_more('\uf20b'),
        ion_mouse('\uf340'),
        ion_music_note('\uf20c'),
        ion_navicon('\uf20e'),
        ion_navicon_round('\uf20d'),
        ion_navigate('\uf2a3'),
        ion_network('\uf341'),
        ion_no_smoking('\uf2c2'),
        ion_nuclear('\uf2a4'),
        ion_outlet('\uf342'),
        ion_paintbrush('\uf4d5'),
        ion_paintbucket('\uf4d6'),
        ion_paper_airplane('\uf2c3'),
        ion_paperclip('\uf20f'),
        ion_pause('\uf210'),
        ion_person('\uf213'),
        ion_person_add('\uf211'),
        ion_person_stalker('\uf212'),
        ion_pie_graph('\uf2a5'),
        ion_pin('\uf2a6'),
        ion_pinpoint('\uf2a7'),
        ion_pizza('\uf2a8'),
        ion_plane('\uf214'),
        ion_planet('\uf343'),
        ion_play('\uf215'),
        ion_playstation('\uf30a'),
        ion_plus('\uf218'),
        ion_plus_circled('\uf216'),
        ion_plus_round('\uf217'),
        ion_podium('\uf344'),
        ion_pound('\uf219'),
        ion_power('\uf2a9'),
        ion_pricetag('\uf2aa'),
        ion_pricetags('\uf2ab'),
        ion_printer('\uf21a'),
        ion_pull_request('\uf345'),
        ion_qr_scanner('\uf346'),
        ion_quote('\uf347'),
        ion_radio_waves('\uf2ac'),
        ion_record('\uf21b'),
        ion_refresh('\uf21c'),
        ion_reply('\uf21e'),
        ion_reply_all('\uf21d'),
        ion_ribbon_a('\uf348'),
        ion_ribbon_b('\uf349'),
        ion_sad('\uf34a'),
        ion_sad_outline('\uf4d7'),
        ion_scissors('\uf34b'),
        ion_search('\uf21f'),
        ion_settings('\uf2ad'),
        ion_share('\uf220'),
        ion_shuffle('\uf221'),
        ion_skip_backward('\uf222'),
        ion_skip_forward('\uf223'),
        ion_social_android('\uf225'),
        ion_social_android_outline('\uf224'),
        ion_social_angular('\uf4d9'),
        ion_social_angular_outline('\uf4d8'),
        ion_social_apple('\uf227'),
        ion_social_apple_outline('\uf226'),
        ion_social_bitcoin('\uf2af'),
        ion_social_bitcoin_outline('\uf2ae'),
        ion_social_buffer('\uf229'),
        ion_social_buffer_outline('\uf228'),
        ion_social_chrome('\uf4db'),
        ion_social_chrome_outline('\uf4da'),
        ion_social_codepen('\uf4dd'),
        ion_social_codepen_outline('\uf4dc'),
        ion_social_css3('\uf4df'),
        ion_social_css3_outline('\uf4de'),
        ion_social_designernews('\uf22b'),
        ion_social_designernews_outline('\uf22a'),
        ion_social_dribbble('\uf22d'),
        ion_social_dribbble_outline('\uf22c'),
        ion_social_dropbox('\uf22f'),
        ion_social_dropbox_outline('\uf22e'),
        ion_social_euro('\uf4e1'),
        ion_social_euro_outline('\uf4e0'),
        ion_social_facebook('\uf231'),
        ion_social_facebook_outline('\uf230'),
        ion_social_foursquare('\uf34d'),
        ion_social_foursquare_outline('\uf34c'),
        ion_social_freebsd_devil('\uf2c4'),
        ion_social_github('\uf233'),
        ion_social_github_outline('\uf232'),
        ion_social_google('\uf34f'),
        ion_social_google_outline('\uf34e'),
        ion_social_googleplus('\uf235'),
        ion_social_googleplus_outline('\uf234'),
        ion_social_hackernews('\uf237'),
        ion_social_hackernews_outline('\uf236'),
        ion_social_html5('\uf4e3'),
        ion_social_html5_outline('\uf4e2'),
        ion_social_instagram('\uf351'),
        ion_social_instagram_outline('\uf350'),
        ion_social_javascript('\uf4e5'),
        ion_social_javascript_outline('\uf4e4'),
        ion_social_linkedin('\uf239'),
        ion_social_linkedin_outline('\uf238'),
        ion_social_markdown('\uf4e6'),
        ion_social_nodejs('\uf4e7'),
        ion_social_octocat('\uf4e8'),
        ion_social_pinterest('\uf2b1'),
        ion_social_pinterest_outline('\uf2b0'),
        ion_social_python('\uf4e9'),
        ion_social_reddit('\uf23b'),
        ion_social_reddit_outline('\uf23a'),
        ion_social_rss('\uf23d'),
        ion_social_rss_outline('\uf23c'),
        ion_social_sass('\uf4ea'),
        ion_social_skype('\uf23f'),
        ion_social_skype_outline('\uf23e'),
        ion_social_snapchat('\uf4ec'),
        ion_social_snapchat_outline('\uf4eb'),
        ion_social_tumblr('\uf241'),
        ion_social_tumblr_outline('\uf240'),
        ion_social_tux('\uf2c5'),
        ion_social_twitch('\uf4ee'),
        ion_social_twitch_outline('\uf4ed'),
        ion_social_twitter('\uf243'),
        ion_social_twitter_outline('\uf242'),
        ion_social_usd('\uf353'),
        ion_social_usd_outline('\uf352'),
        ion_social_vimeo('\uf245'),
        ion_social_vimeo_outline('\uf244'),
        ion_social_whatsapp('\uf4f0'),
        ion_social_whatsapp_outline('\uf4ef'),
        ion_social_windows('\uf247'),
        ion_social_windows_outline('\uf246'),
        ion_social_wordpress('\uf249'),
        ion_social_wordpress_outline('\uf248'),
        ion_social_yahoo('\uf24b'),
        ion_social_yahoo_outline('\uf24a'),
        ion_social_yen('\uf4f2'),
        ion_social_yen_outline('\uf4f1'),
        ion_social_youtube('\uf24d'),
        ion_social_youtube_outline('\uf24c'),
        ion_soup_can('\uf4f4'),
        ion_soup_can_outline('\uf4f3'),
        ion_speakerphone('\uf2b2'),
        ion_speedometer('\uf2b3'),
        ion_spoon('\uf2b4'),
        ion_star('\uf24e'),
        ion_stats_bars('\uf2b5'),
        ion_steam('\uf30b'),
        ion_stop('\uf24f'),
        ion_thermometer('\uf2b6'),
        ion_thumbsdown('\uf250'),
        ion_thumbsup('\uf251'),
        ion_toggle('\uf355'),
        ion_toggle_filled('\uf354'),
        ion_transgender('\uf4f5'),
        ion_trash_a('\uf252'),
        ion_trash_b('\uf253'),
        ion_trophy('\uf356'),
        ion_tshirt('\uf4f7'),
        ion_tshirt_outline('\uf4f6'),
        ion_umbrella('\uf2b7'),
        ion_university('\uf357'),
        ion_unlocked('\uf254'),
        ion_upload('\uf255'),
        ion_usb('\uf2b8'),
        ion_videocamera('\uf256'),
        ion_volume_high('\uf257'),
        ion_volume_low('\uf258'),
        ion_volume_medium('\uf259'),
        ion_volume_mute('\uf25a'),
        ion_wand('\uf358'),
        ion_waterdrop('\uf25b'),
        ion_wifi('\uf25c'),
        ion_wineglass('\uf2b9'),
        ion_woman('\uf25d'),
        ion_wrench('\uf2ba'),
        ion_xbox('\uf30c');

        override val typeface: ITypeface by lazy { Ionicons }
    }
}
