/*
 * Copyright 2014 Mike Penz
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.mikepenz.iconics.typeface.library.community.material

import com.mikepenz.iconics.typeface.IIcon
import com.mikepenz.iconics.typeface.ITypeface
import com.mikepenz.iconics.typeface.library.community.R
import java.util.LinkedList

@Suppress("EnumEntryName")
object CommunityMaterial : ITypeface {

    override val fontRes: Int
        get() = R.font.community_material_font_v3_7_95_1

    override val characters: Map<String, Char> by lazy {
        mutableMapOf<String, Char>().apply {
            Icon.values().associateTo(this) { it.name to it.character }
            Icon2.values().associateTo(this) { it.name to it.character }
        }
    }

    override val mappingPrefix: String
        get() = "cmd"

    override val fontName: String
        get() = "Community Material Design"

    override val version: String
        get() = "3.7.95.3"

    override val iconCount: Int
        get() = characters.size

    override val icons: List<String>
        get() = characters.keys.toCollection(LinkedList())

    override val author: String
        get() = "Templarian / Community / Google"

    override val url: String
        get() = "http://materialdesignicons.com/"

    override val description: String
        get() = "Material Design Icons are the official open-source icons featured in the Google " +
                "Material Design specification."

    override val license: String
        get() = "Templates - Free, Community Icons - SIL Open Font License 1.1, Google Material " +
                "Design Icons: Attribution 4.0 International"

    override val licenseUrl: String
        get() = "https://raw.githubusercontent.com/Templarian/MaterialDesign/master/license.txt"

    override fun getIcon(key: String): IIcon {
        try {
            return Icon.valueOf(key)
        } catch (ex: Exception) {
            // ignore error, if not in 1st set, it has to be in the second
        }
        return Icon2.valueOf(key)
    }

    enum class Icon constructor(override val character: Char) : IIcon {
        cmd_ab_testing('\uf86d'),
        cmd_access_point('\uf870'),
        cmd_access_point_network('\uf86f'),
        cmd_access_point_network_off('\uf86e'),
        cmd_account('\uf8bf'),
        cmd_account_alert('\uf872'),
        cmd_account_alert_outline('\uf871'),
        cmd_account_arrow_left('\uf874'),
        cmd_account_arrow_left_outline('\uf873'),
        cmd_account_arrow_right('\uf876'),
        cmd_account_arrow_right_outline('\uf875'),
        cmd_account_badge('\uf87c'),
        cmd_account_badge_alert('\uf878'),
        cmd_account_badge_alert_outline('\uf877'),
        cmd_account_badge_horizontal('\uf87a'),
        cmd_account_badge_horizontal_outline('\uf879'),
        cmd_account_badge_outline('\uf87b'),
        cmd_account_box('\uf880'),
        cmd_account_box_multiple('\uf87e'),
        cmd_account_box_multiple_outline('\uf87d'),
        cmd_account_box_outline('\uf87f'),
        cmd_account_cancel('\uf882'),
        cmd_account_cancel_outline('\uf881'),
        cmd_account_card_details('\uf884'),
        cmd_account_card_details_outline('\uf883'),
        cmd_account_cash('\uf886'),
        cmd_account_cash_outline('\uf885'),
        cmd_account_check('\uf888'),
        cmd_account_check_outline('\uf887'),
        cmd_account_child('\uf88b'),
        cmd_account_child_circle('\uf889'),
        cmd_account_child_outline('\uf88a'),
        cmd_account_circle('\uf88d'),
        cmd_account_circle_outline('\uf88c'),
        cmd_account_clock('\uf88f'),
        cmd_account_clock_outline('\uf88e'),
        cmd_account_convert('\uf890'),
        cmd_account_details('\uf891'),
        cmd_account_edit('\uf893'),
        cmd_account_edit_outline('\uf892'),
        cmd_account_group('\uf895'),
        cmd_account_group_outline('\uf894'),
        cmd_account_heart('\uf897'),
        cmd_account_heart_outline('\uf896'),
        cmd_account_key('\uf899'),
        cmd_account_key_outline('\uf898'),
        cmd_account_lock('\uf89b'),
        cmd_account_lock_outline('\uf89a'),
        cmd_account_minus('\uf89d'),
        cmd_account_minus_outline('\uf89c'),
        cmd_account_multiple('\uf8a7'),
        cmd_account_multiple_check('\uf89f'),
        cmd_account_multiple_check_outline('\uf89e'),
        cmd_account_multiple_minus('\uf8a1'),
        cmd_account_multiple_minus_outline('\uf8a0'),
        cmd_account_multiple_outline('\uf8a2'),
        cmd_account_multiple_plus('\uf8a4'),
        cmd_account_multiple_plus_outline('\uf8a3'),
        cmd_account_multiple_remove('\uf8a6'),
        cmd_account_multiple_remove_outline('\uf8a5'),
        cmd_account_network('\uf8a9'),
        cmd_account_network_outline('\uf8a8'),
        cmd_account_off('\uf8ab'),
        cmd_account_off_outline('\uf8aa'),
        cmd_account_outline('\uf8ac'),
        cmd_account_plus('\uf8ae'),
        cmd_account_plus_outline('\uf8ad'),
        cmd_account_question('\uf8b0'),
        cmd_account_question_outline('\uf8af'),
        cmd_account_remove('\uf8b2'),
        cmd_account_remove_outline('\uf8b1'),
        cmd_account_search('\uf8b4'),
        cmd_account_search_outline('\uf8b3'),
        cmd_account_settings('\uf8b6'),
        cmd_account_settings_outline('\uf8b5'),
        cmd_account_star('\uf8b8'),
        cmd_account_star_outline('\uf8b7'),
        cmd_account_supervisor('\uf8bb'),
        cmd_account_supervisor_circle('\uf8b9'),
        cmd_account_supervisor_outline('\uf8ba'),
        cmd_account_switch('\uf8bc'),
        cmd_account_tie('\uf8be'),
        cmd_account_tie_outline('\uf8bd'),
        cmd_accusoft('\uf8c0'),
        cmd_adchoices('\uf8c1'),
        cmd_adjust('\uf8c2'),
        cmd_adobe('\uf8c4'),
        cmd_adobe_acrobat('\uf8c3'),
        cmd_air_conditioner('\uf8c5'),
        cmd_air_filter('\uf8c6'),
        cmd_air_horn('\uf8c7'),
        cmd_air_humidifier('\uf8c8'),
        cmd_air_purifier('\uf8c9'),
        cmd_airbag('\uf8ca'),
        cmd_airballoon('\uf8cc'),
        cmd_airballoon_outline('\uf8cb'),
        cmd_airplane('\uf8d0'),
        cmd_airplane_landing('\uf8cd'),
        cmd_airplane_off('\uf8ce'),
        cmd_airplane_takeoff('\uf8cf'),
        cmd_airplay('\uf8d1'),
        cmd_airport('\uf8d2'),
        cmd_alarm('\uf8dd'),
        cmd_alarm_bell('\uf8d3'),
        cmd_alarm_check('\uf8d4'),
        cmd_alarm_light('\uf8d6'),
        cmd_alarm_light_outline('\uf8d5'),
        cmd_alarm_multiple('\uf8d7'),
        cmd_alarm_note('\uf8d9'),
        cmd_alarm_note_off('\uf8d8'),
        cmd_alarm_off('\uf8da'),
        cmd_alarm_plus('\uf8db'),
        cmd_alarm_snooze('\uf8dc'),
        cmd_album('\uf8de'),
        cmd_alert('\uf8ee'),
        cmd_alert_box('\uf8e0'),
        cmd_alert_box_outline('\uf8df'),
        cmd_alert_circle('\uf8e4'),
        cmd_alert_circle_check('\uf8e2'),
        cmd_alert_circle_check_outline('\uf8e1'),
        cmd_alert_circle_outline('\uf8e3'),
        cmd_alert_decagram('\uf8e6'),
        cmd_alert_decagram_outline('\uf8e5'),
        cmd_alert_octagon('\uf8e8'),
        cmd_alert_octagon_outline('\uf8e7'),
        cmd_alert_octagram('\uf8ea'),
        cmd_alert_octagram_outline('\uf8e9'),
        cmd_alert_outline('\uf8eb'),
        cmd_alert_rhombus('\uf8ed'),
        cmd_alert_rhombus_outline('\uf8ec'),
        cmd_alien('\uf8f0'),
        cmd_alien_outline('\uf8ef'),
        cmd_align_horizontal_center('\uf8f1'),
        cmd_align_horizontal_left('\uf8f2'),
        cmd_align_horizontal_right('\uf8f3'),
        cmd_align_vertical_bottom('\uf8f4'),
        cmd_align_vertical_center('\uf8f5'),
        cmd_align_vertical_top('\uf8f6'),
        cmd_all_inclusive('\uf8f7'),
        cmd_allergy('\uf8f8'),
        cmd_alpha('\uf97b'),
        cmd_alpha_a('\uf8fd'),
        cmd_alpha_a_box('\uf8fa'),
        cmd_alpha_a_box_outline('\uf8f9'),
        cmd_alpha_a_circle('\uf8fc'),
        cmd_alpha_a_circle_outline('\uf8fb'),
        cmd_alpha_b('\uf902'),
        cmd_alpha_b_box('\uf8ff'),
        cmd_alpha_b_box_outline('\uf8fe'),
        cmd_alpha_b_circle('\uf901'),
        cmd_alpha_b_circle_outline('\uf900'),
        cmd_alpha_c('\uf907'),
        cmd_alpha_c_box('\uf904'),
        cmd_alpha_c_box_outline('\uf903'),
        cmd_alpha_c_circle('\uf906'),
        cmd_alpha_c_circle_outline('\uf905'),
        cmd_alpha_d('\uf90c'),
        cmd_alpha_d_box('\uf909'),
        cmd_alpha_d_box_outline('\uf908'),
        cmd_alpha_d_circle('\uf90b'),
        cmd_alpha_d_circle_outline('\uf90a'),
        cmd_alpha_e('\uf911'),
        cmd_alpha_e_box('\uf90e'),
        cmd_alpha_e_box_outline('\uf90d'),
        cmd_alpha_e_circle('\uf910'),
        cmd_alpha_e_circle_outline('\uf90f'),
        cmd_alpha_f('\uf916'),
        cmd_alpha_f_box('\uf913'),
        cmd_alpha_f_box_outline('\uf912'),
        cmd_alpha_f_circle('\uf915'),
        cmd_alpha_f_circle_outline('\uf914'),
        cmd_alpha_g('\uf91b'),
        cmd_alpha_g_box('\uf918'),
        cmd_alpha_g_box_outline('\uf917'),
        cmd_alpha_g_circle('\uf91a'),
        cmd_alpha_g_circle_outline('\uf919'),
        cmd_alpha_h('\uf920'),
        cmd_alpha_h_box('\uf91d'),
        cmd_alpha_h_box_outline('\uf91c'),
        cmd_alpha_h_circle('\uf91f'),
        cmd_alpha_h_circle_outline('\uf91e'),
        cmd_alpha_i('\uf925'),
        cmd_alpha_i_box('\uf922'),
        cmd_alpha_i_box_outline('\uf921'),
        cmd_alpha_i_circle('\uf924'),
        cmd_alpha_i_circle_outline('\uf923'),
        cmd_alpha_j('\uf92a'),
        cmd_alpha_j_box('\uf927'),
        cmd_alpha_j_box_outline('\uf926'),
        cmd_alpha_j_circle('\uf929'),
        cmd_alpha_j_circle_outline('\uf928'),
        cmd_alpha_k('\uf92f'),
        cmd_alpha_k_box('\uf92c'),
        cmd_alpha_k_box_outline('\uf92b'),
        cmd_alpha_k_circle('\uf92e'),
        cmd_alpha_k_circle_outline('\uf92d'),
        cmd_alpha_l('\uf934'),
        cmd_alpha_l_box('\uf931'),
        cmd_alpha_l_box_outline('\uf930'),
        cmd_alpha_l_circle('\uf933'),
        cmd_alpha_l_circle_outline('\uf932'),
        cmd_alpha_m('\uf939'),
        cmd_alpha_m_box('\uf936'),
        cmd_alpha_m_box_outline('\uf935'),
        cmd_alpha_m_circle('\uf938'),
        cmd_alpha_m_circle_outline('\uf937'),
        cmd_alpha_n('\uf93e'),
        cmd_alpha_n_box('\uf93b'),
        cmd_alpha_n_box_outline('\uf93a'),
        cmd_alpha_n_circle('\uf93d'),
        cmd_alpha_n_circle_outline('\uf93c'),
        cmd_alpha_o('\uf943'),
        cmd_alpha_o_box('\uf940'),
        cmd_alpha_o_box_outline('\uf93f'),
        cmd_alpha_o_circle('\uf942'),
        cmd_alpha_o_circle_outline('\uf941'),
        cmd_alpha_p('\uf948'),
        cmd_alpha_p_box('\uf945'),
        cmd_alpha_p_box_outline('\uf944'),
        cmd_alpha_p_circle('\uf947'),
        cmd_alpha_p_circle_outline('\uf946'),
        cmd_alpha_q('\uf94d'),
        cmd_alpha_q_box('\uf94a'),
        cmd_alpha_q_box_outline('\uf949'),
        cmd_alpha_q_circle('\uf94c'),
        cmd_alpha_q_circle_outline('\uf94b'),
        cmd_alpha_r('\uf952'),
        cmd_alpha_r_box('\uf94f'),
        cmd_alpha_r_box_outline('\uf94e'),
        cmd_alpha_r_circle('\uf951'),
        cmd_alpha_r_circle_outline('\uf950'),
        cmd_alpha_s('\uf957'),
        cmd_alpha_s_box('\uf954'),
        cmd_alpha_s_box_outline('\uf953'),
        cmd_alpha_s_circle('\uf956'),
        cmd_alpha_s_circle_outline('\uf955'),
        cmd_alpha_t('\uf95c'),
        cmd_alpha_t_box('\uf959'),
        cmd_alpha_t_box_outline('\uf958'),
        cmd_alpha_t_circle('\uf95b'),
        cmd_alpha_t_circle_outline('\uf95a'),
        cmd_alpha_u('\uf961'),
        cmd_alpha_u_box('\uf95e'),
        cmd_alpha_u_box_outline('\uf95d'),
        cmd_alpha_u_circle('\uf960'),
        cmd_alpha_u_circle_outline('\uf95f'),
        cmd_alpha_v('\uf966'),
        cmd_alpha_v_box('\uf963'),
        cmd_alpha_v_box_outline('\uf962'),
        cmd_alpha_v_circle('\uf965'),
        cmd_alpha_v_circle_outline('\uf964'),
        cmd_alpha_w('\uf96b'),
        cmd_alpha_w_box('\uf968'),
        cmd_alpha_w_box_outline('\uf967'),
        cmd_alpha_w_circle('\uf96a'),
        cmd_alpha_w_circle_outline('\uf969'),
        cmd_alpha_x('\uf970'),
        cmd_alpha_x_box('\uf96d'),
        cmd_alpha_x_box_outline('\uf96c'),
        cmd_alpha_x_circle('\uf96f'),
        cmd_alpha_x_circle_outline('\uf96e'),
        cmd_alpha_y('\uf975'),
        cmd_alpha_y_box('\uf972'),
        cmd_alpha_y_box_outline('\uf971'),
        cmd_alpha_y_circle('\uf974'),
        cmd_alpha_y_circle_outline('\uf973'),
        cmd_alpha_z('\uf97a'),
        cmd_alpha_z_box('\uf977'),
        cmd_alpha_z_box_outline('\uf976'),
        cmd_alpha_z_circle('\uf979'),
        cmd_alpha_z_circle_outline('\uf978'),
        cmd_alphabetical('\uf97f'),
        cmd_alphabetical_off('\uf97c'),
        cmd_alphabetical_variant('\uf97e'),
        cmd_alphabetical_variant_off('\uf97d'),
        cmd_altimeter('\uf980'),
        cmd_amazon('\uf983'),
        cmd_amazon_alexa('\uf981'),
        cmd_amazon_drive('\uf982'),
        cmd_ambulance('\uf984'),
        cmd_ammunition('\uf985'),
        cmd_ampersand('\uf986'),
        cmd_amplifier('\uf988'),
        cmd_amplifier_off('\uf987'),
        cmd_anchor('\uf989'),
        cmd_android('\uf98f'),
        cmd_android_auto('\uf98a'),
        cmd_android_debug_bridge('\uf98b'),
        cmd_android_head('\uf98c'),
        cmd_android_messages('\uf98d'),
        cmd_android_studio('\uf98e'),
        cmd_angle_acute('\uf990'),
        cmd_angle_obtuse('\uf991'),
        cmd_angle_right('\uf992'),
        cmd_angular('\uf993'),
        cmd_angularjs('\uf994'),
        cmd_animation('\uf998'),
        cmd_animation_outline('\uf995'),
        cmd_animation_play('\uf997'),
        cmd_animation_play_outline('\uf996'),
        cmd_ansible('\uf999'),
        cmd_antenna('\uf99a'),
        cmd_anvil('\uf99b'),
        cmd_apache_kafka('\uf99c'),
        cmd_api('\uf99e'),
        cmd_api_off('\uf99d'),
        cmd_apple('\uf9a8'),
        cmd_apple_finder('\uf99f'),
        cmd_apple_icloud('\uf9a0'),
        cmd_apple_ios('\uf9a1'),
        cmd_apple_keyboard_caps('\uf9a2'),
        cmd_apple_keyboard_command('\uf9a3'),
        cmd_apple_keyboard_control('\uf9a4'),
        cmd_apple_keyboard_option('\uf9a5'),
        cmd_apple_keyboard_shift('\uf9a6'),
        cmd_apple_safari('\uf9a7'),
        cmd_application('\uf9ab'),
        cmd_application_export('\uf9a9'),
        cmd_application_import('\uf9aa'),
        cmd_approximately_equal('\uf9ad'),
        cmd_approximately_equal_box('\uf9ac'),
        cmd_apps('\uf9af'),
        cmd_apps_box('\uf9ae'),
        cmd_arch('\uf9b0'),
        cmd_archive('\uf9b6'),
        cmd_archive_arrow_down('\uf9b2'),
        cmd_archive_arrow_down_outline('\uf9b1'),
        cmd_archive_arrow_up('\uf9b4'),
        cmd_archive_arrow_up_outline('\uf9b3'),
        cmd_archive_outline('\uf9b5'),
        cmd_arm_flex('\uf9b8'),
        cmd_arm_flex_outline('\uf9b7'),
        cmd_arrange_bring_forward('\uf9b9'),
        cmd_arrange_bring_to_front('\uf9ba'),
        cmd_arrange_send_backward('\uf9bb'),
        cmd_arrange_send_to_back('\uf9bc'),
        cmd_arrow_all('\uf9bd'),
        cmd_arrow_bottom_left('\uf9c0'),
        cmd_arrow_bottom_left_bold_outline('\uf9be'),
        cmd_arrow_bottom_left_thick('\uf9bf'),
        cmd_arrow_bottom_right('\uf9c3'),
        cmd_arrow_bottom_right_bold_outline('\uf9c1'),
        cmd_arrow_bottom_right_thick('\uf9c2'),
        cmd_arrow_collapse('\uf9cb'),
        cmd_arrow_collapse_all('\uf9c4'),
        cmd_arrow_collapse_down('\uf9c5'),
        cmd_arrow_collapse_horizontal('\uf9c6'),
        cmd_arrow_collapse_left('\uf9c7'),
        cmd_arrow_collapse_right('\uf9c8'),
        cmd_arrow_collapse_up('\uf9c9'),
        cmd_arrow_collapse_vertical('\uf9ca'),
        cmd_arrow_decision('\uf9cf'),
        cmd_arrow_decision_auto('\uf9cd'),
        cmd_arrow_decision_auto_outline('\uf9cc'),
        cmd_arrow_decision_outline('\uf9ce'),
        cmd_arrow_down('\uf9dd'),
        cmd_arrow_down_bold('\uf9d6'),
        cmd_arrow_down_bold_box('\uf9d1'),
        cmd_arrow_down_bold_box_outline('\uf9d0'),
        cmd_arrow_down_bold_circle('\uf9d3'),
        cmd_arrow_down_bold_circle_outline('\uf9d2'),
        cmd_arrow_down_bold_hexagon_outline('\uf9d4'),
        cmd_arrow_down_bold_outline('\uf9d5'),
        cmd_arrow_down_box('\uf9d7'),
        cmd_arrow_down_circle('\uf9d9'),
        cmd_arrow_down_circle_outline('\uf9d8'),
        cmd_arrow_down_drop_circle('\uf9db'),
        cmd_arrow_down_drop_circle_outline('\uf9da'),
        cmd_arrow_down_thick('\uf9dc'),
        cmd_arrow_expand('\uf9e5'),
        cmd_arrow_expand_all('\uf9de'),
        cmd_arrow_expand_down('\uf9df'),
        cmd_arrow_expand_horizontal('\uf9e0'),
        cmd_arrow_expand_left('\uf9e1'),
        cmd_arrow_expand_right('\uf9e2'),
        cmd_arrow_expand_up('\uf9e3'),
        cmd_arrow_expand_vertical('\uf9e4'),
        cmd_arrow_horizontal_lock('\uf9e6'),
        cmd_arrow_left('\uf9f7'),
        cmd_arrow_left_bold('\uf9ed'),
        cmd_arrow_left_bold_box('\uf9e8'),
        cmd_arrow_left_bold_box_outline('\uf9e7'),
        cmd_arrow_left_bold_circle('\uf9ea'),
        cmd_arrow_left_bold_circle_outline('\uf9e9'),
        cmd_arrow_left_bold_hexagon_outline('\uf9eb'),
        cmd_arrow_left_bold_outline('\uf9ec'),
        cmd_arrow_left_box('\uf9ee'),
        cmd_arrow_left_circle('\uf9f0'),
        cmd_arrow_left_circle_outline('\uf9ef'),
        cmd_arrow_left_drop_circle('\uf9f2'),
        cmd_arrow_left_drop_circle_outline('\uf9f1'),
        cmd_arrow_left_right('\uf9f5'),
        cmd_arrow_left_right_bold('\uf9f4'),
        cmd_arrow_left_right_bold_outline('\uf9f3'),
        cmd_arrow_left_thick('\uf9f6'),
        cmd_arrow_right('\ufa05'),
        cmd_arrow_right_bold('\uf9fe'),
        cmd_arrow_right_bold_box('\uf9f9'),
        cmd_arrow_right_bold_box_outline('\uf9f8'),
        cmd_arrow_right_bold_circle('\uf9fb'),
        cmd_arrow_right_bold_circle_outline('\uf9fa'),
        cmd_arrow_right_bold_hexagon_outline('\uf9fc'),
        cmd_arrow_right_bold_outline('\uf9fd'),
        cmd_arrow_right_box('\uf9ff'),
        cmd_arrow_right_circle('\ufa01'),
        cmd_arrow_right_circle_outline('\ufa00'),
        cmd_arrow_right_drop_circle('\ufa03'),
        cmd_arrow_right_drop_circle_outline('\ufa02'),
        cmd_arrow_right_thick('\ufa04'),
        cmd_arrow_split_horizontal('\ufa06'),
        cmd_arrow_split_vertical('\ufa07'),
        cmd_arrow_top_left('\ufa0c'),
        cmd_arrow_top_left_bold_outline('\ufa08'),
        cmd_arrow_top_left_bottom_right('\ufa0a'),
        cmd_arrow_top_left_bottom_right_bold('\ufa09'),
        cmd_arrow_top_left_thick('\ufa0b'),
        cmd_arrow_top_right('\ufa11'),
        cmd_arrow_top_right_bold_outline('\ufa0d'),
        cmd_arrow_top_right_bottom_left('\ufa0f'),
        cmd_arrow_top_right_bottom_left_bold('\ufa0e'),
        cmd_arrow_top_right_thick('\ufa10'),
        cmd_arrow_up('\ufa22'),
        cmd_arrow_up_bold('\ufa18'),
        cmd_arrow_up_bold_box('\ufa13'),
        cmd_arrow_up_bold_box_outline('\ufa12'),
        cmd_arrow_up_bold_circle('\ufa15'),
        cmd_arrow_up_bold_circle_outline('\ufa14'),
        cmd_arrow_up_bold_hexagon_outline('\ufa16'),
        cmd_arrow_up_bold_outline('\ufa17'),
        cmd_arrow_up_box('\ufa19'),
        cmd_arrow_up_circle('\ufa1b'),
        cmd_arrow_up_circle_outline('\ufa1a'),
        cmd_arrow_up_down('\ufa1e'),
        cmd_arrow_up_down_bold('\ufa1d'),
        cmd_arrow_up_down_bold_outline('\ufa1c'),
        cmd_arrow_up_drop_circle('\ufa20'),
        cmd_arrow_up_drop_circle_outline('\ufa1f'),
        cmd_arrow_up_thick('\ufa21'),
        cmd_arrow_vertical_lock('\ufa23'),
        cmd_artist('\ufa25'),
        cmd_artist_outline('\ufa24'),
        cmd_artstation('\ufa26'),
        cmd_aspect_ratio('\ufa27'),
        cmd_assistant('\ufa28'),
        cmd_asterisk('\ufa29'),
        cmd_at('\ufa2a'),
        cmd_atlassian('\ufa2b'),
        cmd_atm('\ufa2c'),
        cmd_atom('\ufa2e'),
        cmd_atom_variant('\ufa2d'),
        cmd_attachment('\ufa2f'),
        cmd_audio_video('\ufa31'),
        cmd_audio_video_off('\ufa30'),
        cmd_audiobook('\ufa32'),
        cmd_augmented_reality('\ufa33'),
        cmd_auto_fix('\ufa34'),
        cmd_auto_upload('\ufa35'),
        cmd_autorenew('\ufa36'),
        cmd_av_timer('\ufa37'),
        cmd_aws('\ufa38'),
        cmd_axe('\ufa39'),
        cmd_axis('\ufa4a'),
        cmd_axis_arrow('\ufa3b'),
        cmd_axis_arrow_lock('\ufa3a'),
        cmd_axis_lock('\ufa3c'),
        cmd_axis_x_arrow('\ufa3e'),
        cmd_axis_x_arrow_lock('\ufa3d'),
        cmd_axis_x_rotate_clockwise('\ufa3f'),
        cmd_axis_x_rotate_counterclockwise('\ufa40'),
        cmd_axis_x_y_arrow_lock('\ufa41'),
        cmd_axis_y_arrow('\ufa43'),
        cmd_axis_y_arrow_lock('\ufa42'),
        cmd_axis_y_rotate_clockwise('\ufa44'),
        cmd_axis_y_rotate_counterclockwise('\ufa45'),
        cmd_axis_z_arrow('\ufa47'),
        cmd_axis_z_arrow_lock('\ufa46'),
        cmd_axis_z_rotate_clockwise('\ufa48'),
        cmd_axis_z_rotate_counterclockwise('\ufa49'),
        cmd_azure('\ufa4c'),
        cmd_azure_devops('\ufa4b'),
        cmd_babel('\ufa4d'),
        cmd_baby('\ufa54'),
        cmd_baby_bottle('\ufa4f'),
        cmd_baby_bottle_outline('\ufa4e'),
        cmd_baby_carriage('\ufa51'),
        cmd_baby_carriage_off('\ufa50'),
        cmd_baby_face('\ufa53'),
        cmd_baby_face_outline('\ufa52'),
        cmd_backburger('\ufa55'),
        cmd_backspace('\ufa59'),
        cmd_backspace_outline('\ufa56'),
        cmd_backspace_reverse('\ufa58'),
        cmd_backspace_reverse_outline('\ufa57'),
        cmd_backup_restore('\ufa5a'),
        cmd_bacteria('\ufa5c'),
        cmd_bacteria_outline('\ufa5b'),
        cmd_badminton('\ufa5d'),
        cmd_bag_carry_on('\ufa60'),
        cmd_bag_carry_on_check('\ufa5e'),
        cmd_bag_carry_on_off('\ufa5f'),
        cmd_bag_checked('\ufa61'),
        cmd_bag_personal('\ufa65'),
        cmd_bag_personal_off('\ufa63'),
        cmd_bag_personal_off_outline('\ufa62'),
        cmd_bag_personal_outline('\ufa64'),
        cmd_baguette('\ufa66'),
        cmd_balloon('\ufa67'),
        cmd_ballot('\ufa6b'),
        cmd_ballot_outline('\ufa68'),
        cmd_ballot_recount('\ufa6a'),
        cmd_ballot_recount_outline('\ufa69'),
        cmd_bandage('\ufa6c'),
        cmd_bandcamp('\ufa6d'),
        cmd_bank('\ufa75'),
        cmd_bank_minus('\ufa6e'),
        cmd_bank_outline('\ufa6f'),
        cmd_bank_plus('\ufa70'),
        cmd_bank_remove('\ufa71'),
        cmd_bank_transfer('\ufa74'),
        cmd_bank_transfer_in('\ufa72'),
        cmd_bank_transfer_out('\ufa73'),
        cmd_barcode('\ufa78'),
        cmd_barcode_off('\ufa76'),
        cmd_barcode_scan('\ufa77'),
        cmd_barley('\ufa7a'),
        cmd_barley_off('\ufa79'),
        cmd_barn('\ufa7b'),
        cmd_barrel('\ufa7c'),
        cmd_baseball('\ufa7e'),
        cmd_baseball_bat('\ufa7d'),
        cmd_basecamp('\ufa7f'),
        cmd_bash('\ufa80'),
        cmd_basket('\ufa84'),
        cmd_basket_fill('\ufa81'),
        cmd_basket_outline('\ufa82'),
        cmd_basket_unfill('\ufa83'),
        cmd_basketball('\ufa87'),
        cmd_basketball_hoop('\ufa86'),
        cmd_basketball_hoop_outline('\ufa85'),
        cmd_bat('\ufa88'),
        cmd_battery('\ufacb'),
        cmd_battery_10('\ufa8a'),
        cmd_battery_10_bluetooth('\ufa89'),
        cmd_battery_20('\ufa8c'),
        cmd_battery_20_bluetooth('\ufa8b'),
        cmd_battery_30('\ufa8e'),
        cmd_battery_30_bluetooth('\ufa8d'),
        cmd_battery_40('\ufa90'),
        cmd_battery_40_bluetooth('\ufa8f'),
        cmd_battery_50('\ufa92'),
        cmd_battery_50_bluetooth('\ufa91'),
        cmd_battery_60('\ufa94'),
        cmd_battery_60_bluetooth('\ufa93'),
        cmd_battery_70('\ufa96'),
        cmd_battery_70_bluetooth('\ufa95'),
        cmd_battery_80('\ufa98'),
        cmd_battery_80_bluetooth('\ufa97'),
        cmd_battery_90('\ufa9a'),
        cmd_battery_90_bluetooth('\ufa99'),
        cmd_battery_alert('\ufa9e'),
        cmd_battery_alert_bluetooth('\ufa9b'),
        cmd_battery_alert_variant('\ufa9d'),
        cmd_battery_alert_variant_outline('\ufa9c'),
        cmd_battery_bluetooth('\ufaa0'),
        cmd_battery_bluetooth_variant('\ufa9f'),
        cmd_battery_charging('\ufabb'),
        cmd_battery_charging_10('\ufaa1'),
        cmd_battery_charging_100('\ufaaa'),
        cmd_battery_charging_20('\ufaa2'),
        cmd_battery_charging_30('\ufaa3'),
        cmd_battery_charging_40('\ufaa4'),
        cmd_battery_charging_50('\ufaa5'),
        cmd_battery_charging_60('\ufaa6'),
        cmd_battery_charging_70('\ufaa7'),
        cmd_battery_charging_80('\ufaa8'),
        cmd_battery_charging_90('\ufaa9'),
        cmd_battery_charging_high('\ufaab'),
        cmd_battery_charging_low('\ufaac'),
        cmd_battery_charging_medium('\ufaad'),
        cmd_battery_charging_outline('\ufaae'),
        cmd_battery_charging_wireless('\ufaba'),
        cmd_battery_charging_wireless_10('\ufaaf'),
        cmd_battery_charging_wireless_20('\ufab0'),
        cmd_battery_charging_wireless_30('\ufab1'),
        cmd_battery_charging_wireless_40('\ufab2'),
        cmd_battery_charging_wireless_50('\ufab3'),
        cmd_battery_charging_wireless_60('\ufab4'),
        cmd_battery_charging_wireless_70('\ufab5'),
        cmd_battery_charging_wireless_80('\ufab6'),
        cmd_battery_charging_wireless_90('\ufab7'),
        cmd_battery_charging_wireless_alert('\ufab8'),
        cmd_battery_charging_wireless_outline('\ufab9'),
        cmd_battery_heart('\ufabe'),
        cmd_battery_heart_outline('\ufabc'),
        cmd_battery_heart_variant('\ufabd'),
        cmd_battery_high('\ufabf'),
        cmd_battery_low('\ufac0'),
        cmd_battery_medium('\ufac1'),
        cmd_battery_minus('\ufac2'),
        cmd_battery_negative('\ufac3'),
        cmd_battery_off('\ufac5'),
        cmd_battery_off_outline('\ufac4'),
        cmd_battery_outline('\ufac6'),
        cmd_battery_plus('\ufac7'),
        cmd_battery_positive('\ufac8'),
        cmd_battery_unknown('\ufaca'),
        cmd_battery_unknown_bluetooth('\ufac9'),
        cmd_battlenet('\ufacc'),
        cmd_beach('\ufacd'),
        cmd_beaker('\ufadb'),
        cmd_beaker_alert('\ufacf'),
        cmd_beaker_alert_outline('\uface'),
        cmd_beaker_check('\ufad1'),
        cmd_beaker_check_outline('\ufad0'),
        cmd_beaker_minus('\ufad3'),
        cmd_beaker_minus_outline('\ufad2'),
        cmd_beaker_outline('\ufad4'),
        cmd_beaker_plus('\ufad6'),
        cmd_beaker_plus_outline('\ufad5'),
        cmd_beaker_question('\ufad8'),
        cmd_beaker_question_outline('\ufad7'),
        cmd_beaker_remove('\ufada'),
        cmd_beaker_remove_outline('\ufad9'),
        cmd_beats('\ufadc'),
        cmd_bed_double('\ufade'),
        cmd_bed_double_outline('\ufadd'),
        cmd_bed_empty('\ufadf'),
        cmd_bed_king('\ufae1'),
        cmd_bed_king_outline('\ufae0'),
        cmd_bed_queen('\ufae3'),
        cmd_bed_queen_outline('\ufae2'),
        cmd_bed_single('\ufae5'),
        cmd_bed_single_outline('\ufae4'),
        cmd_bee('\ufae7'),
        cmd_bee_flower('\ufae6'),
        cmd_beehive_outline('\ufae8'),
        cmd_beer('\ufae9'),
        cmd_behance('\ufaea'),
        cmd_bell('\ufafa'),
        cmd_bell_alert('\ufaec'),
        cmd_bell_alert_outline('\ufaeb'),
        cmd_bell_check('\ufaee'),
        cmd_bell_check_outline('\ufaed'),
        cmd_bell_circle('\ufaf0'),
        cmd_bell_circle_outline('\ufaef'),
        cmd_bell_off('\ufaf2'),
        cmd_bell_off_outline('\ufaf1'),
        cmd_bell_outline('\ufaf3'),
        cmd_bell_plus('\ufaf5'),
        cmd_bell_plus_outline('\ufaf4'),
        cmd_bell_ring('\ufaf7'),
        cmd_bell_ring_outline('\ufaf6'),
        cmd_bell_sleep('\ufaf9'),
        cmd_bell_sleep_outline('\ufaf8'),
        cmd_beta('\ufafb'),
        cmd_betamax('\ufafc'),
        cmd_biathlon('\ufafd'),
        cmd_bible('\ufafe'),
        cmd_bicycle('\ufb00'),
        cmd_bicycle_basket('\ufaff'),
        cmd_bike('\ufb02'),
        cmd_bike_fast('\ufb01'),
        cmd_billboard('\ufb03'),
        cmd_billiards('\ufb05'),
        cmd_billiards_rack('\ufb04'),
        cmd_bing('\ufb06'),
        cmd_binoculars('\ufb07'),
        cmd_bio('\ufb08'),
        cmd_biohazard('\ufb09'),
        cmd_bitbucket('\ufb0a'),
        cmd_bitcoin('\ufb0b'),
        cmd_black_mesa('\ufb0c'),
        cmd_blackberry('\ufb0d'),
        cmd_blender('\ufb0f'),
        cmd_blender_software('\ufb0e'),
        cmd_blinds('\ufb11'),
        cmd_blinds_open('\ufb10'),
        cmd_block_helper('\ufb12'),
        cmd_blogger('\ufb13'),
        cmd_blood_bag('\ufb14'),
        cmd_bluetooth('\ufb1a'),
        cmd_bluetooth_audio('\ufb15'),
        cmd_bluetooth_connect('\ufb16'),
        cmd_bluetooth_off('\ufb17'),
        cmd_bluetooth_settings('\ufb18'),
        cmd_bluetooth_transfer('\ufb19'),
        cmd_blur('\ufb1e'),
        cmd_blur_linear('\ufb1b'),
        cmd_blur_off('\ufb1c'),
        cmd_blur_radial('\ufb1d'),
        cmd_bolnisi_cross('\ufb1f'),
        cmd_bolt('\ufb20'),
        cmd_bomb('\ufb22'),
        cmd_bomb_off('\ufb21'),
        cmd_bone('\ufb23'),
        cmd_book('\ufb39'),
        cmd_book_information_variant('\ufb24'),
        cmd_book_lock('\ufb26'),
        cmd_book_lock_open('\ufb25'),
        cmd_book_minus('\ufb28'),
        cmd_book_minus_multiple('\ufb27'),
        cmd_book_multiple('\ufb29'),
        cmd_book_open('\ufb2d'),
        cmd_book_open_outline('\ufb2a'),
        cmd_book_open_page_variant('\ufb2b'),
        cmd_book_open_variant('\ufb2c'),
        cmd_book_outline('\ufb2e'),
        cmd_book_play('\ufb30'),
        cmd_book_play_outline('\ufb2f'),
        cmd_book_plus('\ufb32'),
        cmd_book_plus_multiple('\ufb31'),
        cmd_book_remove('\ufb34'),
        cmd_book_remove_multiple('\ufb33'),
        cmd_book_search('\ufb36'),
        cmd_book_search_outline('\ufb35'),
        cmd_book_variant('\ufb38'),
        cmd_book_variant_multiple('\ufb37'),
        cmd_bookmark('\ufb46'),
        cmd_bookmark_check('\ufb3a'),
        cmd_bookmark_minus('\ufb3c'),
        cmd_bookmark_minus_outline('\ufb3b'),
        cmd_bookmark_multiple('\ufb3e'),
        cmd_bookmark_multiple_outline('\ufb3d'),
        cmd_bookmark_music('\ufb3f'),
        cmd_bookmark_off('\ufb41'),
        cmd_bookmark_off_outline('\ufb40'),
        cmd_bookmark_outline('\ufb42'),
        cmd_bookmark_plus('\ufb44'),
        cmd_bookmark_plus_outline('\ufb43'),
        cmd_bookmark_remove('\ufb45'),
        cmd_bookshelf('\ufb47'),
        cmd_boom_gate('\ufb4f'),
        cmd_boom_gate_alert('\ufb49'),
        cmd_boom_gate_alert_outline('\ufb48'),
        cmd_boom_gate_down('\ufb4b'),
        cmd_boom_gate_down_outline('\ufb4a'),
        cmd_boom_gate_outline('\ufb4c'),
        cmd_boom_gate_up('\ufb4e'),
        cmd_boom_gate_up_outline('\ufb4d'),
        cmd_boombox('\ufb50'),
        cmd_boomerang('\ufb51'),
        cmd_bootstrap('\ufb52'),
        cmd_border_all('\ufb54'),
        cmd_border_all_variant('\ufb53'),
        cmd_border_bottom('\ufb56'),
        cmd_border_bottom_variant('\ufb55'),
        cmd_border_color('\ufb57'),
        cmd_border_horizontal('\ufb58'),
        cmd_border_inside('\ufb59'),
        cmd_border_left('\ufb5b'),
        cmd_border_left_variant('\ufb5a'),
        cmd_border_none('\ufb5d'),
        cmd_border_none_variant('\ufb5c'),
        cmd_border_outside('\ufb5e'),
        cmd_border_right('\ufb60'),
        cmd_border_right_variant('\ufb5f'),
        cmd_border_style('\ufb61'),
        cmd_border_top('\ufb63'),
        cmd_border_top_variant('\ufb62'),
        cmd_border_vertical('\ufb64'),
        cmd_bottle_soda('\ufb67'),
        cmd_bottle_soda_classic('\ufb65'),
        cmd_bottle_soda_outline('\ufb66'),
        cmd_bottle_tonic('\ufb6d'),
        cmd_bottle_tonic_outline('\ufb68'),
        cmd_bottle_tonic_plus('\ufb6a'),
        cmd_bottle_tonic_plus_outline('\ufb69'),
        cmd_bottle_tonic_skull('\ufb6c'),
        cmd_bottle_tonic_skull_outline('\ufb6b'),
        cmd_bottle_wine('\ufb6e'),
        cmd_bow_tie('\ufb6f'),
        cmd_bowl('\ufb70'),
        cmd_bowling('\ufb71'),
        cmd_box('\ufb74'),
        cmd_box_cutter('\ufb72'),
        cmd_box_shadow('\ufb73'),
        cmd_boxing_glove('\ufb75'),
        cmd_braille('\ufb76'),
        cmd_brain('\ufb77'),
        cmd_bread_slice('\ufb79'),
        cmd_bread_slice_outline('\ufb78'),
        cmd_bridge('\ufb7a'),
        cmd_briefcase('\ufb8f'),
        cmd_briefcase_account('\ufb7c'),
        cmd_briefcase_account_outline('\ufb7b'),
        cmd_briefcase_check('\ufb7d'),
        cmd_briefcase_clock('\ufb7f'),
        cmd_briefcase_clock_outline('\ufb7e'),
        cmd_briefcase_download('\ufb81'),
        cmd_briefcase_download_outline('\ufb80'),
        cmd_briefcase_edit('\ufb83'),
        cmd_briefcase_edit_outline('\ufb82'),
        cmd_briefcase_minus('\ufb85'),
        cmd_briefcase_minus_outline('\ufb84'),
        cmd_briefcase_outline('\ufb86'),
        cmd_briefcase_plus('\ufb88'),
        cmd_briefcase_plus_outline('\ufb87'),
        cmd_briefcase_remove('\ufb8a'),
        cmd_briefcase_remove_outline('\ufb89'),
        cmd_briefcase_search('\ufb8c'),
        cmd_briefcase_search_outline('\ufb8b'),
        cmd_briefcase_upload('\ufb8e'),
        cmd_briefcase_upload_outline('\ufb8d'),
        cmd_brightness_1('\ufb90'),
        cmd_brightness_2('\ufb91'),
        cmd_brightness_3('\ufb92'),
        cmd_brightness_4('\ufb93'),
        cmd_brightness_5('\ufb94'),
        cmd_brightness_6('\ufb95'),
        cmd_brightness_7('\ufb96'),
        cmd_brightness_auto('\ufb97'),
        cmd_brightness_percent('\ufb98'),
        cmd_broom('\ufb99'),
        cmd_brush('\ufb9a'),
        cmd_buddhism('\ufb9b'),
        cmd_buffer('\ufb9c'),
        cmd_bug('\ufba0'),
        cmd_bug_check('\ufb9e'),
        cmd_bug_check_outline('\ufb9d'),
        cmd_bug_outline('\ufb9f'),
        cmd_bugle('\ufba1'),
        cmd_bulldozer('\ufba2'),
        cmd_bullet('\ufba3'),
        cmd_bulletin_board('\ufba4'),
        cmd_bullhorn('\ufba6'),
        cmd_bullhorn_outline('\ufba5'),
        cmd_bullseye('\ufba8'),
        cmd_bullseye_arrow('\ufba7'),
        cmd_bus('\ufbb5'),
        cmd_bus_alert('\ufba9'),
        cmd_bus_articulated_end('\ufbaa'),
        cmd_bus_articulated_front('\ufbab'),
        cmd_bus_clock('\ufbac'),
        cmd_bus_double_decker('\ufbad'),
        cmd_bus_marker('\ufbae'),
        cmd_bus_multiple('\ufbaf'),
        cmd_bus_school('\ufbb0'),
        cmd_bus_side('\ufbb1'),
        cmd_bus_stop('\ufbb4'),
        cmd_bus_stop_covered('\ufbb2'),
        cmd_bus_stop_uncovered('\ufbb3'),
        cmd_cached('\ufbb6'),
        cmd_cactus('\ufbb7'),
        cmd_cake('\ufbba'),
        cmd_cake_layered('\ufbb8'),
        cmd_cake_variant('\ufbb9'),
        cmd_calculator('\ufbbc'),
        cmd_calculator_variant('\ufbbb'),
        cmd_calendar('\ufbe4'),
        cmd_calendar_account('\ufbbe'),
        cmd_calendar_account_outline('\ufbbd'),
        cmd_calendar_alert('\ufbbf'),
        cmd_calendar_arrow_left('\ufbc0'),
        cmd_calendar_arrow_right('\ufbc1'),
        cmd_calendar_blank('\ufbc4'),
        cmd_calendar_blank_multiple('\ufbc2'),
        cmd_calendar_blank_outline('\ufbc3'),
        cmd_calendar_check('\ufbc6'),
        cmd_calendar_check_outline('\ufbc5'),
        cmd_calendar_clock('\ufbc7'),
        cmd_calendar_edit('\ufbc8'),
        cmd_calendar_export('\ufbc9'),
        cmd_calendar_heart('\ufbca'),
        cmd_calendar_import('\ufbcb'),
        cmd_calendar_minus('\ufbcc'),
        cmd_calendar_month('\ufbce'),
        cmd_calendar_month_outline('\ufbcd'),
        cmd_calendar_multiple('\ufbd0'),
        cmd_calendar_multiple_check('\ufbcf'),
        cmd_calendar_multiselect('\ufbd1'),
        cmd_calendar_outline('\ufbd2'),
        cmd_calendar_plus('\ufbd3'),
        cmd_calendar_question('\ufbd4'),
        cmd_calendar_range('\ufbd6'),
        cmd_calendar_range_outline('\ufbd5'),
        cmd_calendar_remove('\ufbd8'),
        cmd_calendar_remove_outline('\ufbd7'),
        cmd_calendar_repeat('\ufbda'),
        cmd_calendar_repeat_outline('\ufbd9'),
        cmd_calendar_search('\ufbdb'),
        cmd_calendar_star('\ufbdc'),
        cmd_calendar_text('\ufbde'),
        cmd_calendar_text_outline('\ufbdd'),
        cmd_calendar_today('\ufbdf'),
        cmd_calendar_week('\ufbe1'),
        cmd_calendar_week_begin('\ufbe0'),
        cmd_calendar_weekend('\ufbe3'),
        cmd_calendar_weekend_outline('\ufbe2'),
        cmd_call_made('\uf256'),
        cmd_call_merge('\uf257'),
        cmd_call_missed('\uf258'),
        cmd_call_received('\uf259'),
        cmd_call_split('\uf25a'),
        cmd_camcorder('\uf25e'),
        cmd_camcorder_box('\uf25c'),
        cmd_camcorder_box_off('\uf25b'),
        cmd_camcorder_off('\uf25d'),
        cmd_camera('\uf27a'),
        cmd_camera_account('\uf25f'),
        cmd_camera_burst('\uf260'),
        cmd_camera_control('\uf261'),
        cmd_camera_enhance('\uf263'),
        cmd_camera_enhance_outline('\uf262'),
        cmd_camera_front('\uf265'),
        cmd_camera_front_variant('\uf264'),
        cmd_camera_gopro('\uf266'),
        cmd_camera_image('\uf267'),
        cmd_camera_iris('\uf268'),
        cmd_camera_metering_center('\uf269'),
        cmd_camera_metering_matrix('\uf26a'),
        cmd_camera_metering_partial('\uf26b'),
        cmd_camera_metering_spot('\uf26c'),
        cmd_camera_off('\uf26d'),
        cmd_camera_outline('\uf26e'),
        cmd_camera_party_mode('\uf26f'),
        cmd_camera_plus('\uf271'),
        cmd_camera_plus_outline('\uf270'),
        cmd_camera_rear('\uf273'),
        cmd_camera_rear_variant('\uf272'),
        cmd_camera_retake('\uf275'),
        cmd_camera_retake_outline('\uf274'),
        cmd_camera_switch('\uf276'),
        cmd_camera_timer('\uf277'),
        cmd_camera_wireless('\uf279'),
        cmd_camera_wireless_outline('\uf278'),
        cmd_campfire('\uf27b'),
        cmd_cancel('\uf27c'),
        cmd_candle('\uf27d'),
        cmd_candycane('\uf27e'),
        cmd_cannabis('\uf27f'),
        cmd_caps_lock('\uf280'),
        cmd_car('\uf2ae'),
        cmd_car_2_plus('\uf281'),
        cmd_car_3_plus('\uf282'),
        cmd_car_back('\uf283'),
        cmd_car_battery('\uf284'),
        cmd_car_brake_abs('\uf285'),
        cmd_car_brake_alert('\uf286'),
        cmd_car_brake_hold('\uf287'),
        cmd_car_brake_parking('\uf288'),
        cmd_car_brake_retarder('\uf289'),
        cmd_car_child_seat('\uf28a'),
        cmd_car_clutch('\uf28b'),
        cmd_car_connected('\uf28c'),
        cmd_car_convertible('\uf28d'),
        cmd_car_coolant_level('\uf28e'),
        cmd_car_cruise_control('\uf28f'),
        cmd_car_defrost_front('\uf290'),
        cmd_car_defrost_rear('\uf291'),
        cmd_car_door('\uf293'),
        cmd_car_door_lock('\uf292'),
        cmd_car_electric('\uf294'),
        cmd_car_esp('\uf295'),
        cmd_car_estate('\uf296'),
        cmd_car_hatchback('\uf297'),
        cmd_car_info('\uf298'),
        cmd_car_key('\uf299'),
        cmd_car_light_dimmed('\uf29a'),
        cmd_car_light_fog('\uf29b'),
        cmd_car_light_high('\uf29c'),
        cmd_car_limousine('\uf29d'),
        cmd_car_multiple('\uf29e'),
        cmd_car_off('\uf29f'),
        cmd_car_parking_lights('\uf2a0'),
        cmd_car_pickup('\uf2a1'),
        cmd_car_seat('\uf2a4'),
        cmd_car_seat_cooler('\uf2a2'),
        cmd_car_seat_heater('\uf2a3'),
        cmd_car_shift_pattern('\uf2a5'),
        cmd_car_side('\uf2a6'),
        cmd_car_sports('\uf2a7'),
        cmd_car_tire_alert('\uf2a8'),
        cmd_car_traction_control('\uf2a9'),
        cmd_car_turbocharger('\uf2aa'),
        cmd_car_wash('\uf2ab'),
        cmd_car_windshield('\uf2ad'),
        cmd_car_windshield_outline('\uf2ac'),
        cmd_caravan('\uf2af'),
        cmd_card('\uf2bd'),
        cmd_card_bulleted('\uf2b5'),
        cmd_card_bulleted_off('\uf2b1'),
        cmd_card_bulleted_off_outline('\uf2b0'),
        cmd_card_bulleted_outline('\uf2b2'),
        cmd_card_bulleted_settings('\uf2b4'),
        cmd_card_bulleted_settings_outline('\uf2b3'),
        cmd_card_outline('\uf2b6'),
        cmd_card_plus('\uf2b8'),
        cmd_card_plus_outline('\uf2b7'),
        cmd_card_search('\uf2ba'),
        cmd_card_search_outline('\uf2b9'),
        cmd_card_text('\uf2bc'),
        cmd_card_text_outline('\uf2bb'),
        cmd_cards('\uf2c6'),
        cmd_cards_club('\uf2be'),
        cmd_cards_diamond('\uf2c0'),
        cmd_cards_diamond_outline('\uf2bf'),
        cmd_cards_heart('\uf2c1'),
        cmd_cards_outline('\uf2c2'),
        cmd_cards_playing_outline('\uf2c3'),
        cmd_cards_spade('\uf2c4'),
        cmd_cards_variant('\uf2c5'),
        cmd_carrot('\uf2c7'),
        cmd_cart('\uf2d0'),
        cmd_cart_arrow_down('\uf2c8'),
        cmd_cart_arrow_right('\uf2c9'),
        cmd_cart_arrow_up('\uf2ca'),
        cmd_cart_minus('\uf2cb'),
        cmd_cart_off('\uf2cc'),
        cmd_cart_outline('\uf2cd'),
        cmd_cart_plus('\uf2ce'),
        cmd_cart_remove('\uf2cf'),
        cmd_case_sensitive_alt('\uf2d1'),
        cmd_cash('\uf2dc'),
        cmd_cash_100('\uf2d2'),
        cmd_cash_marker('\uf2d3'),
        cmd_cash_minus('\uf2d4'),
        cmd_cash_multiple('\uf2d5'),
        cmd_cash_plus('\uf2d6'),
        cmd_cash_refund('\uf2d7'),
        cmd_cash_register('\uf2d8'),
        cmd_cash_remove('\uf2d9'),
        cmd_cash_usd('\uf2db'),
        cmd_cash_usd_outline('\uf2da'),
        cmd_cassette('\uf2dd'),
        cmd_cast('\uf2e2'),
        cmd_cast_audio('\uf2de'),
        cmd_cast_connected('\uf2df'),
        cmd_cast_education('\uf2e0'),
        cmd_cast_off('\uf2e1'),
        cmd_castle('\uf2e3'),
        cmd_cat('\uf2e4'),
        cmd_cctv('\uf2e5'),
        cmd_ceiling_light('\uf2e6'),
        cmd_cellphone('\uf2fe'),
        cmd_cellphone_android('\uf2e7'),
        cmd_cellphone_arrow_down('\uf2e8'),
        cmd_cellphone_basic('\uf2e9'),
        cmd_cellphone_dock('\uf2ea'),
        cmd_cellphone_erase('\uf2eb'),
        cmd_cellphone_information('\uf2ec'),
        cmd_cellphone_iphone('\uf2ed'),
        cmd_cellphone_key('\uf2ee'),
        cmd_cellphone_link('\uf2f0'),
        cmd_cellphone_link_off('\uf2ef'),
        cmd_cellphone_lock('\uf2f1'),
        cmd_cellphone_message('\uf2f3'),
        cmd_cellphone_message_off('\uf2f2'),
        cmd_cellphone_nfc('\uf2f5'),
        cmd_cellphone_nfc_off('\uf2f4'),
        cmd_cellphone_off('\uf2f6'),
        cmd_cellphone_play('\uf2f7'),
        cmd_cellphone_screenshot('\uf2f8'),
        cmd_cellphone_settings('\uf2fa'),
        cmd_cellphone_settings_variant('\uf2f9'),
        cmd_cellphone_sound('\uf2fb'),
        cmd_cellphone_text('\uf2fc'),
        cmd_cellphone_wireless('\uf2fd'),
        cmd_celtic_cross('\uf2ff'),
        cmd_centos('\uf300'),
        cmd_certificate('\uf302'),
        cmd_certificate_outline('\uf301'),
        cmd_chair_rolling('\uf303'),
        cmd_chair_school('\uf304'),
        cmd_charity('\uf305'),
        cmd_chart_arc('\uf306'),
        cmd_chart_areaspline('\uf308'),
        cmd_chart_areaspline_variant('\uf307'),
        cmd_chart_bar('\uf30a'),
        cmd_chart_bar_stacked('\uf309'),
        cmd_chart_bell_curve('\uf30c'),
        cmd_chart_bell_curve_cumulative('\uf30b'),
        cmd_chart_bubble('\uf30d'),
        cmd_chart_donut('\uf30f'),
        cmd_chart_donut_variant('\uf30e'),
        cmd_chart_gantt('\uf310'),
        cmd_chart_histogram('\uf311'),
        cmd_chart_line('\uf314'),
        cmd_chart_line_stacked('\uf312'),
        cmd_chart_line_variant('\uf313'),
        cmd_chart_multiline('\uf315'),
        cmd_chart_multiple('\uf316'),
        cmd_chart_pie('\uf317'),
        cmd_chart_scatter_plot('\uf319'),
        cmd_chart_scatter_plot_hexbin('\uf318'),
        cmd_chart_snakey('\uf31b'),
        cmd_chart_snakey_variant('\uf31a'),
        cmd_chart_timeline('\uf31d'),
        cmd_chart_timeline_variant('\uf31c'),
        cmd_chart_tree('\uf31e'),
        cmd_chat('\uf326'),
        cmd_chat_alert('\uf320'),
        cmd_chat_alert_outline('\uf31f'),
        cmd_chat_outline('\uf321'),
        cmd_chat_processing('\uf323'),
        cmd_chat_processing_outline('\uf322'),
        cmd_chat_sleep('\uf325'),
        cmd_chat_sleep_outline('\uf324'),
        cmd_check('\uf334'),
        cmd_check_all('\uf327'),
        cmd_check_bold('\uf328'),
        cmd_check_box_multiple_outline('\uf329'),
        cmd_check_box_outline('\uf32a'),
        cmd_check_circle('\uf32c'),
        cmd_check_circle_outline('\uf32b'),
        cmd_check_decagram('\uf32d'),
        cmd_check_network('\uf32f'),
        cmd_check_network_outline('\uf32e'),
        cmd_check_outline('\uf330'),
        cmd_check_underline('\uf333'),
        cmd_check_underline_circle('\uf332'),
        cmd_check_underline_circle_outline('\uf331'),
        cmd_checkbook('\uf335'),
        cmd_checkbox_blank('\uf339'),
        cmd_checkbox_blank_circle('\uf337'),
        cmd_checkbox_blank_circle_outline('\uf336'),
        cmd_checkbox_blank_outline('\uf338'),
        cmd_checkbox_intermediate('\uf33a'),
        cmd_checkbox_marked('\uf33e'),
        cmd_checkbox_marked_circle('\uf33c'),
        cmd_checkbox_marked_circle_outline('\uf33b'),
        cmd_checkbox_marked_outline('\uf33d'),
        cmd_checkbox_multiple_blank('\uf342'),
        cmd_checkbox_multiple_blank_circle('\uf340'),
        cmd_checkbox_multiple_blank_circle_outline('\uf33f'),
        cmd_checkbox_multiple_blank_outline('\uf341'),
        cmd_checkbox_multiple_marked('\uf346'),
        cmd_checkbox_multiple_marked_circle('\uf344'),
        cmd_checkbox_multiple_marked_circle_outline('\uf343'),
        cmd_checkbox_multiple_marked_outline('\uf345'),
        cmd_checkerboard('\uf34a'),
        cmd_checkerboard_minus('\uf347'),
        cmd_checkerboard_plus('\uf348'),
        cmd_checkerboard_remove('\uf349'),
        cmd_cheese('\uf34b'),
        cmd_chef_hat('\uf34c'),
        cmd_chemical_weapon('\uf34d'),
        cmd_chess_bishop('\uf34e'),
        cmd_chess_king('\uf34f'),
        cmd_chess_knight('\uf350'),
        cmd_chess_pawn('\uf351'),
        cmd_chess_queen('\uf352'),
        cmd_chess_rook('\uf353'),
        cmd_chevron_double_down('\uf354'),
        cmd_chevron_double_left('\uf355'),
        cmd_chevron_double_right('\uf356'),
        cmd_chevron_double_up('\uf357'),
        cmd_chevron_down('\uf35c'),
        cmd_chevron_down_box('\uf359'),
        cmd_chevron_down_box_outline('\uf358'),
        cmd_chevron_down_circle('\uf35b'),
        cmd_chevron_down_circle_outline('\uf35a'),
        cmd_chevron_left('\uf361'),
        cmd_chevron_left_box('\uf35e'),
        cmd_chevron_left_box_outline('\uf35d'),
        cmd_chevron_left_circle('\uf360'),
        cmd_chevron_left_circle_outline('\uf35f'),
        cmd_chevron_right('\uf366'),
        cmd_chevron_right_box('\uf363'),
        cmd_chevron_right_box_outline('\uf362'),
        cmd_chevron_right_circle('\uf365'),
        cmd_chevron_right_circle_outline('\uf364'),
        cmd_chevron_triple_down('\uf367'),
        cmd_chevron_triple_left('\uf368'),
        cmd_chevron_triple_right('\uf369'),
        cmd_chevron_triple_up('\uf36a'),
        cmd_chevron_up('\uf36f'),
        cmd_chevron_up_box('\uf36c'),
        cmd_chevron_up_box_outline('\uf36b'),
        cmd_chevron_up_circle('\uf36e'),
        cmd_chevron_up_circle_outline('\uf36d'),
        cmd_chili_hot('\uf370'),
        cmd_chili_medium('\uf371'),
        cmd_chili_mild('\uf372'),
        cmd_chip('\uf373'),
        cmd_christianity('\uf375'),
        cmd_christianity_outline('\uf374'),
        cmd_church('\uf376'),
        cmd_cigar('\uf377'),
        cmd_circle('\uf387'),
        cmd_circle_double('\uf378'),
        cmd_circle_edit_outline('\uf379'),
        cmd_circle_expand('\uf37a'),
        cmd_circle_medium('\uf37b'),
        cmd_circle_off_outline('\uf37c'),
        cmd_circle_outline('\uf37d'),
        cmd_circle_slice_1('\uf37e'),
        cmd_circle_slice_2('\uf37f'),
        cmd_circle_slice_3('\uf380'),
        cmd_circle_slice_4('\uf381'),
        cmd_circle_slice_5('\uf382'),
        cmd_circle_slice_6('\uf383'),
        cmd_circle_slice_7('\uf384'),
        cmd_circle_slice_8('\uf385'),
        cmd_circle_small('\uf386'),
        cmd_circular_saw('\uf388'),
        cmd_cisco_webex('\uf389'),
        cmd_city('\uf38c'),
        cmd_city_variant('\uf38b'),
        cmd_city_variant_outline('\uf38a'),
        cmd_clipboard('\uf3b3'),
        cmd_clipboard_account('\uf38e'),
        cmd_clipboard_account_outline('\uf38d'),
        cmd_clipboard_alert('\uf390'),
        cmd_clipboard_alert_outline('\uf38f'),
        cmd_clipboard_arrow_down('\uf392'),
        cmd_clipboard_arrow_down_outline('\uf391'),
        cmd_clipboard_arrow_left('\uf394'),
        cmd_clipboard_arrow_left_outline('\uf393'),
        cmd_clipboard_arrow_right('\uf396'),
        cmd_clipboard_arrow_right_outline('\uf395'),
        cmd_clipboard_arrow_up('\uf398'),
        cmd_clipboard_arrow_up_outline('\uf397'),
        cmd_clipboard_check('\uf39c'),
        cmd_clipboard_check_multiple('\uf39a'),
        cmd_clipboard_check_multiple_outline('\uf399'),
        cmd_clipboard_check_outline('\uf39b'),
        cmd_clipboard_file('\uf39e'),
        cmd_clipboard_file_outline('\uf39d'),
        cmd_clipboard_flow('\uf3a0'),
        cmd_clipboard_flow_outline('\uf39f'),
        cmd_clipboard_list('\uf3a2'),
        cmd_clipboard_list_outline('\uf3a1'),
        cmd_clipboard_multiple('\uf3a4'),
        cmd_clipboard_multiple_outline('\uf3a3'),
        cmd_clipboard_outline('\uf3a5'),
        cmd_clipboard_play('\uf3a9'),
        cmd_clipboard_play_multiple('\uf3a7'),
        cmd_clipboard_play_multiple_outline('\uf3a6'),
        cmd_clipboard_play_outline('\uf3a8'),
        cmd_clipboard_plus('\uf3aa'),
        cmd_clipboard_pulse('\uf3ac'),
        cmd_clipboard_pulse_outline('\uf3ab'),
        cmd_clipboard_text('\uf3b2'),
        cmd_clipboard_text_multiple('\uf3ae'),
        cmd_clipboard_text_multiple_outline('\uf3ad'),
        cmd_clipboard_text_outline('\uf3af'),
        cmd_clipboard_text_play('\uf3b1'),
        cmd_clipboard_text_play_outline('\uf3b0'),
        cmd_clippy('\uf3b4'),
        cmd_clock('\uf3c0'),
        cmd_clock_alert('\uf3b6'),
        cmd_clock_alert_outline('\uf3b5'),
        cmd_clock_check('\uf3b8'),
        cmd_clock_check_outline('\uf3b7'),
        cmd_clock_digital('\uf3b9'),
        cmd_clock_end('\uf3ba'),
        cmd_clock_fast('\uf3bb'),
        cmd_clock_in('\uf3bc'),
        cmd_clock_out('\uf3bd'),
        cmd_clock_outline('\uf3be'),
        cmd_clock_start('\uf3bf'),
        cmd_close('\uf3cc'),
        cmd_close_box('\uf3c4'),
        cmd_close_box_multiple('\uf3c2'),
        cmd_close_box_multiple_outline('\uf3c1'),
        cmd_close_box_outline('\uf3c3'),
        cmd_close_circle('\uf3c6'),
        cmd_close_circle_outline('\uf3c5'),
        cmd_close_network('\uf3c8'),
        cmd_close_network_outline('\uf3c7'),
        cmd_close_octagon('\uf3ca'),
        cmd_close_octagon_outline('\uf3c9'),
        cmd_close_outline('\uf3cb'),
        cmd_closed_caption('\uf3ce'),
        cmd_closed_caption_outline('\uf3cd'),
        cmd_cloud('\uf3e4'),
        cmd_cloud_alert('\uf3cf'),
        cmd_cloud_braces('\uf3d0'),
        cmd_cloud_check('\uf3d2'),
        cmd_cloud_check_outline('\uf3d1'),
        cmd_cloud_circle('\uf3d3'),
        cmd_cloud_download('\uf3d5'),
        cmd_cloud_download_outline('\uf3d4'),
        cmd_cloud_lock('\uf3d7'),
        cmd_cloud_lock_outline('\uf3d6'),
        cmd_cloud_off_outline('\uf3d8'),
        cmd_cloud_outline('\uf3d9'),
        cmd_cloud_print('\uf3db'),
        cmd_cloud_print_outline('\uf3da'),
        cmd_cloud_question('\uf3dc'),
        cmd_cloud_search('\uf3de'),
        cmd_cloud_search_outline('\uf3dd'),
        cmd_cloud_sync('\uf3e0'),
        cmd_cloud_sync_outline('\uf3df'),
        cmd_cloud_tags('\uf3e1'),
        cmd_cloud_upload('\uf3e3'),
        cmd_cloud_upload_outline('\uf3e2'),
        cmd_clover('\uf3e5'),
        cmd_coach_lamp('\uf3e6'),
        cmd_coat_rack('\uf3e7'),
        cmd_code_array('\uf3e8'),
        cmd_code_braces('\uf3ea'),
        cmd_code_braces_box('\uf3e9'),
        cmd_code_brackets('\uf3eb'),
        cmd_code_equal('\uf3ec'),
        cmd_code_greater_than('\uf3ee'),
        cmd_code_greater_than_or_equal('\uf3ed'),
        cmd_code_less_than('\uf3f0'),
        cmd_code_less_than_or_equal('\uf3ef'),
        cmd_code_not_equal('\uf3f2'),
        cmd_code_not_equal_variant('\uf3f1'),
        cmd_code_parentheses('\uf3f4'),
        cmd_code_parentheses_box('\uf3f3'),
        cmd_code_string('\uf3f5'),
        cmd_code_tags('\uf3f7'),
        cmd_code_tags_check('\uf3f6'),
        cmd_codepen('\uf3f8'),
        cmd_coffee('\uf3fe'),
        cmd_coffee_maker('\uf3f9'),
        cmd_coffee_off('\uf3fb'),
        cmd_coffee_off_outline('\uf3fa'),
        cmd_coffee_outline('\uf3fc'),
        cmd_coffee_to_go('\uf3fd'),
        cmd_coffin('\uf3ff'),
        cmd_cog_clockwise('\uf400'),
        cmd_cog_counterclockwise('\uf401'),
        cmd_cogs('\uf402'),
        cmd_coin('\uf404'),
        cmd_coin_outline('\uf403'),
        cmd_coins('\uf405'),
        cmd_collage('\uf406'),
        cmd_collapse_all('\uf408'),
        cmd_collapse_all_outline('\uf407'),
        cmd_color_helper('\uf409'),
        cmd_comma('\uf40e'),
        cmd_comma_box('\uf40b'),
        cmd_comma_box_outline('\uf40a'),
        cmd_comma_circle('\uf40d'),
        cmd_comma_circle_outline('\uf40c'),
        cmd_comment('\uf430'),
        cmd_comment_account('\uf410'),
        cmd_comment_account_outline('\uf40f'),
        cmd_comment_alert('\uf412'),
        cmd_comment_alert_outline('\uf411'),
        cmd_comment_arrow_left('\uf414'),
        cmd_comment_arrow_left_outline('\uf413'),
        cmd_comment_arrow_right('\uf416'),
        cmd_comment_arrow_right_outline('\uf415'),
        cmd_comment_check('\uf418'),
        cmd_comment_check_outline('\uf417'),
        cmd_comment_edit('\uf41a'),
        cmd_comment_edit_outline('\uf419'),
        cmd_comment_eye('\uf41c'),
        cmd_comment_eye_outline('\uf41b'),
        cmd_comment_multiple('\uf41e'),
        cmd_comment_multiple_outline('\uf41d'),
        cmd_comment_outline('\uf41f'),
        cmd_comment_plus('\uf421'),
        cmd_comment_plus_outline('\uf420'),
        cmd_comment_processing('\uf423'),
        cmd_comment_processing_outline('\uf422'),
        cmd_comment_question('\uf425'),
        cmd_comment_question_outline('\uf424'),
        cmd_comment_quote('\uf427'),
        cmd_comment_quote_outline('\uf426'),
        cmd_comment_remove('\uf429'),
        cmd_comment_remove_outline('\uf428'),
        cmd_comment_search('\uf42b'),
        cmd_comment_search_outline('\uf42a'),
        cmd_comment_text('\uf42f'),
        cmd_comment_text_multiple('\uf42d'),
        cmd_comment_text_multiple_outline('\uf42c'),
        cmd_comment_text_outline('\uf42e'),
        cmd_compare('\uf431'),
        cmd_compass('\uf435'),
        cmd_compass_off('\uf433'),
        cmd_compass_off_outline('\uf432'),
        cmd_compass_outline('\uf434'),
        cmd_concourse_ci('\uf436'),
        cmd_console('\uf43a'),
        cmd_console_line('\uf437'),
        cmd_console_network('\uf439'),
        cmd_console_network_outline('\uf438'),
        cmd_consolidate('\uf43b'),
        cmd_contact_mail('\uf43d'),
        cmd_contact_mail_outline('\uf43c'),
        cmd_contact_phone('\uf43f'),
        cmd_contact_phone_outline('\uf43e'),
        cmd_contactless_payment('\uf440'),
        cmd_contacts('\uf441'),
        cmd_contain('\uf444'),
        cmd_contain_end('\uf442'),
        cmd_contain_start('\uf443'),
        cmd_content_copy('\uf445'),
        cmd_content_cut('\uf446'),
        cmd_content_duplicate('\uf447'),
        cmd_content_paste('\uf448'),
        cmd_content_save('\uf454'),
        cmd_content_save_alert('\uf44a'),
        cmd_content_save_alert_outline('\uf449'),
        cmd_content_save_all('\uf44c'),
        cmd_content_save_all_outline('\uf44b'),
        cmd_content_save_edit('\uf44e'),
        cmd_content_save_edit_outline('\uf44d'),
        cmd_content_save_move('\uf450'),
        cmd_content_save_move_outline('\uf44f'),
        cmd_content_save_outline('\uf451'),
        cmd_content_save_settings('\uf453'),
        cmd_content_save_settings_outline('\uf452'),
        cmd_contrast('\uf457'),
        cmd_contrast_box('\uf455'),
        cmd_contrast_circle('\uf456'),
        cmd_controller_classic('\uf459'),
        cmd_controller_classic_outline('\uf458'),
        cmd_cookie('\uf45a'),
        cmd_coolant_temperature('\uf45b'),
        cmd_copyright('\uf45c'),
        cmd_cordova('\uf45d'),
        cmd_corn('\uf45e'),
        cmd_counter('\uf45f'),
        cmd_cow('\uf460'),
        cmd_cowboy('\uf461'),
        cmd_cpu_32_bit('\uf462'),
        cmd_cpu_64_bit('\uf463'),
        cmd_crane('\uf464'),
        cmd_creation('\uf465'),
        cmd_creative_commons('\uf466'),
        cmd_credit_card('\uf47e'),
        cmd_credit_card_clock('\uf468'),
        cmd_credit_card_clock_outline('\uf467'),
        cmd_credit_card_marker('\uf46a'),
        cmd_credit_card_marker_outline('\uf469'),
        cmd_credit_card_minus('\uf46c'),
        cmd_credit_card_minus_outline('\uf46b'),
        cmd_credit_card_multiple('\uf46e'),
        cmd_credit_card_multiple_outline('\uf46d'),
        cmd_credit_card_off('\uf470'),
        cmd_credit_card_off_outline('\uf46f'),
        cmd_credit_card_outline('\uf471'),
        cmd_credit_card_plus('\uf473'),
        cmd_credit_card_plus_outline('\uf472'),
        cmd_credit_card_refund('\uf475'),
        cmd_credit_card_refund_outline('\uf474'),
        cmd_credit_card_remove('\uf477'),
        cmd_credit_card_remove_outline('\uf476'),
        cmd_credit_card_scan('\uf479'),
        cmd_credit_card_scan_outline('\uf478'),
        cmd_credit_card_settings('\uf47b'),
        cmd_credit_card_settings_outline('\uf47a'),
        cmd_credit_card_wireless('\uf47d'),
        cmd_credit_card_wireless_outline('\uf47c'),
        cmd_cricket('\uf47f'),
        cmd_crop('\uf485'),
        cmd_crop_free('\uf480'),
        cmd_crop_landscape('\uf481'),
        cmd_crop_portrait('\uf482'),
        cmd_crop_rotate('\uf483'),
        cmd_crop_square('\uf484'),
        cmd_crosshairs('\uf489'),
        cmd_crosshairs_gps('\uf486'),
        cmd_crosshairs_off('\uf487'),
        cmd_crosshairs_question('\uf488'),
        cmd_crown('\uf48b'),
        cmd_crown_outline('\uf48a'),
        cmd_cryengine('\uf48c'),
        cmd_crystal_ball('\uf48d'),
        cmd_cube('\uf492'),
        cmd_cube_outline('\uf48e'),
        cmd_cube_scan('\uf48f'),
        cmd_cube_send('\uf490'),
        cmd_cube_unfolded('\uf491'),
        cmd_cup('\uf495'),
        cmd_cup_off('\uf493'),
        cmd_cup_water('\uf494'),
        cmd_cupboard('\uf497'),
        cmd_cupboard_outline('\uf496'),
        cmd_cupcake('\uf498'),
        cmd_curling('\uf499'),
        cmd_currency_bdt('\uf49a'),
        cmd_currency_brl('\uf49b'),
        cmd_currency_btc('\uf49c'),
        cmd_currency_cny('\uf49d'),
        cmd_currency_eth('\uf49e'),
        cmd_currency_eur('\uf49f'),
        cmd_currency_gbp('\uf4a0'),
        cmd_currency_ils('\uf4a1'),
        cmd_currency_inr('\uf4a2'),
        cmd_currency_jpy('\uf4a3'),
        cmd_currency_krw('\uf4a4'),
        cmd_currency_kzt('\uf4a5'),
        cmd_currency_ngn('\uf4a6'),
        cmd_currency_php('\uf4a7'),
        cmd_currency_rial('\uf4a8'),
        cmd_currency_rub('\uf4a9'),
        cmd_currency_sign('\uf4aa'),
        cmd_currency_try('\uf4ab'),
        cmd_currency_twd('\uf4ac'),
        cmd_currency_usd('\uf4ae'),
        cmd_currency_usd_off('\uf4ad'),
        cmd_current_ac('\uf4af'),
        cmd_current_dc('\uf4b0'),
        cmd_cursor_default('\uf4b6'),
        cmd_cursor_default_click('\uf4b2'),
        cmd_cursor_default_click_outline('\uf4b1'),
        cmd_cursor_default_gesture('\uf4b4'),
        cmd_cursor_default_gesture_outline('\uf4b3'),
        cmd_cursor_default_outline('\uf4b5'),
        cmd_cursor_move('\uf4b7'),
        cmd_cursor_pointer('\uf4b8'),
        cmd_cursor_text('\uf4b9'),
        cmd_database('\uf4c5'),
        cmd_database_check('\uf4ba'),
        cmd_database_edit('\uf4bb'),
        cmd_database_export('\uf4bc'),
        cmd_database_import('\uf4bd'),
        cmd_database_lock('\uf4be'),
        cmd_database_minus('\uf4bf'),
        cmd_database_plus('\uf4c0'),
        cmd_database_refresh('\uf4c1'),
        cmd_database_remove('\uf4c2'),
        cmd_database_search('\uf4c3'),
        cmd_database_settings('\uf4c4'),
        cmd_death_star('\uf4c7'),
        cmd_death_star_variant('\uf4c6'),
        cmd_deathly_hallows('\uf4c8'),
        cmd_debian('\uf4c9'),
        cmd_debug_step_into('\uf4ca'),
        cmd_debug_step_out('\uf4cb'),
        cmd_debug_step_over('\uf4cc'),
        cmd_decagram('\uf4ce'),
        cmd_decagram_outline('\uf4cd'),
        cmd_decimal('\uf4d4'),
        cmd_decimal_comma('\uf4d1'),
        cmd_decimal_comma_decrease('\uf4cf'),
        cmd_decimal_comma_increase('\uf4d0'),
        cmd_decimal_decrease('\uf4d2'),
        cmd_decimal_increase('\uf4d3'),
        cmd_delete('\uf4e4'),
        cmd_delete_alert('\uf4d6'),
        cmd_delete_alert_outline('\uf4d5'),
        cmd_delete_circle('\uf4d8'),
        cmd_delete_circle_outline('\uf4d7'),
        cmd_delete_empty('\uf4da'),
        cmd_delete_empty_outline('\uf4d9'),
        cmd_delete_forever('\uf4dc'),
        cmd_delete_forever_outline('\uf4db'),
        cmd_delete_off('\uf4de'),
        cmd_delete_off_outline('\uf4dd'),
        cmd_delete_outline('\uf4df'),
        cmd_delete_restore('\uf4e0'),
        cmd_delete_sweep('\uf4e2'),
        cmd_delete_sweep_outline('\uf4e1'),
        cmd_delete_variant('\uf4e3'),
        cmd_delta('\uf4e5'),
        cmd_desk('\uf4e7'),
        cmd_desk_lamp('\uf4e6'),
        cmd_deskphone('\uf4e8'),
        cmd_desktop_classic('\uf4e9'),
        cmd_desktop_mac('\uf4eb'),
        cmd_desktop_mac_dashboard('\uf4ea'),
        cmd_desktop_tower('\uf4ed'),
        cmd_desktop_tower_monitor('\uf4ec'),
        cmd_details('\uf4ee'),
        cmd_dev_to('\uf4ef'),
        cmd_developer_board('\uf4f0'),
        cmd_deviantart('\uf4f1'),
        cmd_devices('\uf4f2'),
        cmd_diabetes('\uf4f3'),
        cmd_dialpad('\uf4f4'),
        cmd_diameter('\uf4f7'),
        cmd_diameter_outline('\uf4f5'),
        cmd_diameter_variant('\uf4f6'),
        cmd_diamond('\uf4fa'),
        cmd_diamond_outline('\uf4f8'),
        cmd_diamond_stone('\uf4f9'),
        cmd_dice_1('\uf4fc'),
        cmd_dice_1_outline('\uf4fb'),
        cmd_dice_2('\uf4fe'),
        cmd_dice_2_outline('\uf4fd'),
        cmd_dice_3('\uf500'),
        cmd_dice_3_outline('\uf4ff'),
        cmd_dice_4('\uf502'),
        cmd_dice_4_outline('\uf501'),
        cmd_dice_5('\uf504'),
        cmd_dice_5_outline('\uf503'),
        cmd_dice_6('\uf506'),
        cmd_dice_6_outline('\uf505'),
        cmd_dice_d10('\uf50e'),
        cmd_dice_d10_outline('\uf50d'),
        cmd_dice_d12('\uf510'),
        cmd_dice_d12_outline('\uf50f'),
        cmd_dice_d20('\uf512'),
        cmd_dice_d20_outline('\uf511'),
        cmd_dice_d4('\uf508'),
        cmd_dice_d4_outline('\uf507'),
        cmd_dice_d6('\uf50a'),
        cmd_dice_d6_outline('\uf509'),
        cmd_dice_d8('\uf50c'),
        cmd_dice_d8_outline('\uf50b'),
        cmd_dice_multiple('\uf514'),
        cmd_dice_multiple_outline('\uf513'),
        cmd_dictionary('\uf515'),
        cmd_digital_ocean('\uf516'),
        cmd_dip_switch('\uf517'),
        cmd_directions('\uf519'),
        cmd_directions_fork('\uf518'),
        cmd_disc('\uf51c'),
        cmd_disc_alert('\uf51a'),
        cmd_disc_player('\uf51b'),
        cmd_discord('\uf51d'),
        cmd_dishwasher('\uf520'),
        cmd_dishwasher_alert('\uf51e'),
        cmd_dishwasher_off('\uf51f'),
        cmd_disqus('\uf522'),
        cmd_disqus_outline('\uf521'),
        cmd_distribute_horizontal_center('\uf523'),
        cmd_distribute_horizontal_left('\uf524'),
        cmd_distribute_horizontal_right('\uf525'),
        cmd_distribute_vertical_bottom('\uf526'),
        cmd_distribute_vertical_center('\uf527'),
        cmd_distribute_vertical_top('\uf528'),
        cmd_diving_flippers('\uf529'),
        cmd_diving_helmet('\uf52a'),
        cmd_diving_scuba('\uf52e'),
        cmd_diving_scuba_flag('\uf52b'),
        cmd_diving_scuba_tank('\uf52d'),
        cmd_diving_scuba_tank_multiple('\uf52c'),
        cmd_diving_snorkel('\uf52f'),
        cmd_division('\uf531'),
        cmd_division_box('\uf530'),
        cmd_dlna('\uf532'),
        cmd_dna('\uf533'),
        cmd_dns('\uf535'),
        cmd_dns_outline('\uf534'),
        cmd_do_not_disturb('\uf537'),
        cmd_do_not_disturb_off('\uf536'),
        cmd_dock_bottom('\uf538'),
        cmd_dock_left('\uf539'),
        cmd_dock_right('\uf53a'),
        cmd_dock_window('\uf53b'),
        cmd_docker('\uf53c'),
        cmd_doctor('\uf53d'),
        cmd_dog('\uf540'),
        cmd_dog_service('\uf53e'),
        cmd_dog_side('\uf53f'),
        cmd_dolby('\uf541'),
        cmd_dolly('\uf542'),
        cmd_domain('\uf546'),
        cmd_domain_off('\uf543'),
        cmd_domain_plus('\uf544'),
        cmd_domain_remove('\uf545'),
        cmd_domino_mask('\uf547'),
        cmd_donkey('\uf548'),
        cmd_door('\uf54c'),
        cmd_door_closed('\uf54a'),
        cmd_door_closed_lock('\uf549'),
        cmd_door_open('\uf54b'),
        cmd_doorbell_video('\uf54d'),
        cmd_dot_net('\uf54e'),
        cmd_dots_horizontal('\uf551'),
        cmd_dots_horizontal_circle('\uf550'),
        cmd_dots_horizontal_circle_outline('\uf54f'),
        cmd_dots_vertical('\uf554'),
        cmd_dots_vertical_circle('\uf553'),
        cmd_dots_vertical_circle_outline('\uf552'),
        cmd_douban('\uf555'),
        cmd_download('\uf55c'),
        cmd_download_multiple('\uf556'),
        cmd_download_network('\uf558'),
        cmd_download_network_outline('\uf557'),
        cmd_download_off('\uf55a'),
        cmd_download_off_outline('\uf559'),
        cmd_download_outline('\uf55b'),
        cmd_drag('\uf560'),
        cmd_drag_horizontal('\uf55d'),
        cmd_drag_variant('\uf55e'),
        cmd_drag_vertical('\uf55f'),
        cmd_drama_masks('\uf561'),
        cmd_draw('\uf562'),
        cmd_drawing('\uf564'),
        cmd_drawing_box('\uf563'),
        cmd_dresser('\uf566'),
        cmd_dresser_outline('\uf565'),
        cmd_dribbble('\uf568'),
        cmd_dribbble_box('\uf567'),
        cmd_drone('\uf569'),
        cmd_dropbox('\uf56a'),
        cmd_drupal('\uf56b'),
        cmd_duck('\uf56c'),
        cmd_dumbbell('\uf56d'),
        cmd_dump_truck('\uf56e'),
        cmd_ear_hearing('\uf570'),
        cmd_ear_hearing_off('\uf56f'),
        cmd_earth('\uf574'),
        cmd_earth_box('\uf572'),
        cmd_earth_box_off('\uf571'),
        cmd_earth_off('\uf573'),
        cmd_edge('\uf576'),
        cmd_edge_legacy('\uf575'),
        cmd_egg('\uf578'),
        cmd_egg_easter('\uf577'),
        cmd_eight_track('\uf579'),
        cmd_eject('\uf57b'),
        cmd_eject_outline('\uf57a'),
        cmd_electric_switch('\uf57d'),
        cmd_electric_switch_closed('\uf57c'),
        cmd_electron_framework('\uf57e'),
        cmd_elephant('\uf57f'),
        cmd_elevation_decline('\uf580'),
        cmd_elevation_rise('\uf581'),
        cmd_elevator('\uf584'),
        cmd_elevator_down('\uf582'),
        cmd_elevator_up('\uf583'),
        cmd_ellipse('\uf586'),
        cmd_ellipse_outline('\uf585'),
        cmd_email('\uf5a4'),
        cmd_email_alert('\uf587'),
        cmd_email_box('\uf588'),
        cmd_email_check('\uf58a'),
        cmd_email_check_outline('\uf589'),
        cmd_email_edit('\uf58c'),
        cmd_email_edit_outline('\uf58b'),
        cmd_email_lock('\uf58d'),
        cmd_email_mark_as_unread('\uf58e'),
        cmd_email_minus('\uf590'),
        cmd_email_minus_outline('\uf58f'),
        cmd_email_multiple('\uf592'),
        cmd_email_multiple_outline('\uf591'),
        cmd_email_newsletter('\uf593'),
        cmd_email_open('\uf597'),
        cmd_email_open_multiple('\uf595'),
        cmd_email_open_multiple_outline('\uf594'),
        cmd_email_open_outline('\uf596'),
        cmd_email_outline('\uf598'),
        cmd_email_plus('\uf59a'),
        cmd_email_plus_outline('\uf599'),
        cmd_email_receive('\uf59c'),
        cmd_email_receive_outline('\uf59b'),
        cmd_email_search('\uf59e'),
        cmd_email_search_outline('\uf59d'),
        cmd_email_send('\uf5a0'),
        cmd_email_send_outline('\uf59f'),
        cmd_email_sync('\uf5a2'),
        cmd_email_sync_outline('\uf5a1'),
        cmd_email_variant('\uf5a3'),
        cmd_ember('\uf5a5'),
        cmd_emby('\uf5a6'),
        cmd_emoticon('\uf5c8'),
        cmd_emoticon_angry('\uf5a8'),
        cmd_emoticon_angry_outline('\uf5a7'),
        cmd_emoticon_confused('\uf5aa'),
        cmd_emoticon_confused_outline('\uf5a9'),
        cmd_emoticon_cool('\uf5ac'),
        cmd_emoticon_cool_outline('\uf5ab'),
        cmd_emoticon_cry('\uf5ae'),
        cmd_emoticon_cry_outline('\uf5ad'),
        cmd_emoticon_dead('\uf5b0'),
        cmd_emoticon_dead_outline('\uf5af'),
        cmd_emoticon_devil('\uf5b2'),
        cmd_emoticon_devil_outline('\uf5b1'),
        cmd_emoticon_excited('\uf5b4'),
        cmd_emoticon_excited_outline('\uf5b3'),
        cmd_emoticon_frown('\uf5b6'),
        cmd_emoticon_frown_outline('\uf5b5'),
        cmd_emoticon_happy('\uf5b8'),
        cmd_emoticon_happy_outline('\uf5b7'),
        cmd_emoticon_kiss('\uf5ba'),
        cmd_emoticon_kiss_outline('\uf5b9'),
        cmd_emoticon_lol('\uf5bc'),
        cmd_emoticon_lol_outline('\uf5bb'),
        cmd_emoticon_neutral('\uf5be'),
        cmd_emoticon_neutral_outline('\uf5bd'),
        cmd_emoticon_outline('\uf5bf'),
        cmd_emoticon_poop('\uf5c1'),
        cmd_emoticon_poop_outline('\uf5c0'),
        cmd_emoticon_sad('\uf5c3'),
        cmd_emoticon_sad_outline('\uf5c2'),
        cmd_emoticon_tongue('\uf5c5'),
        cmd_emoticon_tongue_outline('\uf5c4'),
        cmd_emoticon_wink('\uf5c7'),
        cmd_emoticon_wink_outline('\uf5c6'),
        cmd_engine('\uf5cc'),
        cmd_engine_off('\uf5ca'),
        cmd_engine_off_outline('\uf5c9'),
        cmd_engine_outline('\uf5cb'),
        cmd_epsilon('\uf5cd'),
        cmd_equal('\uf5cf'),
        cmd_equal_box('\uf5ce'),
        cmd_equalizer('\uf5d1'),
        cmd_equalizer_outline('\uf5d0'),
        cmd_eraser('\uf5d3'),
        cmd_eraser_variant('\uf5d2'),
        cmd_escalator('\uf5d6'),
        cmd_escalator_down('\uf5d4'),
        cmd_escalator_up('\uf5d5'),
        cmd_eslint('\uf5d7'),
        cmd_et('\uf5d8'),
        cmd_ethereum('\uf5d9'),
        cmd_ethernet('\uf5dc'),
        cmd_ethernet_cable('\uf5db'),
        cmd_ethernet_cable_off('\uf5da'),
        cmd_etsy('\uf5dd'),
        cmd_ev_station('\uf5de'),
        cmd_eventbrite('\uf5df'),
        cmd_evernote('\uf5e0'),
        cmd_excavator('\uf5e1'),
        cmd_exclamation('\uf5e3'),
        cmd_exclamation_thick('\uf5e2'),
        cmd_exit_run('\uf5e4'),
        cmd_exit_to_app('\uf5e5'),
        cmd_expand_all('\uf5e7'),
        cmd_expand_all_outline('\uf5e6'),
        cmd_expansion_card('\uf5e9'),
        cmd_expansion_card_variant('\uf5e8'),
        cmd_exponent('\uf5eb'),
        cmd_exponent_box('\uf5ea'),
        cmd_export('\uf5ed'),
        cmd_export_variant('\uf5ec'),
        cmd_eye('\uf5fb'),
        cmd_eye_check('\uf5ef'),
        cmd_eye_check_outline('\uf5ee'),
        cmd_eye_circle('\uf5f1'),
        cmd_eye_circle_outline('\uf5f0'),
        cmd_eye_minus('\uf5f3'),
        cmd_eye_minus_outline('\uf5f2'),
        cmd_eye_off('\uf5f5'),
        cmd_eye_off_outline('\uf5f4'),
        cmd_eye_outline('\uf5f6'),
        cmd_eye_plus('\uf5f8'),
        cmd_eye_plus_outline('\uf5f7'),
        cmd_eye_settings('\uf5fa'),
        cmd_eye_settings_outline('\uf5f9'),
        cmd_eyedropper('\uf5fd'),
        cmd_eyedropper_variant('\uf5fc'),
        cmd_face('\uf605'),
        cmd_face_agent('\uf5fe'),
        cmd_face_outline('\uf5ff'),
        cmd_face_profile('\uf601'),
        cmd_face_profile_woman('\uf600'),
        cmd_face_recognition('\uf602'),
        cmd_face_woman('\uf604'),
        cmd_face_woman_outline('\uf603'),
        cmd_facebook('\uf609'),
        cmd_facebook_box('\uf606'),
        cmd_facebook_messenger('\uf607'),
        cmd_facebook_workplace('\uf608'),
        cmd_factory('\uf60a'),
        cmd_fan('\uf60c'),
        cmd_fan_off('\uf60b'),
        cmd_fast_forward('\uf611'),
        cmd_fast_forward_10('\uf60e'),
        cmd_fast_forward_30('\uf60f'),
        cmd_fast_forward_5('\uf60d'),
        cmd_fast_forward_outline('\uf610'),
        cmd_fax('\uf612'),
        cmd_feather('\uf613'),
        cmd_feature_search('\uf615'),
        cmd_feature_search_outline('\uf614'),
        cmd_fedora('\uf616'),
        cmd_ferris_wheel('\uf617'),
        cmd_ferry('\uf618'),
        cmd_file('\uf699'),
        cmd_file_account('\uf61a'),
        cmd_file_account_outline('\uf619'),
        cmd_file_alert('\uf61c'),
        cmd_file_alert_outline('\uf61b'),
        cmd_file_cabinet('\uf61d'),
        cmd_file_cad('\uf61f'),
        cmd_file_cad_box('\uf61e'),
        cmd_file_cancel('\uf621'),
        cmd_file_cancel_outline('\uf620'),
        cmd_file_certificate('\uf623'),
        cmd_file_certificate_outline('\uf622'),
        cmd_file_chart('\uf625'),
        cmd_file_chart_outline('\uf624'),
        cmd_file_check('\uf627'),
        cmd_file_check_outline('\uf626'),
        cmd_file_clock('\uf629'),
        cmd_file_clock_outline('\uf628'),
        cmd_file_cloud('\uf62b'),
        cmd_file_cloud_outline('\uf62a'),
        cmd_file_code('\uf62d'),
        cmd_file_code_outline('\uf62c'),
        cmd_file_compare('\uf62e'),
        cmd_file_delimited('\uf630'),
        cmd_file_delimited_outline('\uf62f'),
        cmd_file_document('\uf642'),
        cmd_file_document_box('\uf63e'),
        cmd_file_document_box_check('\uf632'),
        cmd_file_document_box_check_outline('\uf631'),
        cmd_file_document_box_minus('\uf634'),
        cmd_file_document_box_minus_outline('\uf633'),
        cmd_file_document_box_multiple('\uf636'),
        cmd_file_document_box_multiple_outline('\uf635'),
        cmd_file_document_box_outline('\uf637'),
        cmd_file_document_box_plus('\uf639'),
        cmd_file_document_box_plus_outline('\uf638'),
        cmd_file_document_box_remove('\uf63b'),
        cmd_file_document_box_remove_outline('\uf63a'),
        cmd_file_document_box_search('\uf63d'),
        cmd_file_document_box_search_outline('\uf63c'),
        cmd_file_document_edit('\uf640'),
        cmd_file_document_edit_outline('\uf63f'),
        cmd_file_document_outline('\uf641'),
        cmd_file_download('\uf644'),
        cmd_file_download_outline('\uf643'),
        cmd_file_edit('\uf646'),
        cmd_file_edit_outline('\uf645'),
        cmd_file_excel('\uf64a'),
        cmd_file_excel_box('\uf648'),
        cmd_file_excel_box_outline('\uf647'),
        cmd_file_excel_outline('\uf649'),
        cmd_file_export('\uf64c'),
        cmd_file_export_outline('\uf64b'),
        cmd_file_eye('\uf64e'),
        cmd_file_eye_outline('\uf64d'),
        cmd_file_find('\uf650'),
        cmd_file_find_outline('\uf64f'),
        cmd_file_hidden('\uf651'),
        cmd_file_image('\uf653'),
        cmd_file_image_outline('\uf652'),
        cmd_file_import('\uf655'),
        cmd_file_import_outline('\uf654'),
        cmd_file_key('\uf657'),
        cmd_file_key_outline('\uf656'),
        cmd_file_link('\uf659'),
        cmd_file_link_outline('\uf658'),
        cmd_file_lock('\uf65b'),
        cmd_file_lock_outline('\uf65a'),
        cmd_file_move('\uf65d'),
        cmd_file_move_outline('\uf65c'),
        cmd_file_multiple('\uf65f'),
        cmd_file_multiple_outline('\uf65e'),
        cmd_file_music('\uf661'),
        cmd_file_music_outline('\uf660'),
        cmd_file_outline('\uf662'),
        cmd_file_pdf('\uf666'),
        cmd_file_pdf_box('\uf664'),
        cmd_file_pdf_box_outline('\uf663'),
        cmd_file_pdf_outline('\uf665'),
        cmd_file_percent('\uf668'),
        cmd_file_percent_outline('\uf667'),
        cmd_file_phone('\uf66a'),
        cmd_file_phone_outline('\uf669'),
        cmd_file_plus('\uf66c'),
        cmd_file_plus_outline('\uf66b'),
        cmd_file_powerpoint('\uf670'),
        cmd_file_powerpoint_box('\uf66e'),
        cmd_file_powerpoint_box_outline('\uf66d'),
        cmd_file_powerpoint_outline('\uf66f'),
        cmd_file_presentation_box('\uf671'),
        cmd_file_question('\uf673'),
        cmd_file_question_outline('\uf672'),
        cmd_file_remove('\uf675'),
        cmd_file_remove_outline('\uf674'),
        cmd_file_replace('\uf677'),
        cmd_file_replace_outline('\uf676'),
        cmd_file_restore('\uf679'),
        cmd_file_restore_outline('\uf678'),
        cmd_file_search('\uf67b'),
        cmd_file_search_outline('\uf67a'),
        cmd_file_send('\uf67d'),
        cmd_file_send_outline('\uf67c'),
        cmd_file_settings('\uf681'),
        cmd_file_settings_outline('\uf67e'),
        cmd_file_settings_variant('\uf680'),
        cmd_file_settings_variant_outline('\uf67f'),
        cmd_file_star('\uf683'),
        cmd_file_star_outline('\uf682'),
        cmd_file_swap('\uf685'),
        cmd_file_swap_outline('\uf684'),
        cmd_file_sync('\uf687'),
        cmd_file_sync_outline('\uf686'),
        cmd_file_table('\uf68d'),
        cmd_file_table_box('\uf68b'),
        cmd_file_table_box_multiple('\uf689'),
        cmd_file_table_box_multiple_outline('\uf688'),
        cmd_file_table_box_outline('\uf68a'),
        cmd_file_table_outline('\uf68c'),
        cmd_file_tree('\uf68e'),
        cmd_file_undo('\uf690'),
        cmd_file_undo_outline('\uf68f'),
        cmd_file_upload('\uf692'),
        cmd_file_upload_outline('\uf691'),
        cmd_file_video('\uf694'),
        cmd_file_video_outline('\uf693'),
        cmd_file_word('\uf698'),
        cmd_file_word_box('\uf696'),
        cmd_file_word_box_outline('\uf695'),
        cmd_file_word_outline('\uf697'),
        cmd_film('\uf69a'),
        cmd_filmstrip('\uf69c'),
        cmd_filmstrip_off('\uf69b'),
        cmd_filter('\uf6aa'),
        cmd_filter_menu('\uf69e'),
        cmd_filter_menu_outline('\uf69d'),
        cmd_filter_minus('\uf6a0'),
        cmd_filter_minus_outline('\uf69f'),
        cmd_filter_outline('\uf6a1'),
        cmd_filter_plus('\uf6a3'),
        cmd_filter_plus_outline('\uf6a2'),
        cmd_filter_remove('\uf6a5'),
        cmd_filter_remove_outline('\uf6a4'),
        cmd_filter_variant('\uf6a9'),
        cmd_filter_variant_minus('\uf6a6'),
        cmd_filter_variant_plus('\uf6a7'),
        cmd_filter_variant_remove('\uf6a8'),
        cmd_finance('\uf6ab'),
        cmd_find_replace('\uf6ac'),
        cmd_fingerprint('\uf6ae'),
        cmd_fingerprint_off('\uf6ad'),
        cmd_fire('\uf6b4'),
        cmd_fire_extinguisher('\uf6af'),
        cmd_fire_hydrant('\uf6b2'),
        cmd_fire_hydrant_alert('\uf6b0'),
        cmd_fire_hydrant_off('\uf6b1'),
        cmd_fire_truck('\uf6b3'),
        cmd_firebase('\uf6b5'),
        cmd_firefox('\uf6b6'),
        cmd_fireplace('\uf6b8'),
        cmd_fireplace_off('\uf6b7'),
        cmd_firework('\uf6b9'),
        cmd_fish('\uf6ba'),
        cmd_fishbowl('\uf6bc'),
        cmd_fishbowl_outline('\uf6bb'),
        cmd_fit_to_page('\uf6be'),
        cmd_fit_to_page_outline('\uf6bd'),
        cmd_flag('\uf6ca'),
        cmd_flag_checkered('\uf6bf'),
        cmd_flag_minus('\uf6c1'),
        cmd_flag_minus_outline('\uf6c0'),
        cmd_flag_outline('\uf6c2'),
        cmd_flag_plus('\uf6c4'),
        cmd_flag_plus_outline('\uf6c3'),
        cmd_flag_remove('\uf6c6'),
        cmd_flag_remove_outline('\uf6c5'),
        cmd_flag_triangle('\uf6c7'),
        cmd_flag_variant('\uf6c9'),
        cmd_flag_variant_outline('\uf6c8'),
        cmd_flare('\uf6cb'),
        cmd_flash('\uf6d3'),
        cmd_flash_alert('\uf6cd'),
        cmd_flash_alert_outline('\uf6cc'),
        cmd_flash_auto('\uf6ce'),
        cmd_flash_circle('\uf6cf'),
        cmd_flash_off('\uf6d0'),
        cmd_flash_outline('\uf6d1'),
        cmd_flash_red_eye('\uf6d2'),
        cmd_flashlight('\uf6d5'),
        cmd_flashlight_off('\uf6d4'),
        cmd_flask('\uf6e9'),
        cmd_flask_empty('\uf6dd'),
        cmd_flask_empty_minus('\uf6d7'),
        cmd_flask_empty_minus_outline('\uf6d6'),
        cmd_flask_empty_outline('\uf6d8'),
        cmd_flask_empty_plus('\uf6da'),
        cmd_flask_empty_plus_outline('\uf6d9'),
        cmd_flask_empty_remove('\uf6dc'),
        cmd_flask_empty_remove_outline('\uf6db'),
        cmd_flask_minus('\uf6df'),
        cmd_flask_minus_outline('\uf6de'),
        cmd_flask_outline('\uf6e0'),
        cmd_flask_plus('\uf6e2'),
        cmd_flask_plus_outline('\uf6e1'),
        cmd_flask_remove('\uf6e4'),
        cmd_flask_remove_outline('\uf6e3'),
        cmd_flask_round_bottom('\uf6e8'),
        cmd_flask_round_bottom_empty('\uf6e6'),
        cmd_flask_round_bottom_empty_outline('\uf6e5'),
        cmd_flask_round_bottom_outline('\uf6e7'),
        cmd_flattr('\uf6ea'),
        cmd_flickr('\uf6eb'),
        cmd_flip_horizontal('\uf6ec'),
        cmd_flip_to_back('\uf6ed'),
        cmd_flip_to_front('\uf6ee'),
        cmd_flip_vertical('\uf6ef'),
        cmd_floor_lamp('\uf6f2'),
        cmd_floor_lamp_dual('\uf6f0'),
        cmd_floor_lamp_variant('\uf6f1'),
        cmd_floor_plan('\uf6f3'),
        cmd_floppy('\uf6f5'),
        cmd_floppy_variant('\uf6f4'),
        cmd_flower('\uf6fa'),
        cmd_flower_outline('\uf6f6'),
        cmd_flower_poppy('\uf6f7'),
        cmd_flower_tulip('\uf6f9'),
        cmd_flower_tulip_outline('\uf6f8'),
        cmd_focus_auto('\uf6fb'),
        cmd_focus_field('\uf6fe'),
        cmd_focus_field_horizontal('\uf6fc'),
        cmd_focus_field_vertical('\uf6fd'),
        cmd_folder('\uf73d'),
        cmd_folder_account('\uf700'),
        cmd_folder_account_outline('\uf6ff'),
        cmd_folder_alert('\uf702'),
        cmd_folder_alert_outline('\uf701'),
        cmd_folder_clock('\uf704'),
        cmd_folder_clock_outline('\uf703'),
        cmd_folder_download('\uf706'),
        cmd_folder_download_outline('\uf705'),
        cmd_folder_edit('\uf708'),
        cmd_folder_edit_outline('\uf707'),
        cmd_folder_google_drive('\uf709'),
        cmd_folder_heart('\uf70b'),
        cmd_folder_heart_outline('\uf70a'),
        cmd_folder_home('\uf70d'),
        cmd_folder_home_outline('\uf70c'),
        cmd_folder_image('\uf70e'),
        cmd_folder_information('\uf710'),
        cmd_folder_information_outline('\uf70f'),
        cmd_folder_key('\uf714'),
        cmd_folder_key_network('\uf712'),
        cmd_folder_key_network_outline('\uf711'),
        cmd_folder_key_outline('\uf713'),
        cmd_folder_lock('\uf716'),
        cmd_folder_lock_open('\uf715'),
        cmd_folder_marker('\uf718'),
        cmd_folder_marker_outline('\uf717'),
        cmd_folder_move('\uf71a'),
        cmd_folder_move_outline('\uf719'),
        cmd_folder_multiple('\uf71d'),
        cmd_folder_multiple_image('\uf71b'),
        cmd_folder_multiple_outline('\uf71c'),
        cmd_folder_network('\uf71f'),
        cmd_folder_network_outline('\uf71e'),
        cmd_folder_open('\uf721'),
        cmd_folder_open_outline('\uf720'),
        cmd_folder_outline('\uf722'),
        cmd_folder_plus('\uf724'),
        cmd_folder_plus_outline('\uf723'),
        cmd_folder_pound('\uf726'),
        cmd_folder_pound_outline('\uf725'),
        cmd_folder_remove('\uf728'),
        cmd_folder_remove_outline('\uf727'),
        cmd_folder_search('\uf72a'),
        cmd_folder_search_outline('\uf729'),
        cmd_folder_settings('\uf72e'),
        cmd_folder_settings_outline('\uf72b'),
        cmd_folder_settings_variant('\uf72d'),
        cmd_folder_settings_variant_outline('\uf72c'),
        cmd_folder_star('\uf730'),
        cmd_folder_star_outline('\uf72f'),
        cmd_folder_swap('\uf732'),
        cmd_folder_swap_outline('\uf731'),
        cmd_folder_sync('\uf734'),
        cmd_folder_sync_outline('\uf733'),
        cmd_folder_table('\uf736'),
        cmd_folder_table_outline('\uf735'),
        cmd_folder_text('\uf738'),
        cmd_folder_text_outline('\uf737'),
        cmd_folder_upload('\uf73a'),
        cmd_folder_upload_outline('\uf739'),
        cmd_folder_zip('\uf73c'),
        cmd_folder_zip_outline('\uf73b'),
        cmd_font_awesome('\uf73e'),
        cmd_food('\uf745'),
        cmd_food_apple('\uf740'),
        cmd_food_apple_outline('\uf73f'),
        cmd_food_croissant('\uf741'),
        cmd_food_fork_drink('\uf742'),
        cmd_food_off('\uf743'),
        cmd_food_variant('\uf744'),
        cmd_foot_print('\uf746'),
        cmd_football('\uf749'),
        cmd_football_australian('\uf747'),
        cmd_football_helmet('\uf748'),
        cmd_forklift('\uf74a'),
        cmd_format_align_bottom('\uf74b'),
        cmd_format_align_center('\uf74c'),
        cmd_format_align_justify('\uf74d'),
        cmd_format_align_left('\uf74e'),
        cmd_format_align_middle('\uf74f'),
        cmd_format_align_right('\uf750'),
        cmd_format_align_top('\uf751'),
        cmd_format_annotation_minus('\uf752'),
        cmd_format_annotation_plus('\uf753'),
        cmd_format_bold('\uf754'),
        cmd_format_clear('\uf755'),
        cmd_format_color_fill('\uf756'),
        cmd_format_color_highlight('\uf757'),
        cmd_format_color_text('\uf758'),
        cmd_format_columns('\uf759'),
        cmd_format_float_center('\uf75a'),
        cmd_format_float_left('\uf75b'),
        cmd_format_float_none('\uf75c'),
        cmd_format_float_right('\uf75d'),
        cmd_format_font('\uf760'),
        cmd_format_font_size_decrease('\uf75e'),
        cmd_format_font_size_increase('\uf75f'),
        cmd_format_header_1('\uf761'),
        cmd_format_header_2('\uf762'),
        cmd_format_header_3('\uf763'),
        cmd_format_header_4('\uf764'),
        cmd_format_header_5('\uf765'),
        cmd_format_header_6('\uf766'),
        cmd_format_header_decrease('\uf767'),
        cmd_format_header_equal('\uf768'),
        cmd_format_header_increase('\uf769'),
        cmd_format_header_pound('\uf76a'),
        cmd_format_horizontal_align_center('\uf76b'),
        cmd_format_horizontal_align_left('\uf76c'),
        cmd_format_horizontal_align_right('\uf76d'),
        cmd_format_indent_decrease('\uf76e'),
        cmd_format_indent_increase('\uf76f'),
        cmd_format_italic('\uf770'),
        cmd_format_letter_case('\uf773'),
        cmd_format_letter_case_lower('\uf771'),
        cmd_format_letter_case_upper('\uf772'),
        cmd_format_letter_ends_with('\uf774'),
        cmd_format_letter_matches('\uf775'),
        cmd_format_letter_starts_with('\uf776'),
        cmd_format_line_spacing('\uf777'),
        cmd_format_line_style('\uf778'),
        cmd_format_line_weight('\uf779'),
        cmd_format_list_bulleted('\uf77d'),
        cmd_format_list_bulleted_square('\uf77a'),
        cmd_format_list_bulleted_triangle('\uf77b'),
        cmd_format_list_bulleted_type('\uf77c'),
        cmd_format_list_checkbox('\uf77e'),
        cmd_format_list_checks('\uf77f'),
        cmd_format_list_numbered('\uf781'),
        cmd_format_list_numbered_rtl('\uf780'),
        cmd_format_list_text('\uf782'),
        cmd_format_overline('\uf783'),
        cmd_format_page_break('\uf784'),
        cmd_format_paint('\uf785'),
        cmd_format_paragraph('\uf786'),
        cmd_format_pilcrow('\uf787'),
        cmd_format_quote_close('\uf789'),
        cmd_format_quote_close_outline('\uf788'),
        cmd_format_quote_open('\uf78b'),
        cmd_format_quote_open_outline('\uf78a'),
        cmd_format_rotate_90('\uf78c'),
        cmd_format_section('\uf78d'),
        cmd_format_size('\uf78e'),
        cmd_format_strikethrough('\uf790'),
        cmd_format_strikethrough_variant('\uf78f'),
        cmd_format_subscript('\uf791'),
        cmd_format_superscript('\uf792'),
        cmd_format_text('\uf79e'),
        cmd_format_text_rotation_angle_down('\uf793'),
        cmd_format_text_rotation_angle_up('\uf794'),
        cmd_format_text_rotation_down('\uf796'),
        cmd_format_text_rotation_down_vertical('\uf795'),
        cmd_format_text_rotation_none('\uf797'),
        cmd_format_text_rotation_up('\uf798'),
        cmd_format_text_rotation_vertical('\uf799'),
        cmd_format_text_variant('\uf79a'),
        cmd_format_text_wrapping_clip('\uf79b'),
        cmd_format_text_wrapping_overflow('\uf79c'),
        cmd_format_text_wrapping_wrap('\uf79d'),
        cmd_format_textbox('\uf79f'),
        cmd_format_textdirection_l_to_r('\uf7a0'),
        cmd_format_textdirection_r_to_l('\uf7a1'),
        cmd_format_title('\uf7a2'),
        cmd_format_underline('\uf7a3'),
        cmd_format_vertical_align_bottom('\uf7a4'),
        cmd_format_vertical_align_center('\uf7a5'),
        cmd_format_vertical_align_top('\uf7a6'),
        cmd_format_wrap_inline('\uf7a7'),
        cmd_format_wrap_square('\uf7a8'),
        cmd_format_wrap_tight('\uf7a9'),
        cmd_format_wrap_top_bottom('\uf7aa'),
        cmd_forum('\uf7ac'),
        cmd_forum_outline('\uf7ab'),
        cmd_forward('\uf7ad'),
        cmd_forwardburger('\uf7ae'),
        cmd_fountain('\uf7b1'),
        cmd_fountain_pen('\uf7b0'),
        cmd_fountain_pen_tip('\uf7af'),
        cmd_foursquare('\uf7b2'),
        cmd_freebsd('\uf7b3'),
        cmd_frequently_asked_questions('\uf7b4'),
        cmd_fridge('\uf7bc'),
        cmd_fridge_alert('\uf7b6'),
        cmd_fridge_alert_outline('\uf7b5'),
        cmd_fridge_bottom('\uf7b7'),
        cmd_fridge_off('\uf7b9'),
        cmd_fridge_off_outline('\uf7b8'),
        cmd_fridge_outline('\uf7ba'),
        cmd_fridge_top('\uf7bb'),
        cmd_fruit_cherries('\uf7bd'),
        cmd_fruit_citrus('\uf7be'),
        cmd_fruit_grapes('\uf7c0'),
        cmd_fruit_grapes_outline('\uf7bf'),
        cmd_fruit_pineapple('\uf7c1'),
        cmd_fruit_watermelon('\uf7c2'),
        cmd_fuel('\uf7c3'),
        cmd_fullscreen('\uf7c5'),
        cmd_fullscreen_exit('\uf7c4'),
        cmd_function('\uf7c7'),
        cmd_function_variant('\uf7c6'),
        cmd_furigana_horizontal('\uf7c8'),
        cmd_furigana_vertical('\uf7c9'),
        cmd_fuse('\uf7cb'),
        cmd_fuse_blade('\uf7ca'),
        cmd_gamepad('\uf7e0'),
        cmd_gamepad_circle('\uf7d1'),
        cmd_gamepad_circle_down('\uf7cc'),
        cmd_gamepad_circle_left('\uf7cd'),
        cmd_gamepad_circle_outline('\uf7ce'),
        cmd_gamepad_circle_right('\uf7cf'),
        cmd_gamepad_circle_up('\uf7d0'),
        cmd_gamepad_down('\uf7d2'),
        cmd_gamepad_left('\uf7d3'),
        cmd_gamepad_right('\uf7d4'),
        cmd_gamepad_round('\uf7da'),
        cmd_gamepad_round_down('\uf7d5'),
        cmd_gamepad_round_left('\uf7d6'),
        cmd_gamepad_round_outline('\uf7d7'),
        cmd_gamepad_round_right('\uf7d8'),
        cmd_gamepad_round_up('\uf7d9'),
        cmd_gamepad_square('\uf7dc'),
        cmd_gamepad_square_outline('\uf7db'),
        cmd_gamepad_up('\uf7dd'),
        cmd_gamepad_variant('\uf7df'),
        cmd_gamepad_variant_outline('\uf7de'),
        cmd_gamma('\uf7e1'),
        cmd_gantry_crane('\uf7e2'),
        cmd_garage('\uf7e8'),
        cmd_garage_alert('\uf7e4'),
        cmd_garage_alert_variant('\uf7e3'),
        cmd_garage_open('\uf7e6'),
        cmd_garage_open_variant('\uf7e5'),
        cmd_garage_variant('\uf7e7'),
        cmd_gas_cylinder('\uf7e9'),
        cmd_gas_station('\uf7eb'),
        cmd_gas_station_outline('\uf7ea'),
        cmd_gate('\uf7f5'),
        cmd_gate_and('\uf7ec'),
        cmd_gate_arrow_right('\uf7ed'),
        cmd_gate_nand('\uf7ee'),
        cmd_gate_nor('\uf7ef'),
        cmd_gate_not('\uf7f0'),
        cmd_gate_open('\uf7f1'),
        cmd_gate_or('\uf7f2'),
        cmd_gate_xnor('\uf7f3'),
        cmd_gate_xor('\uf7f4'),
        cmd_gatsby('\uf7f6'),
        cmd_gauge('\uf7fa'),
        cmd_gauge_empty('\uf7f7'),
        cmd_gauge_full('\uf7f8'),
        cmd_gauge_low('\uf7f9'),
        cmd_gavel('\uf7fb'),
        cmd_gender_female('\uf7fc'),
        cmd_gender_male('\uf7ff'),
        cmd_gender_male_female('\uf7fe'),
        cmd_gender_male_female_variant('\uf7fd'),
        cmd_gender_non_binary('\uf800'),
        cmd_gender_transgender('\uf801'),
        cmd_gentoo('\uf802'),
        cmd_gesture('\uf813'),
        cmd_gesture_double_tap('\uf803'),
        cmd_gesture_pinch('\uf804'),
        cmd_gesture_spread('\uf805'),
        cmd_gesture_swipe('\uf80c'),
        cmd_gesture_swipe_down('\uf806'),
        cmd_gesture_swipe_horizontal('\uf807'),
        cmd_gesture_swipe_left('\uf808'),
        cmd_gesture_swipe_right('\uf809'),
        cmd_gesture_swipe_up('\uf80a'),
        cmd_gesture_swipe_vertical('\uf80b'),
        cmd_gesture_tap('\uf810'),
        cmd_gesture_tap_box('\uf80d'),
        cmd_gesture_tap_button('\uf80e'),
        cmd_gesture_tap_hold('\uf80f'),
        cmd_gesture_two_double_tap('\uf811'),
        cmd_gesture_two_tap('\uf812'),
        cmd_ghost('\uf815'),
        cmd_ghost_off('\uf814'),
        cmd_gif('\uf816'),
        cmd_gift('\uf818'),
        cmd_gift_outline('\uf817'),
        cmd_git('\uf819'),
        cmd_github_box('\uf81a'),
        cmd_github_circle('\uf81b'),
        cmd_github_face('\uf81c'),
        cmd_gitlab('\uf81d'),
        cmd_glass_cocktail('\uf81e'),
        cmd_glass_flute('\uf81f'),
        cmd_glass_mug('\uf821'),
        cmd_glass_mug_variant('\uf820'),
        cmd_glass_stange('\uf822'),
        cmd_glass_tulip('\uf823'),
        cmd_glass_wine('\uf824'),
        cmd_glassdoor('\uf825'),
        cmd_glasses('\uf826'),
        cmd_globe_light('\uf827'),
        cmd_globe_model('\uf828'),
        cmd_gmail('\uf829'),
        cmd_gnome('\uf82a'),
        cmd_go_kart('\uf82c'),
        cmd_go_kart_track('\uf82b'),
        cmd_gog('\uf82d'),
        cmd_gold('\uf82e'),
        cmd_golf('\uf831'),
        cmd_golf_cart('\uf82f'),
        cmd_golf_tee('\uf830'),
        cmd_gondola('\uf832'),
        cmd_goodreads('\uf833'),
        cmd_google('\uf856'),
        cmd_google_adwords('\uf834'),
        cmd_google_analytics('\uf835'),
        cmd_google_assistant('\uf836'),
        cmd_google_cardboard('\uf837'),
        cmd_google_chrome('\uf838'),
        cmd_google_circles('\uf83c'),
        cmd_google_circles_communities('\uf839'),
        cmd_google_circles_extended('\uf83a'),
        cmd_google_circles_group('\uf83b'),
        cmd_google_classroom('\uf83d'),
        cmd_google_cloud('\uf83e'),
        cmd_google_controller('\uf840'),
        cmd_google_controller_off('\uf83f'),
        cmd_google_drive('\uf841'),
        cmd_google_earth('\uf842'),
        cmd_google_fit('\uf843'),
        cmd_google_glass('\uf844'),
        cmd_google_hangouts('\uf845'),
        cmd_google_home('\uf846'),
        cmd_google_keep('\uf847'),
        cmd_google_lens('\uf848'),
        cmd_google_maps('\uf849'),
        cmd_google_my_business('\uf84a'),
        cmd_google_nearby('\uf84b'),
        cmd_google_pages('\uf84c'),
        cmd_google_photos('\uf84d'),
        cmd_google_physical_web('\uf84e'),
        cmd_google_play('\uf84f'),
        cmd_google_plus('\uf851'),
        cmd_google_plus_box('\uf850'),
        cmd_google_podcast('\uf852'),
        cmd_google_spreadsheet('\uf853'),
        cmd_google_street_view('\uf854'),
        cmd_google_translate('\uf855'),
        cmd_gradient('\uf857'),
        cmd_grain('\uf858'),
        cmd_graph('\uf85a'),
        cmd_graph_outline('\uf859'),
        cmd_graphql('\uf85b'),
        cmd_grave_stone('\uf85c'),
        cmd_grease_pencil('\uf85d'),
        cmd_greater_than('\uf85f'),
        cmd_greater_than_or_equal('\uf85e'),
        cmd_grid('\uf862'),
        cmd_grid_large('\uf860'),
        cmd_grid_off('\uf861'),
        cmd_grill('\uf864'),
        cmd_grill_outline('\uf863'),
        cmd_group('\uf865'),
        cmd_guitar_acoustic('\uf866'),
        cmd_guitar_electric('\uf867'),
        cmd_guitar_pick('\uf869'),
        cmd_guitar_pick_outline('\uf868'),
        cmd_guy_fawkes_mask('\uf86a');

        override val typeface: ITypeface by lazy { CommunityMaterial }
    }

    enum class Icon2 constructor(override val character: Char) : IIcon {

        cmd_hackernews('\uf86b'),
        cmd_hail('\uf86c'),
        cmd_hair_dryer('\ued8d'),
        cmd_hair_dryer_outline('\ued8c'),
        cmd_halloween('\ued8e'),
        cmd_hamburger('\ued8f'),
        cmd_hammer('\ued90'),
        cmd_hand('\ued9c'),
        cmd_hand_heart('\ued91'),
        cmd_hand_left('\ued92'),
        cmd_hand_okay('\ued93'),
        cmd_hand_peace('\ued95'),
        cmd_hand_peace_variant('\ued94'),
        cmd_hand_pointing_down('\ued96'),
        cmd_hand_pointing_left('\ued97'),
        cmd_hand_pointing_right('\ued98'),
        cmd_hand_pointing_up('\ued99'),
        cmd_hand_right('\ued9a'),
        cmd_hand_saw('\ued9b'),
        cmd_handball('\ued9d'),
        cmd_handcuffs('\ued9e'),
        cmd_handshake('\ued9f'),
        cmd_hanger('\ueda0'),
        cmd_hard_hat('\ueda1'),
        cmd_harddisk('\ueda4'),
        cmd_harddisk_plus('\ueda2'),
        cmd_harddisk_remove('\ueda3'),
        cmd_hat_fedora('\ueda5'),
        cmd_hazard_lights('\ueda6'),
        cmd_hdr('\ueda8'),
        cmd_hdr_off('\ueda7'),
        cmd_headphones('\uedad'),
        cmd_headphones_bluetooth('\ueda9'),
        cmd_headphones_box('\uedaa'),
        cmd_headphones_off('\uedab'),
        cmd_headphones_settings('\uedac'),
        cmd_headset('\uedb0'),
        cmd_headset_dock('\uedae'),
        cmd_headset_off('\uedaf'),
        cmd_heart('\uedc0'),
        cmd_heart_box('\uedb2'),
        cmd_heart_box_outline('\uedb1'),
        cmd_heart_broken('\uedb4'),
        cmd_heart_broken_outline('\uedb3'),
        cmd_heart_circle('\uedb6'),
        cmd_heart_circle_outline('\uedb5'),
        cmd_heart_flash('\uedb7'),
        cmd_heart_half('\uedba'),
        cmd_heart_half_full('\uedb8'),
        cmd_heart_half_outline('\uedb9'),
        cmd_heart_multiple('\uedbc'),
        cmd_heart_multiple_outline('\uedbb'),
        cmd_heart_off('\uedbd'),
        cmd_heart_outline('\uedbe'),
        cmd_heart_pulse('\uedbf'),
        cmd_helicopter('\uedc1'),
        cmd_help('\uedc9'),
        cmd_help_box('\uedc2'),
        cmd_help_circle('\uedc4'),
        cmd_help_circle_outline('\uedc3'),
        cmd_help_network('\uedc6'),
        cmd_help_network_outline('\uedc5'),
        cmd_help_rhombus('\uedc8'),
        cmd_help_rhombus_outline('\uedc7'),
        cmd_hexadecimal('\uedca'),
        cmd_hexagon('\uedd4'),
        cmd_hexagon_multiple('\uedcc'),
        cmd_hexagon_multiple_outline('\uedcb'),
        cmd_hexagon_outline('\uedcd'),
        cmd_hexagon_slice_1('\uedce'),
        cmd_hexagon_slice_2('\uedcf'),
        cmd_hexagon_slice_3('\uedd0'),
        cmd_hexagon_slice_4('\uedd1'),
        cmd_hexagon_slice_5('\uedd2'),
        cmd_hexagon_slice_6('\uedd3'),
        cmd_hexagram('\uedd6'),
        cmd_hexagram_outline('\uedd5'),
        cmd_high_definition('\uedd8'),
        cmd_high_definition_box('\uedd7'),
        cmd_highway('\uedd9'),
        cmd_hiking('\uedda'),
        cmd_hinduism('\ueddb'),
        cmd_history('\ueddc'),
        cmd_hockey_puck('\ueddd'),
        cmd_hockey_sticks('\uedde'),
        cmd_hololens('\ueddf'),
        cmd_home('\uee09'),
        cmd_home_account('\uede0'),
        cmd_home_alert('\uede1'),
        cmd_home_analytics('\uede2'),
        cmd_home_assistant('\uede3'),
        cmd_home_automation('\uede4'),
        cmd_home_circle('\uede6'),
        cmd_home_circle_outline('\uede5'),
        cmd_home_city('\uede8'),
        cmd_home_city_outline('\uede7'),
        cmd_home_currency_usd('\uede9'),
        cmd_home_edit('\uedeb'),
        cmd_home_edit_outline('\uedea'),
        cmd_home_export_outline('\uedec'),
        cmd_home_flood('\ueded'),
        cmd_home_floor_0('\uedee'),
        cmd_home_floor_1('\uedef'),
        cmd_home_floor_2('\uedf0'),
        cmd_home_floor_3('\uedf1'),
        cmd_home_floor_a('\uedf2'),
        cmd_home_floor_b('\uedf3'),
        cmd_home_floor_g('\uedf4'),
        cmd_home_floor_l('\uedf5'),
        cmd_home_floor_negative_1('\uedf6'),
        cmd_home_group('\uedf7'),
        cmd_home_heart('\uedf8'),
        cmd_home_import_outline('\uedf9'),
        cmd_home_lightbulb('\uedfb'),
        cmd_home_lightbulb_outline('\uedfa'),
        cmd_home_lock('\uedfd'),
        cmd_home_lock_open('\uedfc'),
        cmd_home_map_marker('\uedfe'),
        cmd_home_minus('\uedff'),
        cmd_home_modern('\uee00'),
        cmd_home_outline('\uee01'),
        cmd_home_plus('\uee02'),
        cmd_home_remove('\uee03'),
        cmd_home_roof('\uee04'),
        cmd_home_thermometer('\uee06'),
        cmd_home_thermometer_outline('\uee05'),
        cmd_home_variant('\uee08'),
        cmd_home_variant_outline('\uee07'),
        cmd_hook('\uee0b'),
        cmd_hook_off('\uee0a'),
        cmd_hops('\uee0c'),
        cmd_horizontal_rotate_clockwise('\uee0d'),
        cmd_horizontal_rotate_counterclockwise('\uee0e'),
        cmd_horseshoe('\uee0f'),
        cmd_hospital('\uee14'),
        cmd_hospital_box('\uee11'),
        cmd_hospital_box_outline('\uee10'),
        cmd_hospital_building('\uee12'),
        cmd_hospital_marker('\uee13'),
        cmd_hot_tub('\uee15'),
        cmd_hotel('\uee16'),
        cmd_houzz('\uee18'),
        cmd_houzz_box('\uee17'),
        cmd_hubspot('\uee19'),
        cmd_hulu('\uee1a'),
        cmd_human('\uee2b'),
        cmd_human_child('\uee1b'),
        cmd_human_female('\uee1f'),
        cmd_human_female_boy('\uee1c'),
        cmd_human_female_female('\uee1d'),
        cmd_human_female_girl('\uee1e'),
        cmd_human_greeting('\uee20'),
        cmd_human_handsdown('\uee21'),
        cmd_human_handsup('\uee22'),
        cmd_human_male('\uee29'),
        cmd_human_male_boy('\uee23'),
        cmd_human_male_female('\uee24'),
        cmd_human_male_girl('\uee25'),
        cmd_human_male_height('\uee27'),
        cmd_human_male_height_variant('\uee26'),
        cmd_human_male_male('\uee28'),
        cmd_human_pregnant('\uee2a'),
        cmd_humble_bundle('\uee2c'),
        cmd_hydro_power('\uee2d'),
        cmd_ice_cream('\uee2e'),
        cmd_ice_pop('\uee2f'),
        cmd_id_card('\uee30'),
        cmd_identifier('\uee31'),
        cmd_iframe('\uee3b'),
        cmd_iframe_array('\uee33'),
        cmd_iframe_array_outline('\uee32'),
        cmd_iframe_braces('\uee35'),
        cmd_iframe_braces_outline('\uee34'),
        cmd_iframe_outline('\uee36'),
        cmd_iframe_parentheses('\uee38'),
        cmd_iframe_parentheses_outline('\uee37'),
        cmd_iframe_variable('\uee3a'),
        cmd_iframe_variable_outline('\uee39'),
        cmd_image('\uee5c'),
        cmd_image_album('\uee3c'),
        cmd_image_area('\uee3e'),
        cmd_image_area_close('\uee3d'),
        cmd_image_auto_adjust('\uee3f'),
        cmd_image_broken('\uee41'),
        cmd_image_broken_variant('\uee40'),
        cmd_image_edit('\uee43'),
        cmd_image_edit_outline('\uee42'),
        cmd_image_filter('\uee4f'),
        cmd_image_filter_black_white('\uee44'),
        cmd_image_filter_center_focus('\uee48'),
        cmd_image_filter_center_focus_strong('\uee46'),
        cmd_image_filter_center_focus_strong_outline('\uee45'),
        cmd_image_filter_center_focus_weak('\uee47'),
        cmd_image_filter_drama('\uee49'),
        cmd_image_filter_frames('\uee4a'),
        cmd_image_filter_hdr('\uee4b'),
        cmd_image_filter_none('\uee4c'),
        cmd_image_filter_tilt_shift('\uee4d'),
        cmd_image_filter_vintage('\uee4e'),
        cmd_image_frame('\uee50'),
        cmd_image_move('\uee51'),
        cmd_image_multiple('\uee52'),
        cmd_image_off('\uee54'),
        cmd_image_off_outline('\uee53'),
        cmd_image_outline('\uee55'),
        cmd_image_plus('\uee56'),
        cmd_image_search('\uee58'),
        cmd_image_search_outline('\uee57'),
        cmd_image_size_select_actual('\uee59'),
        cmd_image_size_select_large('\uee5a'),
        cmd_image_size_select_small('\uee5b'),
        cmd_import('\uee5d'),
        cmd_inbox('\uee67'),
        cmd_inbox_arrow_down('\uee5f'),
        cmd_inbox_arrow_down_outline('\uee5e'),
        cmd_inbox_arrow_up('\uee61'),
        cmd_inbox_arrow_up_outline('\uee60'),
        cmd_inbox_full('\uee63'),
        cmd_inbox_full_outline('\uee62'),
        cmd_inbox_multiple('\uee65'),
        cmd_inbox_multiple_outline('\uee64'),
        cmd_inbox_outline('\uee66'),
        cmd_incognito('\uee68'),
        cmd_infinity('\uee69'),
        cmd_information('\uee6c'),
        cmd_information_outline('\uee6a'),
        cmd_information_variant('\uee6b'),
        cmd_instagram('\uee6d'),
        cmd_instapaper('\uee6e'),
        cmd_instrument_triangle('\uee6f'),
        cmd_internet_explorer('\uee70'),
        cmd_invert_colors('\uee72'),
        cmd_invert_colors_off('\uee71'),
        cmd_ip('\uee75'),
        cmd_ip_network('\uee74'),
        cmd_ip_network_outline('\uee73'),
        cmd_ipod('\uee76'),
        cmd_islam('\uee77'),
        cmd_island('\uee78'),
        cmd_itunes('\uee79'),
        cmd_iv_bag('\uee7a'),
        cmd_jabber('\uee7b'),
        cmd_jeepney('\uee7c'),
        cmd_jellyfish('\uee7e'),
        cmd_jellyfish_outline('\uee7d'),
        cmd_jira('\uee7f'),
        cmd_jquery('\uee80'),
        cmd_jsfiddle('\uee81'),
        cmd_json('\uee82'),
        cmd_judaism('\uee83'),
        cmd_kabaddi('\uee84'),
        cmd_karate('\uee85'),
        cmd_keg('\uee86'),
        cmd_kettle('\uee88'),
        cmd_kettle_outline('\uee87'),
        cmd_key('\uee92'),
        cmd_key_change('\uee89'),
        cmd_key_link('\uee8a'),
        cmd_key_minus('\uee8b'),
        cmd_key_outline('\uee8c'),
        cmd_key_plus('\uee8d'),
        cmd_key_remove('\uee8e'),
        cmd_key_star('\uee8f'),
        cmd_key_variant('\uee90'),
        cmd_key_wireless('\uee91'),
        cmd_keyboard('\ueeac'),
        cmd_keyboard_backspace('\uee93'),
        cmd_keyboard_caps('\uee94'),
        cmd_keyboard_close('\uee95'),
        cmd_keyboard_esc('\uee96'),
        cmd_keyboard_f1('\uee97'),
        cmd_keyboard_f10('\ueea0'),
        cmd_keyboard_f11('\ueea1'),
        cmd_keyboard_f12('\ueea2'),
        cmd_keyboard_f2('\uee98'),
        cmd_keyboard_f3('\uee99'),
        cmd_keyboard_f4('\uee9a'),
        cmd_keyboard_f5('\uee9b'),
        cmd_keyboard_f6('\uee9c'),
        cmd_keyboard_f7('\uee9d'),
        cmd_keyboard_f8('\uee9e'),
        cmd_keyboard_f9('\uee9f'),
        cmd_keyboard_off('\ueea4'),
        cmd_keyboard_off_outline('\ueea3'),
        cmd_keyboard_outline('\ueea5'),
        cmd_keyboard_return('\ueea6'),
        cmd_keyboard_settings('\ueea8'),
        cmd_keyboard_settings_outline('\ueea7'),
        cmd_keyboard_space('\ueea9'),
        cmd_keyboard_tab('\ueeaa'),
        cmd_keyboard_variant('\ueeab'),
        cmd_khanda('\ueead'),
        cmd_kickstarter('\ueeae'),
        cmd_knife('\ueeb0'),
        cmd_knife_military('\ueeaf'),
        cmd_kodi('\ueeb1'),
        cmd_kotlin('\ueeb2'),
        cmd_kubernetes('\ueeb3'),
        cmd_label('\ueeb9'),
        cmd_label_off('\ueeb5'),
        cmd_label_off_outline('\ueeb4'),
        cmd_label_outline('\ueeb6'),
        cmd_label_variant('\ueeb8'),
        cmd_label_variant_outline('\ueeb7'),
        cmd_ladybug('\ueeba'),
        cmd_lambda('\ueebb'),
        cmd_lamp('\ueebc'),
        cmd_lan('\ueec1'),
        cmd_lan_check('\ueebd'),
        cmd_lan_connect('\ueebe'),
        cmd_lan_disconnect('\ueebf'),
        cmd_lan_pending('\ueec0'),
        cmd_language_c('\ueec2'),
        cmd_language_cpp('\ueec3'),
        cmd_language_csharp('\ueec4'),
        cmd_language_css3('\ueec5'),
        cmd_language_fortran('\ueec6'),
        cmd_language_go('\ueec7'),
        cmd_language_haskell('\ueec8'),
        cmd_language_html5('\ueec9'),
        cmd_language_java('\ueeca'),
        cmd_language_javascript('\ueecb'),
        cmd_language_lua('\ueecc'),
        cmd_language_php('\ueecd'),
        cmd_language_python('\ueecf'),
        cmd_language_python_text('\ueece'),
        cmd_language_r('\ueed0'),
        cmd_language_ruby_on_rails('\ueed1'),
        cmd_language_swift('\ueed2'),
        cmd_language_typescript('\ueed3'),
        cmd_laptop('\ueed8'),
        cmd_laptop_chromebook('\ueed4'),
        cmd_laptop_mac('\ueed5'),
        cmd_laptop_off('\ueed6'),
        cmd_laptop_windows('\ueed7'),
        cmd_laravel('\ueed9'),
        cmd_lasso('\ueeda'),
        cmd_lastfm('\ueedb'),
        cmd_lastpass('\ueedc'),
        cmd_latitude('\ueedd'),
        cmd_launch('\ueede'),
        cmd_lava_lamp('\ueedf'),
        cmd_layers('\ueeea'),
        cmd_layers_minus('\ueee0'),
        cmd_layers_off('\ueee2'),
        cmd_layers_off_outline('\ueee1'),
        cmd_layers_outline('\ueee3'),
        cmd_layers_plus('\ueee4'),
        cmd_layers_remove('\ueee5'),
        cmd_layers_search('\ueee7'),
        cmd_layers_search_outline('\ueee6'),
        cmd_layers_triple('\ueee9'),
        cmd_layers_triple_outline('\ueee8'),
        cmd_lead_pencil('\ueeeb'),
        cmd_leaf('\ueeef'),
        cmd_leaf_maple('\ueeed'),
        cmd_leaf_maple_off('\ueeec'),
        cmd_leaf_off('\ueeee'),
        cmd_leak('\ueef1'),
        cmd_leak_off('\ueef0'),
        cmd_led_off('\ueef2'),
        cmd_led_on('\ueef3'),
        cmd_led_outline('\ueef4'),
        cmd_led_strip('\ueef6'),
        cmd_led_strip_variant('\ueef5'),
        cmd_led_variant_off('\ueef7'),
        cmd_led_variant_on('\ueef8'),
        cmd_led_variant_outline('\ueef9'),
        cmd_leek('\ueefa'),
        cmd_less_than('\ueefc'),
        cmd_less_than_or_equal('\ueefb'),
        cmd_library('\uef03'),
        cmd_library_books('\ueefd'),
        cmd_library_movie('\ueefe'),
        cmd_library_music('\uef00'),
        cmd_library_music_outline('\ueeff'),
        cmd_library_shelves('\uef01'),
        cmd_library_video('\uef02'),
        cmd_license('\uef04'),
        cmd_lifebuoy('\uef05'),
        cmd_light_switch('\uef06'),
        cmd_lightbulb('\uef18'),
        cmd_lightbulb_cfl('\uef0a'),
        cmd_lightbulb_cfl_off('\uef07'),
        cmd_lightbulb_cfl_spiral('\uef09'),
        cmd_lightbulb_cfl_spiral_off('\uef08'),
        cmd_lightbulb_group('\uef0e'),
        cmd_lightbulb_group_off('\uef0c'),
        cmd_lightbulb_group_off_outline('\uef0b'),
        cmd_lightbulb_group_outline('\uef0d'),
        cmd_lightbulb_multiple('\uef12'),
        cmd_lightbulb_multiple_off('\uef10'),
        cmd_lightbulb_multiple_off_outline('\uef0f'),
        cmd_lightbulb_multiple_outline('\uef11'),
        cmd_lightbulb_off('\uef14'),
        cmd_lightbulb_off_outline('\uef13'),
        cmd_lightbulb_on('\uef16'),
        cmd_lightbulb_on_outline('\uef15'),
        cmd_lightbulb_outline('\uef17'),
        cmd_lighthouse('\uef1a'),
        cmd_lighthouse_on('\uef19'),
        cmd_link('\uef27'),
        cmd_link_box('\uef1e'),
        cmd_link_box_outline('\uef1b'),
        cmd_link_box_variant('\uef1d'),
        cmd_link_box_variant_outline('\uef1c'),
        cmd_link_lock('\uef1f'),
        cmd_link_off('\uef20'),
        cmd_link_plus('\uef21'),
        cmd_link_variant('\uef26'),
        cmd_link_variant_minus('\uef22'),
        cmd_link_variant_off('\uef23'),
        cmd_link_variant_plus('\uef24'),
        cmd_link_variant_remove('\uef25'),
        cmd_linkedin('\uef29'),
        cmd_linkedin_box('\uef28'),
        cmd_linux('\uef2b'),
        cmd_linux_mint('\uef2a'),
        cmd_litecoin('\uef2c'),
        cmd_loading('\uef2d'),
        cmd_location_enter('\uef2e'),
        cmd_location_exit('\uef2f'),
        cmd_lock('\uef3c'),
        cmd_lock_alert('\uef30'),
        cmd_lock_clock('\uef31'),
        cmd_lock_open('\uef35'),
        cmd_lock_open_outline('\uef32'),
        cmd_lock_open_variant('\uef34'),
        cmd_lock_open_variant_outline('\uef33'),
        cmd_lock_outline('\uef36'),
        cmd_lock_pattern('\uef37'),
        cmd_lock_plus('\uef38'),
        cmd_lock_question('\uef39'),
        cmd_lock_reset('\uef3a'),
        cmd_lock_smart('\uef3b'),
        cmd_locker('\uef3e'),
        cmd_locker_multiple('\uef3d'),
        cmd_login('\uef40'),
        cmd_login_variant('\uef3f'),
        cmd_logout('\uef42'),
        cmd_logout_variant('\uef41'),
        cmd_longitude('\uef43'),
        cmd_looks('\uef44'),
        cmd_loupe('\uef45'),
        cmd_lumx('\uef46'),
        cmd_lungs('\uef47'),
        cmd_lyft('\uef48'),
        cmd_magnet('\uef4a'),
        cmd_magnet_on('\uef49'),
        cmd_magnify('\uef55'),
        cmd_magnify_close('\uef4b'),
        cmd_magnify_minus('\uef4e'),
        cmd_magnify_minus_cursor('\uef4c'),
        cmd_magnify_minus_outline('\uef4d'),
        cmd_magnify_plus('\uef51'),
        cmd_magnify_plus_cursor('\uef4f'),
        cmd_magnify_plus_outline('\uef50'),
        cmd_magnify_remove_cursor('\uef52'),
        cmd_magnify_remove_outline('\uef53'),
        cmd_magnify_scan('\uef54'),
        cmd_mail('\uef57'),
        cmd_mail_ru('\uef56'),
        cmd_mailbox('\uef5f'),
        cmd_mailbox_open('\uef5b'),
        cmd_mailbox_open_outline('\uef58'),
        cmd_mailbox_open_up('\uef5a'),
        cmd_mailbox_open_up_outline('\uef59'),
        cmd_mailbox_outline('\uef5c'),
        cmd_mailbox_up('\uef5e'),
        cmd_mailbox_up_outline('\uef5d'),
        cmd_map('\uef82'),
        cmd_map_check('\uef61'),
        cmd_map_check_outline('\uef60'),
        cmd_map_clock('\uef63'),
        cmd_map_clock_outline('\uef62'),
        cmd_map_legend('\uef64'),
        cmd_map_marker('\uef7c'),
        cmd_map_marker_alert('\uef66'),
        cmd_map_marker_alert_outline('\uef65'),
        cmd_map_marker_check('\uef67'),
        cmd_map_marker_circle('\uef68'),
        cmd_map_marker_distance('\uef69'),
        cmd_map_marker_down('\uef6a'),
        cmd_map_marker_left('\uef6c'),
        cmd_map_marker_left_outline('\uef6b'),
        cmd_map_marker_minus('\uef6d'),
        cmd_map_marker_multiple('\uef6f'),
        cmd_map_marker_multiple_outline('\uef6e'),
        cmd_map_marker_off('\uef70'),
        cmd_map_marker_outline('\uef71'),
        cmd_map_marker_path('\uef72'),
        cmd_map_marker_plus('\uef73'),
        cmd_map_marker_question('\uef75'),
        cmd_map_marker_question_outline('\uef74'),
        cmd_map_marker_radius('\uef76'),
        cmd_map_marker_remove('\uef78'),
        cmd_map_marker_remove_variant('\uef77'),
        cmd_map_marker_right('\uef7a'),
        cmd_map_marker_right_outline('\uef79'),
        cmd_map_marker_up('\uef7b'),
        cmd_map_minus('\uef7d'),
        cmd_map_outline('\uef7e'),
        cmd_map_plus('\uef7f'),
        cmd_map_search('\uef81'),
        cmd_map_search_outline('\uef80'),
        cmd_mapbox('\uef83'),
        cmd_margin('\uef84'),
        cmd_markdown('\uef86'),
        cmd_markdown_outline('\uef85'),
        cmd_marker('\uef89'),
        cmd_marker_cancel('\uef87'),
        cmd_marker_check('\uef88'),
        cmd_mastodon('\uef8b'),
        cmd_mastodon_variant('\uef8a'),
        cmd_material_design('\uef8c'),
        cmd_material_ui('\uef8d'),
        cmd_math_compass('\uef8e'),
        cmd_math_cos('\uef8f'),
        cmd_math_integral('\uef91'),
        cmd_math_integral_box('\uef90'),
        cmd_math_log('\uef92'),
        cmd_math_norm('\uef94'),
        cmd_math_norm_box('\uef93'),
        cmd_math_sin('\uef95'),
        cmd_math_tan('\uef96'),
        cmd_matrix('\uef97'),
        cmd_medal('\uef98'),
        cmd_medical_bag('\uef99'),
        cmd_meditation('\uef9a'),
        cmd_medium('\uef9b'),
        cmd_meetup('\uef9c'),
        cmd_memory('\uef9d'),
        cmd_menu('\uefa9'),
        cmd_menu_down('\uef9f'),
        cmd_menu_down_outline('\uef9e'),
        cmd_menu_left('\uefa1'),
        cmd_menu_left_outline('\uefa0'),
        cmd_menu_open('\uefa2'),
        cmd_menu_right('\uefa4'),
        cmd_menu_right_outline('\uefa3'),
        cmd_menu_swap('\uefa6'),
        cmd_menu_swap_outline('\uefa5'),
        cmd_menu_up('\uefa8'),
        cmd_menu_up_outline('\uefa7'),
        cmd_merge('\uefaa'),
        cmd_message('\uefc8'),
        cmd_message_alert('\uefac'),
        cmd_message_alert_outline('\uefab'),
        cmd_message_bulleted('\uefae'),
        cmd_message_bulleted_off('\uefad'),
        cmd_message_draw('\uefaf'),
        cmd_message_image('\uefb1'),
        cmd_message_image_outline('\uefb0'),
        cmd_message_lock('\uefb3'),
        cmd_message_lock_outline('\uefb2'),
        cmd_message_minus('\uefb5'),
        cmd_message_minus_outline('\uefb4'),
        cmd_message_outline('\uefb6'),
        cmd_message_plus('\uefb8'),
        cmd_message_plus_outline('\uefb7'),
        cmd_message_processing('\uefba'),
        cmd_message_processing_outline('\uefb9'),
        cmd_message_reply('\uefbc'),
        cmd_message_reply_text('\uefbb'),
        cmd_message_settings('\uefc0'),
        cmd_message_settings_outline('\uefbd'),
        cmd_message_settings_variant('\uefbf'),
        cmd_message_settings_variant_outline('\uefbe'),
        cmd_message_text('\uefc6'),
        cmd_message_text_clock('\uefc2'),
        cmd_message_text_clock_outline('\uefc1'),
        cmd_message_text_lock('\uefc4'),
        cmd_message_text_lock_outline('\uefc3'),
        cmd_message_text_outline('\uefc5'),
        cmd_message_video('\uefc7'),
        cmd_meteor('\uefc9'),
        cmd_metronome('\uefcb'),
        cmd_metronome_tick('\uefca'),
        cmd_micro_sd('\uefcc'),
        cmd_microphone('\uefd4'),
        cmd_microphone_minus('\uefcd'),
        cmd_microphone_off('\uefce'),
        cmd_microphone_outline('\uefcf'),
        cmd_microphone_plus('\uefd0'),
        cmd_microphone_settings('\uefd1'),
        cmd_microphone_variant('\uefd3'),
        cmd_microphone_variant_off('\uefd2'),
        cmd_microscope('\uefd5'),
        cmd_microsoft('\uefd7'),
        cmd_microsoft_dynamics('\uefd6'),
        cmd_microwave('\uefd8'),
        cmd_middleware('\uefda'),
        cmd_middleware_outline('\uefd9'),
        cmd_midi('\uefdc'),
        cmd_midi_port('\uefdb'),
        cmd_mine('\uefdd'),
        cmd_minecraft('\uefde'),
        cmd_mini_sd('\uefdf'),
        cmd_minidisc('\uefe0'),
        cmd_minus('\uefe9'),
        cmd_minus_box('\uefe4'),
        cmd_minus_box_multiple('\uefe2'),
        cmd_minus_box_multiple_outline('\uefe1'),
        cmd_minus_box_outline('\uefe3'),
        cmd_minus_circle('\uefe6'),
        cmd_minus_circle_outline('\uefe5'),
        cmd_minus_network('\uefe8'),
        cmd_minus_network_outline('\uefe7'),
        cmd_mirror('\uefea'),
        cmd_mixcloud('\uefeb'),
        cmd_mixed_martial_arts('\uefec'),
        cmd_mixed_reality('\uefed'),
        cmd_mixer('\uefee'),
        cmd_molecule('\uefef'),
        cmd_monitor('\ueffc'),
        cmd_monitor_cellphone('\ueff1'),
        cmd_monitor_cellphone_star('\ueff0'),
        cmd_monitor_clean('\ueff2'),
        cmd_monitor_dashboard('\ueff3'),
        cmd_monitor_edit('\ueff4'),
        cmd_monitor_lock('\ueff5'),
        cmd_monitor_multiple('\ueff6'),
        cmd_monitor_off('\ueff7'),
        cmd_monitor_screenshot('\ueff8'),
        cmd_monitor_speaker('\ueffa'),
        cmd_monitor_speaker_off('\ueff9'),
        cmd_monitor_star('\ueffb'),
        cmd_moon_first_quarter('\ueffd'),
        cmd_moon_full('\ueffe'),
        cmd_moon_last_quarter('\uefff'),
        cmd_moon_new('\uf000'),
        cmd_moon_waning_crescent('\uf001'),
        cmd_moon_waning_gibbous('\uf002'),
        cmd_moon_waxing_crescent('\uf003'),
        cmd_moon_waxing_gibbous('\uf004'),
        cmd_moped('\uf005'),
        cmd_more('\uf006'),
        cmd_mother_nurse('\uf007'),
        cmd_motion_sensor('\uf008'),
        cmd_motorbike('\uf009'),
        cmd_mouse('\uf00e'),
        cmd_mouse_bluetooth('\uf00a'),
        cmd_mouse_off('\uf00b'),
        cmd_mouse_variant('\uf00d'),
        cmd_mouse_variant_off('\uf00c'),
        cmd_move_resize('\uf010'),
        cmd_move_resize_variant('\uf00f'),
        cmd_movie('\uf01b'),
        cmd_movie_edit('\uf012'),
        cmd_movie_edit_outline('\uf011'),
        cmd_movie_filter('\uf014'),
        cmd_movie_filter_outline('\uf013'),
        cmd_movie_open('\uf016'),
        cmd_movie_open_outline('\uf015'),
        cmd_movie_outline('\uf017'),
        cmd_movie_roll('\uf018'),
        cmd_movie_search('\uf01a'),
        cmd_movie_search_outline('\uf019'),
        cmd_muffin('\uf01c'),
        cmd_multiplication('\uf01e'),
        cmd_multiplication_box('\uf01d'),
        cmd_mushroom('\uf020'),
        cmd_mushroom_outline('\uf01f'),
        cmd_music('\uf044'),
        cmd_music_accidental_double_flat('\uf021'),
        cmd_music_accidental_double_sharp('\uf022'),
        cmd_music_accidental_flat('\uf023'),
        cmd_music_accidental_natural('\uf024'),
        cmd_music_accidental_sharp('\uf025'),
        cmd_music_box('\uf027'),
        cmd_music_box_outline('\uf026'),
        cmd_music_circle('\uf029'),
        cmd_music_circle_outline('\uf028'),
        cmd_music_clef_alto('\uf02a'),
        cmd_music_clef_bass('\uf02b'),
        cmd_music_clef_treble('\uf02c'),
        cmd_music_note('\uf03d'),
        cmd_music_note_bluetooth('\uf02e'),
        cmd_music_note_bluetooth_off('\uf02d'),
        cmd_music_note_eighth('\uf030'),
        cmd_music_note_eighth_dotted('\uf02f'),
        cmd_music_note_half('\uf032'),
        cmd_music_note_half_dotted('\uf031'),
        cmd_music_note_off('\uf034'),
        cmd_music_note_off_outline('\uf033'),
        cmd_music_note_outline('\uf035'),
        cmd_music_note_plus('\uf036'),
        cmd_music_note_quarter('\uf038'),
        cmd_music_note_quarter_dotted('\uf037'),
        cmd_music_note_sixteenth('\uf03a'),
        cmd_music_note_sixteenth_dotted('\uf039'),
        cmd_music_note_whole('\uf03c'),
        cmd_music_note_whole_dotted('\uf03b'),
        cmd_music_off('\uf03e'),
        cmd_music_rest_eighth('\uf03f'),
        cmd_music_rest_half('\uf040'),
        cmd_music_rest_quarter('\uf041'),
        cmd_music_rest_sixteenth('\uf042'),
        cmd_music_rest_whole('\uf043'),
        cmd_nail('\uf045'),
        cmd_nas('\uf046'),
        cmd_nativescript('\uf047'),
        cmd_nature('\uf049'),
        cmd_nature_people('\uf048'),
        cmd_navigation('\uf04a'),
        cmd_near_me('\uf04b'),
        cmd_necklace('\uf04c'),
        cmd_needle('\uf04d'),
        cmd_netflix('\uf04e'),
        cmd_network('\uf05e'),
        cmd_network_off('\uf050'),
        cmd_network_off_outline('\uf04f'),
        cmd_network_outline('\uf051'),
        cmd_network_router('\uf052'),
        cmd_network_strength_1('\uf054'),
        cmd_network_strength_1_alert('\uf053'),
        cmd_network_strength_2('\uf056'),
        cmd_network_strength_2_alert('\uf055'),
        cmd_network_strength_3('\uf058'),
        cmd_network_strength_3_alert('\uf057'),
        cmd_network_strength_4('\uf05a'),
        cmd_network_strength_4_alert('\uf059'),
        cmd_network_strength_off('\uf05c'),
        cmd_network_strength_off_outline('\uf05b'),
        cmd_network_strength_outline('\uf05d'),
        cmd_new_box('\uf05f'),
        cmd_newspaper('\uf066'),
        cmd_newspaper_minus('\uf060'),
        cmd_newspaper_plus('\uf061'),
        cmd_newspaper_variant('\uf065'),
        cmd_newspaper_variant_multiple('\uf063'),
        cmd_newspaper_variant_multiple_outline('\uf062'),
        cmd_newspaper_variant_outline('\uf064'),
        cmd_nfc('\uf06c'),
        cmd_nfc_off('\uf067'),
        cmd_nfc_search_variant('\uf068'),
        cmd_nfc_tap('\uf069'),
        cmd_nfc_variant('\uf06b'),
        cmd_nfc_variant_off('\uf06a'),
        cmd_ninja('\uf06d'),
        cmd_nintendo_switch('\uf06e'),
        cmd_nix('\uf06f'),
        cmd_nodejs('\uf070'),
        cmd_noodles('\uf071'),
        cmd_not_equal('\uf073'),
        cmd_not_equal_variant('\uf072'),
        cmd_note('\uf07b'),
        cmd_note_multiple('\uf075'),
        cmd_note_multiple_outline('\uf074'),
        cmd_note_outline('\uf076'),
        cmd_note_plus('\uf078'),
        cmd_note_plus_outline('\uf077'),
        cmd_note_text('\uf07a'),
        cmd_note_text_outline('\uf079'),
        cmd_notebook('\uf07e'),
        cmd_notebook_multiple('\uf07c'),
        cmd_notebook_outline('\uf07d'),
        cmd_notification_clear_all('\uf07f'),
        cmd_npm('\uf082'),
        cmd_npm_variant('\uf081'),
        cmd_npm_variant_outline('\uf080'),
        cmd_nuke('\uf083'),
        cmd_null('\uf084'),
        cmd_numeric('\uf0da'),
        cmd_numeric_0('\uf08b'),
        cmd_numeric_0_box('\uf088'),
        cmd_numeric_0_box_multiple('\uf086'),
        cmd_numeric_0_box_multiple_outline('\uf085'),
        cmd_numeric_0_box_outline('\uf087'),
        cmd_numeric_0_circle('\uf08a'),
        cmd_numeric_0_circle_outline('\uf089'),
        cmd_numeric_1('\uf092'),
        cmd_numeric_10('\uf0d8'),
        cmd_numeric_10_box('\uf0d5'),
        cmd_numeric_10_box_multiple('\uf0d3'),
        cmd_numeric_10_box_multiple_outline('\uf0d2'),
        cmd_numeric_10_box_outline('\uf0d4'),
        cmd_numeric_10_circle('\uf0d7'),
        cmd_numeric_10_circle_outline('\uf0d6'),
        cmd_numeric_1_box('\uf08f'),
        cmd_numeric_1_box_multiple('\uf08d'),
        cmd_numeric_1_box_multiple_outline('\uf08c'),
        cmd_numeric_1_box_outline('\uf08e'),
        cmd_numeric_1_circle('\uf091'),
        cmd_numeric_1_circle_outline('\uf090'),
        cmd_numeric_2('\uf099'),
        cmd_numeric_2_box('\uf096'),
        cmd_numeric_2_box_multiple('\uf094'),
        cmd_numeric_2_box_multiple_outline('\uf093'),
        cmd_numeric_2_box_outline('\uf095'),
        cmd_numeric_2_circle('\uf098'),
        cmd_numeric_2_circle_outline('\uf097'),
        cmd_numeric_3('\uf0a0'),
        cmd_numeric_3_box('\uf09d'),
        cmd_numeric_3_box_multiple('\uf09b'),
        cmd_numeric_3_box_multiple_outline('\uf09a'),
        cmd_numeric_3_box_outline('\uf09c'),
        cmd_numeric_3_circle('\uf09f'),
        cmd_numeric_3_circle_outline('\uf09e'),
        cmd_numeric_4('\uf0a7'),
        cmd_numeric_4_box('\uf0a4'),
        cmd_numeric_4_box_multiple('\uf0a2'),
        cmd_numeric_4_box_multiple_outline('\uf0a1'),
        cmd_numeric_4_box_outline('\uf0a3'),
        cmd_numeric_4_circle('\uf0a6'),
        cmd_numeric_4_circle_outline('\uf0a5'),
        cmd_numeric_5('\uf0ae'),
        cmd_numeric_5_box('\uf0ab'),
        cmd_numeric_5_box_multiple('\uf0a9'),
        cmd_numeric_5_box_multiple_outline('\uf0a8'),
        cmd_numeric_5_box_outline('\uf0aa'),
        cmd_numeric_5_circle('\uf0ad'),
        cmd_numeric_5_circle_outline('\uf0ac'),
        cmd_numeric_6('\uf0b5'),
        cmd_numeric_6_box('\uf0b2'),
        cmd_numeric_6_box_multiple('\uf0b0'),
        cmd_numeric_6_box_multiple_outline('\uf0af'),
        cmd_numeric_6_box_outline('\uf0b1'),
        cmd_numeric_6_circle('\uf0b4'),
        cmd_numeric_6_circle_outline('\uf0b3'),
        cmd_numeric_7('\uf0bc'),
        cmd_numeric_7_box('\uf0b9'),
        cmd_numeric_7_box_multiple('\uf0b7'),
        cmd_numeric_7_box_multiple_outline('\uf0b6'),
        cmd_numeric_7_box_outline('\uf0b8'),
        cmd_numeric_7_circle('\uf0bb'),
        cmd_numeric_7_circle_outline('\uf0ba'),
        cmd_numeric_8('\uf0c3'),
        cmd_numeric_8_box('\uf0c0'),
        cmd_numeric_8_box_multiple('\uf0be'),
        cmd_numeric_8_box_multiple_outline('\uf0bd'),
        cmd_numeric_8_box_outline('\uf0bf'),
        cmd_numeric_8_circle('\uf0c2'),
        cmd_numeric_8_circle_outline('\uf0c1'),
        cmd_numeric_9('\uf0d1'),
        cmd_numeric_9_box('\uf0c7'),
        cmd_numeric_9_box_multiple('\uf0c5'),
        cmd_numeric_9_box_multiple_outline('\uf0c4'),
        cmd_numeric_9_box_outline('\uf0c6'),
        cmd_numeric_9_circle('\uf0c9'),
        cmd_numeric_9_circle_outline('\uf0c8'),
        cmd_numeric_9_plus('\uf0d0'),
        cmd_numeric_9_plus_box('\uf0cd'),
        cmd_numeric_9_plus_box_multiple('\uf0cb'),
        cmd_numeric_9_plus_box_multiple_outline('\uf0ca'),
        cmd_numeric_9_plus_box_outline('\uf0cc'),
        cmd_numeric_9_plus_circle('\uf0cf'),
        cmd_numeric_9_plus_circle_outline('\uf0ce'),
        cmd_numeric_negative_1('\uf0d9'),
        cmd_nut('\uf0db'),
        cmd_nutrition('\uf0dc'),
        cmd_nuxt('\uf0dd'),
        cmd_oar('\uf0de'),
        cmd_ocarina('\uf0df'),
        cmd_ocr('\uf0e0'),
        cmd_octagon('\uf0e2'),
        cmd_octagon_outline('\uf0e1'),
        cmd_octagram('\uf0e4'),
        cmd_octagram_outline('\uf0e3'),
        cmd_odnoklassniki('\uf0e5'),
        cmd_offer('\uf0e6'),
        cmd_office('\uf0e8'),
        cmd_office_building('\uf0e7'),
        cmd_oil('\uf0ec'),
        cmd_oil_lamp('\uf0e9'),
        cmd_oil_level('\uf0ea'),
        cmd_oil_temperature('\uf0eb'),
        cmd_omega('\uf0ed'),
        cmd_one_up('\uf0ee'),
        cmd_onedrive('\uf0ef'),
        cmd_onenote('\uf0f0'),
        cmd_onepassword('\uf0f1'),
        cmd_opacity('\uf0f2'),
        cmd_open_in_app('\uf0f3'),
        cmd_open_in_new('\uf0f4'),
        cmd_open_source_initiative('\uf0f5'),
        cmd_openid('\uf0f6'),
        cmd_opera('\uf0f7'),
        cmd_orbit('\uf0f8'),
        cmd_origin('\uf0f9'),
        cmd_ornament('\uf0fb'),
        cmd_ornament_variant('\uf0fa'),
        cmd_outdoor_lamp('\uf0fc'),
        cmd_outlook('\uf0fd'),
        cmd_overscan('\uf0fe'),
        cmd_owl('\uf0ff'),
        cmd_pac_man('\uf100'),
        cmd_package('\uf105'),
        cmd_package_down('\uf101'),
        cmd_package_up('\uf102'),
        cmd_package_variant('\uf104'),
        cmd_package_variant_closed('\uf103'),
        cmd_page_first('\uf106'),
        cmd_page_last('\uf107'),
        cmd_page_layout_body('\uf108'),
        cmd_page_layout_footer('\uf109'),
        cmd_page_layout_header('\uf10b'),
        cmd_page_layout_header_footer('\uf10a'),
        cmd_page_layout_sidebar_left('\uf10c'),
        cmd_page_layout_sidebar_right('\uf10d'),
        cmd_page_next('\uf10f'),
        cmd_page_next_outline('\uf10e'),
        cmd_page_previous('\uf111'),
        cmd_page_previous_outline('\uf110'),
        cmd_palette('\uf115'),
        cmd_palette_advanced('\uf112'),
        cmd_palette_outline('\uf113'),
        cmd_palette_swatch('\uf114'),
        cmd_palm_tree('\uf116'),
        cmd_pan('\uf121'),
        cmd_pan_bottom_left('\uf117'),
        cmd_pan_bottom_right('\uf118'),
        cmd_pan_down('\uf119'),
        cmd_pan_horizontal('\uf11a'),
        cmd_pan_left('\uf11b'),
        cmd_pan_right('\uf11c'),
        cmd_pan_top_left('\uf11d'),
        cmd_pan_top_right('\uf11e'),
        cmd_pan_up('\uf11f'),
        cmd_pan_vertical('\uf120'),
        cmd_panda('\uf122'),
        cmd_pandora('\uf123'),
        cmd_panorama('\uf128'),
        cmd_panorama_fisheye('\uf124'),
        cmd_panorama_horizontal('\uf125'),
        cmd_panorama_vertical('\uf126'),
        cmd_panorama_wide_angle('\uf127'),
        cmd_paper_cut_vertical('\uf129'),
        cmd_paper_roll('\uf12b'),
        cmd_paper_roll_outline('\uf12a'),
        cmd_paperclip('\uf12c'),
        cmd_parachute('\uf12e'),
        cmd_parachute_outline('\uf12d'),
        cmd_parking('\uf12f'),
        cmd_party_popper('\uf130'),
        cmd_passport('\uf132'),
        cmd_passport_biometric('\uf131'),
        cmd_pasta('\uf133'),
        cmd_patio_heater('\uf134'),
        cmd_patreon('\uf135'),
        cmd_pause('\uf13a'),
        cmd_pause_circle('\uf137'),
        cmd_pause_circle_outline('\uf136'),
        cmd_pause_octagon('\uf139'),
        cmd_pause_octagon_outline('\uf138'),
        cmd_paw('\uf13c'),
        cmd_paw_off('\uf13b'),
        cmd_paypal('\uf13d'),
        cmd_pdf_box('\uf13e'),
        cmd_peace('\uf13f'),
        cmd_peanut('\uf143'),
        cmd_peanut_off('\uf141'),
        cmd_peanut_off_outline('\uf140'),
        cmd_peanut_outline('\uf142'),
        cmd_pen('\uf149'),
        cmd_pen_lock('\uf144'),
        cmd_pen_minus('\uf145'),
        cmd_pen_off('\uf146'),
        cmd_pen_plus('\uf147'),
        cmd_pen_remove('\uf148'),
        cmd_pencil('\uf15b'),
        cmd_pencil_box('\uf14d'),
        cmd_pencil_box_multiple('\uf14b'),
        cmd_pencil_box_multiple_outline('\uf14a'),
        cmd_pencil_box_outline('\uf14c'),
        cmd_pencil_circle('\uf14f'),
        cmd_pencil_circle_outline('\uf14e'),
        cmd_pencil_lock('\uf151'),
        cmd_pencil_lock_outline('\uf150'),
        cmd_pencil_minus('\uf153'),
        cmd_pencil_minus_outline('\uf152'),
        cmd_pencil_off('\uf155'),
        cmd_pencil_off_outline('\uf154'),
        cmd_pencil_outline('\uf156'),
        cmd_pencil_plus('\uf158'),
        cmd_pencil_plus_outline('\uf157'),
        cmd_pencil_remove('\uf15a'),
        cmd_pencil_remove_outline('\uf159'),
        cmd_penguin('\uf15c'),
        cmd_pentagon('\uf15e'),
        cmd_pentagon_outline('\uf15d'),
        cmd_percent('\uf160'),
        cmd_percent_outline('\uf15f'),
        cmd_periodic_table('\uf162'),
        cmd_periodic_table_co2('\uf161'),
        cmd_periscope('\uf163'),
        cmd_perspective_less('\uf164'),
        cmd_perspective_more('\uf165'),
        cmd_pharmacy('\uf166'),
        cmd_phone('\uf195'),
        cmd_phone_alert('\uf168'),
        cmd_phone_alert_outline('\uf167'),
        cmd_phone_bluetooth('\uf16a'),
        cmd_phone_bluetooth_outline('\uf169'),
        cmd_phone_cancel('\uf16c'),
        cmd_phone_cancel_outline('\uf16b'),
        cmd_phone_check('\uf16e'),
        cmd_phone_check_outline('\uf16d'),
        cmd_phone_classic('\uf170'),
        cmd_phone_classic_off('\uf16f'),
        cmd_phone_forward('\uf172'),
        cmd_phone_forward_outline('\uf171'),
        cmd_phone_hangup('\uf174'),
        cmd_phone_hangup_outline('\uf173'),
        cmd_phone_in_talk('\uf176'),
        cmd_phone_in_talk_outline('\uf175'),
        cmd_phone_incoming('\uf178'),
        cmd_phone_incoming_outline('\uf177'),
        cmd_phone_lock('\uf17a'),
        cmd_phone_lock_outline('\uf179'),
        cmd_phone_log('\uf17c'),
        cmd_phone_log_outline('\uf17b'),
        cmd_phone_message('\uf17e'),
        cmd_phone_message_outline('\uf17d'),
        cmd_phone_minus('\uf180'),
        cmd_phone_minus_outline('\uf17f'),
        cmd_phone_missed('\uf182'),
        cmd_phone_missed_outline('\uf181'),
        cmd_phone_off('\uf184'),
        cmd_phone_off_outline('\uf183'),
        cmd_phone_outgoing('\uf186'),
        cmd_phone_outgoing_outline('\uf185'),
        cmd_phone_outline('\uf187'),
        cmd_phone_paused('\uf189'),
        cmd_phone_paused_outline('\uf188'),
        cmd_phone_plus('\uf18b'),
        cmd_phone_plus_outline('\uf18a'),
        cmd_phone_return('\uf18d'),
        cmd_phone_return_outline('\uf18c'),
        cmd_phone_ring('\uf18f'),
        cmd_phone_ring_outline('\uf18e'),
        cmd_phone_rotate_landscape('\uf190'),
        cmd_phone_rotate_portrait('\uf191'),
        cmd_phone_settings('\uf193'),
        cmd_phone_settings_outline('\uf192'),
        cmd_phone_voip('\uf194'),
        cmd_pi('\uf198'),
        cmd_pi_box('\uf196'),
        cmd_pi_hole('\uf197'),
        cmd_piano('\uf199'),
        cmd_pickaxe('\uf19a'),
        cmd_picture_in_picture_bottom_right('\uf19c'),
        cmd_picture_in_picture_bottom_right_outline('\uf19b'),
        cmd_picture_in_picture_top_right('\uf19e'),
        cmd_picture_in_picture_top_right_outline('\uf19d'),
        cmd_pier('\uf1a0'),
        cmd_pier_crane('\uf19f'),
        cmd_pig('\uf1a2'),
        cmd_pig_variant('\uf1a1'),
        cmd_piggy_bank('\uf1a3'),
        cmd_pill('\uf1a4'),
        cmd_pillar('\uf1a5'),
        cmd_pin('\uf1a9'),
        cmd_pin_off('\uf1a7'),
        cmd_pin_off_outline('\uf1a6'),
        cmd_pin_outline('\uf1a8'),
        cmd_pine_tree('\uf1ab'),
        cmd_pine_tree_box('\uf1aa'),
        cmd_pinterest('\uf1ad'),
        cmd_pinterest_box('\uf1ac'),
        cmd_pinwheel('\uf1af'),
        cmd_pinwheel_outline('\uf1ae'),
        cmd_pipe('\uf1b2'),
        cmd_pipe_disconnected('\uf1b0'),
        cmd_pipe_leak('\uf1b1'),
        cmd_pirate('\uf1b3'),
        cmd_pistol('\uf1b4'),
        cmd_piston('\uf1b5'),
        cmd_pizza('\uf1b6'),
        cmd_play('\uf1c1'),
        cmd_play_box('\uf1b8'),
        cmd_play_box_outline('\uf1b7'),
        cmd_play_circle('\uf1ba'),
        cmd_play_circle_outline('\uf1b9'),
        cmd_play_network('\uf1bc'),
        cmd_play_network_outline('\uf1bb'),
        cmd_play_outline('\uf1bd'),
        cmd_play_pause('\uf1be'),
        cmd_play_protected_content('\uf1bf'),
        cmd_play_speed('\uf1c0'),
        cmd_playlist_check('\uf1c2'),
        cmd_playlist_edit('\uf1c3'),
        cmd_playlist_minus('\uf1c4'),
        cmd_playlist_music('\uf1c6'),
        cmd_playlist_music_outline('\uf1c5'),
        cmd_playlist_play('\uf1c7'),
        cmd_playlist_plus('\uf1c8'),
        cmd_playlist_remove('\uf1c9'),
        cmd_playlist_star('\uf1ca'),
        cmd_playstation('\uf1cb'),
        cmd_plex('\uf1cc'),
        cmd_plus('\uf1db'),
        cmd_plus_box('\uf1d0'),
        cmd_plus_box_multiple('\uf1ce'),
        cmd_plus_box_multiple_outline('\uf1cd'),
        cmd_plus_box_outline('\uf1cf'),
        cmd_plus_circle('\uf1d3'),
        cmd_plus_circle_multiple_outline('\uf1d1'),
        cmd_plus_circle_outline('\uf1d2'),
        cmd_plus_minus('\uf1d5'),
        cmd_plus_minus_box('\uf1d4'),
        cmd_plus_network('\uf1d7'),
        cmd_plus_network_outline('\uf1d6'),
        cmd_plus_one('\uf1d8'),
        cmd_plus_outline('\uf1d9'),
        cmd_plus_thick('\uf1da'),
        cmd_pocket('\uf1dc'),
        cmd_podcast('\uf1dd'),
        cmd_podium('\uf1e1'),
        cmd_podium_bronze('\uf1de'),
        cmd_podium_gold('\uf1df'),
        cmd_podium_silver('\uf1e0'),
        cmd_point_of_sale('\uf1e2'),
        cmd_pokeball('\uf1e3'),
        cmd_pokemon_go('\uf1e4'),
        cmd_poker_chip('\uf1e5'),
        cmd_polaroid('\uf1e6'),
        cmd_police_badge('\uf1e8'),
        cmd_police_badge_outline('\uf1e7'),
        cmd_poll('\uf1eb'),
        cmd_poll_box('\uf1ea'),
        cmd_poll_box_outline('\uf1e9'),
        cmd_polymer('\uf1ec'),
        cmd_pool('\uf1ed'),
        cmd_popcorn('\uf1ee'),
        cmd_post('\uf1f0'),
        cmd_post_outline('\uf1ef'),
        cmd_postage_stamp('\uf1f1'),
        cmd_pot('\uf1f3'),
        cmd_pot_mix('\uf1f2'),
        cmd_pound('\uf1f6'),
        cmd_pound_box('\uf1f5'),
        cmd_pound_box_outline('\uf1f4'),
        cmd_power('\uf207'),
        cmd_power_cycle('\uf1f7'),
        cmd_power_off('\uf1f8'),
        cmd_power_on('\uf1f9'),
        cmd_power_plug('\uf1fb'),
        cmd_power_plug_off('\uf1fa'),
        cmd_power_settings('\uf1fc'),
        cmd_power_sleep('\uf1fd'),
        cmd_power_socket('\uf205'),
        cmd_power_socket_au('\uf1fe'),
        cmd_power_socket_de('\uf1ff'),
        cmd_power_socket_eu('\uf200'),
        cmd_power_socket_fr('\uf201'),
        cmd_power_socket_jp('\uf202'),
        cmd_power_socket_uk('\uf203'),
        cmd_power_socket_us('\uf204'),
        cmd_power_standby('\uf206'),
        cmd_powershell('\uf208'),
        cmd_prescription('\uf209'),
        cmd_presentation('\uf20b'),
        cmd_presentation_play('\uf20a'),
        cmd_printer('\uf217'),
        cmd_printer_3d('\uf210'),
        cmd_printer_3d_nozzle('\uf20f'),
        cmd_printer_3d_nozzle_alert('\uf20d'),
        cmd_printer_3d_nozzle_alert_outline('\uf20c'),
        cmd_printer_3d_nozzle_outline('\uf20e'),
        cmd_printer_alert('\uf211'),
        cmd_printer_check('\uf212'),
        cmd_printer_off('\uf213'),
        cmd_printer_pos('\uf214'),
        cmd_printer_settings('\uf215'),
        cmd_printer_wireless('\uf216'),
        cmd_priority_high('\uf218'),
        cmd_priority_low('\uf219'),
        cmd_professional_hexagon('\uf21a'),
        cmd_progress_alert('\uf21b'),
        cmd_progress_check('\uf21c'),
        cmd_progress_clock('\uf21d'),
        cmd_progress_close('\uf21e'),
        cmd_progress_download('\uf21f'),
        cmd_progress_upload('\uf220'),
        cmd_progress_wrench('\uf221'),
        cmd_projector('\uf223'),
        cmd_projector_screen('\uf222'),
        cmd_protocol('\uf224'),
        cmd_publish('\uf225'),
        cmd_pulse('\uf226'),
        cmd_pumpkin('\uf227'),
        cmd_purse('\uf229'),
        cmd_purse_outline('\uf228'),
        cmd_puzzle('\uf22b'),
        cmd_puzzle_outline('\uf22a'),
        cmd_qi('\uf22c'),
        cmd_qqchat('\uf22d'),
        cmd_qrcode('\uf233'),
        cmd_qrcode_edit('\uf22e'),
        cmd_qrcode_minus('\uf22f'),
        cmd_qrcode_plus('\uf230'),
        cmd_qrcode_remove('\uf231'),
        cmd_qrcode_scan('\uf232'),
        cmd_quadcopter('\uf234'),
        cmd_quality_high('\uf235'),
        cmd_quality_low('\uf236'),
        cmd_quality_medium('\uf237'),
        cmd_quicktime('\uf238'),
        cmd_quora('\uf239'),
        cmd_rabbit('\uf23a'),
        cmd_racing_helmet('\uf23b'),
        cmd_racquetball('\uf23c'),
        cmd_radar('\uf23d'),
        cmd_radiator('\uf240'),
        cmd_radiator_disabled('\uf23e'),
        cmd_radiator_off('\uf23f'),
        cmd_radio('\uf246'),
        cmd_radio_am('\uf241'),
        cmd_radio_fm('\uf242'),
        cmd_radio_handheld('\uf243'),
        cmd_radio_off('\uf244'),
        cmd_radio_tower('\uf245'),
        cmd_radioactive('\uf248'),
        cmd_radioactive_off('\uf247'),
        cmd_radiobox_blank('\uf249'),
        cmd_radiobox_marked('\uf24a'),
        cmd_radius('\uf24c'),
        cmd_radius_outline('\uf24b'),
        cmd_railroad_light('\uf24d'),
        cmd_raspberry_pi('\uf24e'),
        cmd_ray_end('\uf250'),
        cmd_ray_end_arrow('\uf24f'),
        cmd_ray_start('\uf253'),
        cmd_ray_start_arrow('\uf251'),
        cmd_ray_start_end('\uf252'),
        cmd_ray_vertex('\uf254'),
        cmd_react('\uf255'),
        cmd_read('\ue900'),
        cmd_receipt('\ue901'),
        cmd_record('\ue906'),
        cmd_record_circle('\ue903'),
        cmd_record_circle_outline('\ue902'),
        cmd_record_player('\ue904'),
        cmd_record_rec('\ue905'),
        cmd_rectangle('\ue908'),
        cmd_rectangle_outline('\ue907'),
        cmd_recycle('\ue909'),
        cmd_reddit('\ue90a'),
        cmd_redhat('\ue90b'),
        cmd_redo('\ue90d'),
        cmd_redo_variant('\ue90c'),
        cmd_reflect_horizontal('\ue90e'),
        cmd_reflect_vertical('\ue90f'),
        cmd_refresh('\ue910'),
        cmd_regex('\ue911'),
        cmd_registered_trademark('\ue912'),
        cmd_relative_scale('\ue913'),
        cmd_reload('\ue915'),
        cmd_reload_alert('\ue914'),
        cmd_reminder('\ue916'),
        cmd_remote('\ue91b'),
        cmd_remote_desktop('\ue917'),
        cmd_remote_off('\ue918'),
        cmd_remote_tv('\ue91a'),
        cmd_remote_tv_off('\ue919'),
        cmd_rename_box('\ue91c'),
        cmd_reorder_horizontal('\ue91d'),
        cmd_reorder_vertical('\ue91e'),
        cmd_repeat('\ue921'),
        cmd_repeat_off('\ue91f'),
        cmd_repeat_once('\ue920'),
        cmd_replay('\ue922'),
        cmd_reply('\ue927'),
        cmd_reply_all('\ue924'),
        cmd_reply_all_outline('\ue923'),
        cmd_reply_circle('\ue925'),
        cmd_reply_outline('\ue926'),
        cmd_reproduction('\ue928'),
        cmd_resistor('\ue92a'),
        cmd_resistor_nodes('\ue929'),
        cmd_resize('\ue92c'),
        cmd_resize_bottom_right('\ue92b'),
        cmd_responsive('\ue92d'),
        cmd_restart('\ue930'),
        cmd_restart_alert('\ue92e'),
        cmd_restart_off('\ue92f'),
        cmd_restore('\ue932'),
        cmd_restore_alert('\ue931'),
        cmd_rewind('\ue937'),
        cmd_rewind_10('\ue934'),
        cmd_rewind_30('\ue935'),
        cmd_rewind_5('\ue933'),
        cmd_rewind_outline('\ue936'),
        cmd_rhombus('\ue93b'),
        cmd_rhombus_medium('\ue938'),
        cmd_rhombus_outline('\ue939'),
        cmd_rhombus_split('\ue93a'),
        cmd_ribbon('\ue93c'),
        cmd_rice('\ue93d'),
        cmd_ring('\ue93e'),
        cmd_rivet('\ue93f'),
        cmd_road('\ue941'),
        cmd_road_variant('\ue940'),
        cmd_robber('\ue942'),
        cmd_robot('\ue948'),
        cmd_robot_industrial('\ue943'),
        cmd_robot_mower('\ue945'),
        cmd_robot_mower_outline('\ue944'),
        cmd_robot_vacuum('\ue947'),
        cmd_robot_vacuum_variant('\ue946'),
        cmd_rocket('\ue949'),
        cmd_roller_skate('\ue94a'),
        cmd_rollerblade('\ue94b'),
        cmd_rollupjs('\ue94c'),
        cmd_roman_numeral_1('\ue94d'),
        cmd_roman_numeral_10('\ue956'),
        cmd_roman_numeral_2('\ue94e'),
        cmd_roman_numeral_3('\ue94f'),
        cmd_roman_numeral_4('\ue950'),
        cmd_roman_numeral_5('\ue951'),
        cmd_roman_numeral_6('\ue952'),
        cmd_roman_numeral_7('\ue953'),
        cmd_roman_numeral_8('\ue954'),
        cmd_roman_numeral_9('\ue955'),
        cmd_room_service('\ue958'),
        cmd_room_service_outline('\ue957'),
        cmd_rotate_3d('\ue95a'),
        cmd_rotate_3d_variant('\ue959'),
        cmd_rotate_left('\ue95c'),
        cmd_rotate_left_variant('\ue95b'),
        cmd_rotate_orbit('\ue95d'),
        cmd_rotate_right('\ue95f'),
        cmd_rotate_right_variant('\ue95e'),
        cmd_rounded_corner('\ue960'),
        cmd_router('\ue963'),
        cmd_router_wireless('\ue962'),
        cmd_router_wireless_settings('\ue961'),
        cmd_routes('\ue965'),
        cmd_routes_clock('\ue964'),
        cmd_rowing('\ue966'),
        cmd_rss('\ue969'),
        cmd_rss_box('\ue967'),
        cmd_rss_off('\ue968'),
        cmd_ruby('\ue96a'),
        cmd_rugby('\ue96b'),
        cmd_ruler('\ue96e'),
        cmd_ruler_square('\ue96d'),
        cmd_ruler_square_compass('\ue96c'),
        cmd_run('\ue970'),
        cmd_run_fast('\ue96f'),
        cmd_rv_truck('\ue971'),
        cmd_sack('\ue973'),
        cmd_sack_percent('\ue972'),
        cmd_safe('\ue976'),
        cmd_safe_square('\ue975'),
        cmd_safe_square_outline('\ue974'),
        cmd_safety_goggles('\ue977'),
        cmd_sailing('\ue978'),
        cmd_sale('\ue979'),
        cmd_salesforce('\ue97a'),
        cmd_sass('\ue97b'),
        cmd_satellite('\ue97e'),
        cmd_satellite_uplink('\ue97c'),
        cmd_satellite_variant('\ue97d'),
        cmd_sausage('\ue97f'),
        cmd_saw_blade('\ue980'),
        cmd_saxophone('\ue981'),
        cmd_scale('\ue985'),
        cmd_scale_balance('\ue982'),
        cmd_scale_bathroom('\ue983'),
        cmd_scale_off('\ue984'),
        cmd_scanner('\ue987'),
        cmd_scanner_off('\ue986'),
        cmd_scatter_plot('\ue989'),
        cmd_scatter_plot_outline('\ue988'),
        cmd_school('\ue98b'),
        cmd_school_outline('\ue98a'),
        cmd_scissors_cutting('\ue98c'),
        cmd_scooter('\ue98d'),
        cmd_scoreboard('\ue98f'),
        cmd_scoreboard_outline('\ue98e'),
        cmd_screen_rotation('\ue991'),
        cmd_screen_rotation_lock('\ue990'),
        cmd_screw_flat_top('\ue992'),
        cmd_screw_lag('\ue993'),
        cmd_screw_machine_flat_top('\ue994'),
        cmd_screw_machine_round_top('\ue995'),
        cmd_screw_round_top('\ue996'),
        cmd_screwdriver('\ue997'),
        cmd_script('\ue99b'),
        cmd_script_outline('\ue998'),
        cmd_script_text('\ue99a'),
        cmd_script_text_outline('\ue999'),
        cmd_sd('\ue99c'),
        cmd_seal('\ue99e'),
        cmd_seal_variant('\ue99d'),
        cmd_search_web('\ue99f'),
        cmd_seat('\ue9aa'),
        cmd_seat_flat('\ue9a1'),
        cmd_seat_flat_angled('\ue9a0'),
        cmd_seat_individual_suite('\ue9a2'),
        cmd_seat_legroom_extra('\ue9a3'),
        cmd_seat_legroom_normal('\ue9a4'),
        cmd_seat_legroom_reduced('\ue9a5'),
        cmd_seat_outline('\ue9a6'),
        cmd_seat_passenger('\ue9a7'),
        cmd_seat_recline_extra('\ue9a8'),
        cmd_seat_recline_normal('\ue9a9'),
        cmd_seatbelt('\ue9ab'),
        cmd_security('\ue9ad'),
        cmd_security_network('\ue9ac'),
        cmd_seed('\ue9af'),
        cmd_seed_outline('\ue9ae'),
        cmd_segment('\ue9b0'),
        cmd_select('\ue9bd'),
        cmd_select_all('\ue9b1'),
        cmd_select_color('\ue9b2'),
        cmd_select_compare('\ue9b3'),
        cmd_select_drag('\ue9b4'),
        cmd_select_group('\ue9b5'),
        cmd_select_inverse('\ue9b6'),
        cmd_select_marker('\ue9b7'),
        cmd_select_multiple('\ue9b9'),
        cmd_select_multiple_marker('\ue9b8'),
        cmd_select_off('\ue9ba'),
        cmd_select_place('\ue9bb'),
        cmd_select_search('\ue9bc'),
        cmd_selection('\ue9c6'),
        cmd_selection_drag('\ue9be'),
        cmd_selection_ellipse('\ue9c0'),
        cmd_selection_ellipse_arrow_inside('\ue9bf'),
        cmd_selection_marker('\ue9c1'),
        cmd_selection_multiple_marker('\ue9c2'),
        cmd_selection_mutliple('\ue9c3'),
        cmd_selection_off('\ue9c4'),
        cmd_selection_search('\ue9c5'),
        cmd_send('\ue9d0'),
        cmd_send_check('\ue9c8'),
        cmd_send_check_outline('\ue9c7'),
        cmd_send_circle('\ue9ca'),
        cmd_send_circle_outline('\ue9c9'),
        cmd_send_clock('\ue9cc'),
        cmd_send_clock_outline('\ue9cb'),
        cmd_send_lock('\ue9ce'),
        cmd_send_lock_outline('\ue9cd'),
        cmd_send_outline('\ue9cf'),
        cmd_serial_port('\ue9d1'),
        cmd_server('\ue9d9'),
        cmd_server_minus('\ue9d2'),
        cmd_server_network('\ue9d4'),
        cmd_server_network_off('\ue9d3'),
        cmd_server_off('\ue9d5'),
        cmd_server_plus('\ue9d6'),
        cmd_server_remove('\ue9d7'),
        cmd_server_security('\ue9d8'),
        cmd_set_all('\ue9da'),
        cmd_set_center('\ue9dc'),
        cmd_set_center_right('\ue9db'),
        cmd_set_left('\ue9df'),
        cmd_set_left_center('\ue9dd'),
        cmd_set_left_right('\ue9de'),
        cmd_set_none('\ue9e0'),
        cmd_set_right('\ue9e1'),
        cmd_set_top_box('\ue9e2'),
        cmd_settings('\ue9e8'),
        cmd_settings_box('\ue9e3'),
        cmd_settings_helper('\ue9e4'),
        cmd_settings_outline('\ue9e5'),
        cmd_settings_transfer('\ue9e7'),
        cmd_settings_transfer_outline('\ue9e6'),
        cmd_shaker('\ue9ea'),
        cmd_shaker_outline('\ue9e9'),
        cmd_shape('\ue9f2'),
        cmd_shape_circle_plus('\ue9eb'),
        cmd_shape_outline('\ue9ec'),
        cmd_shape_oval_plus('\ue9ed'),
        cmd_shape_plus('\ue9ee'),
        cmd_shape_polygon_plus('\ue9ef'),
        cmd_shape_rectangle_plus('\ue9f0'),
        cmd_shape_square_plus('\ue9f1'),
        cmd_share('\ue9fa'),
        cmd_share_all('\ue9f4'),
        cmd_share_all_outline('\ue9f3'),
        cmd_share_circle('\ue9f5'),
        cmd_share_off('\ue9f7'),
        cmd_share_off_outline('\ue9f6'),
        cmd_share_outline('\ue9f8'),
        cmd_share_variant('\ue9f9'),
        cmd_sheep('\ue9fb'),
        cmd_shield('\uea20'),
        cmd_shield_account('\ue9fd'),
        cmd_shield_account_outline('\ue9fc'),
        cmd_shield_airplane('\ue9ff'),
        cmd_shield_airplane_outline('\ue9fe'),
        cmd_shield_alert('\uea01'),
        cmd_shield_alert_outline('\uea00'),
        cmd_shield_car('\uea02'),
        cmd_shield_check('\uea04'),
        cmd_shield_check_outline('\uea03'),
        cmd_shield_cross('\uea06'),
        cmd_shield_cross_outline('\uea05'),
        cmd_shield_edit('\uea08'),
        cmd_shield_edit_outline('\uea07'),
        cmd_shield_half_full('\uea09'),
        cmd_shield_home('\uea0b'),
        cmd_shield_home_outline('\uea0a'),
        cmd_shield_key('\uea0d'),
        cmd_shield_key_outline('\uea0c'),
        cmd_shield_link_variant('\uea0f'),
        cmd_shield_link_variant_outline('\uea0e'),
        cmd_shield_lock('\uea11'),
        cmd_shield_lock_outline('\uea10'),
        cmd_shield_off('\uea13'),
        cmd_shield_off_outline('\uea12'),
        cmd_shield_outline('\uea14'),
        cmd_shield_plus('\uea16'),
        cmd_shield_plus_outline('\uea15'),
        cmd_shield_refresh('\uea18'),
        cmd_shield_refresh_outline('\uea17'),
        cmd_shield_remove('\uea1a'),
        cmd_shield_remove_outline('\uea19'),
        cmd_shield_search('\uea1b'),
        cmd_shield_star('\uea1d'),
        cmd_shield_star_outline('\uea1c'),
        cmd_shield_sun('\uea1f'),
        cmd_shield_sun_outline('\uea1e'),
        cmd_ship_wheel('\uea21'),
        cmd_shoe_formal('\uea22'),
        cmd_shoe_heel('\uea23'),
        cmd_shoe_print('\uea24'),
        cmd_shopify('\uea25'),
        cmd_shopping('\uea29'),
        cmd_shopping_music('\uea26'),
        cmd_shopping_outline('\uea27'),
        cmd_shopping_search('\uea28'),
        cmd_shovel('\uea2b'),
        cmd_shovel_off('\uea2a'),
        cmd_shower('\uea2d'),
        cmd_shower_head('\uea2c'),
        cmd_shredder('\uea2e'),
        cmd_shuffle('\uea31'),
        cmd_shuffle_disabled('\uea2f'),
        cmd_shuffle_variant('\uea30'),
        cmd_sigma('\uea33'),
        cmd_sigma_lower('\uea32'),
        cmd_sign_caution('\uea34'),
        cmd_sign_direction('\uea38'),
        cmd_sign_direction_minus('\uea35'),
        cmd_sign_direction_plus('\uea36'),
        cmd_sign_direction_remove('\uea37'),
        cmd_sign_real_estate('\uea39'),
        cmd_sign_text('\uea3a'),
        cmd_signal('\uea48'),
        cmd_signal_2g('\uea3b'),
        cmd_signal_3g('\uea3c'),
        cmd_signal_4g('\uea3d'),
        cmd_signal_5g('\uea3e'),
        cmd_signal_cellular_1('\uea3f'),
        cmd_signal_cellular_2('\uea40'),
        cmd_signal_cellular_3('\uea41'),
        cmd_signal_cellular_outline('\uea42'),
        cmd_signal_distance_variant('\uea43'),
        cmd_signal_hspa('\uea45'),
        cmd_signal_hspa_plus('\uea44'),
        cmd_signal_off('\uea46'),
        cmd_signal_variant('\uea47'),
        cmd_signature('\uea4c'),
        cmd_signature_freehand('\uea49'),
        cmd_signature_image('\uea4a'),
        cmd_signature_text('\uea4b'),
        cmd_silo('\uea4d'),
        cmd_silverware('\uea53'),
        cmd_silverware_clean('\uea4e'),
        cmd_silverware_fork('\uea50'),
        cmd_silverware_fork_knife('\uea4f'),
        cmd_silverware_spoon('\uea51'),
        cmd_silverware_variant('\uea52'),
        cmd_sim('\uea56'),
        cmd_sim_alert('\uea54'),
        cmd_sim_off('\uea55'),
        cmd_sina_weibo('\uea57'),
        cmd_sitemap('\uea58'),
        cmd_skate('\uea59'),
        cmd_skew_less('\uea5a'),
        cmd_skew_more('\uea5b'),
        cmd_skip_backward('\uea5d'),
        cmd_skip_backward_outline('\uea5c'),
        cmd_skip_forward('\uea5f'),
        cmd_skip_forward_outline('\uea5e'),
        cmd_skip_next('\uea63'),
        cmd_skip_next_circle('\uea61'),
        cmd_skip_next_circle_outline('\uea60'),
        cmd_skip_next_outline('\uea62'),
        cmd_skip_previous('\uea67'),
        cmd_skip_previous_circle('\uea65'),
        cmd_skip_previous_circle_outline('\uea64'),
        cmd_skip_previous_outline('\uea66'),
        cmd_skull('\uea6b'),
        cmd_skull_crossbones('\uea69'),
        cmd_skull_crossbones_outline('\uea68'),
        cmd_skull_outline('\uea6a'),
        cmd_skype('\uea6d'),
        cmd_skype_business('\uea6c'),
        cmd_slack('\uea6e'),
        cmd_slackware('\uea6f'),
        cmd_slash_forward('\uea71'),
        cmd_slash_forward_box('\uea70'),
        cmd_sleep('\uea73'),
        cmd_sleep_off('\uea72'),
        cmd_slope_downhill('\uea74'),
        cmd_slope_uphill('\uea75'),
        cmd_slot_machine('\uea77'),
        cmd_slot_machine_outline('\uea76'),
        cmd_smart_card('\uea7b'),
        cmd_smart_card_outline('\uea78'),
        cmd_smart_card_reader('\uea7a'),
        cmd_smart_card_reader_outline('\uea79'),
        cmd_smog('\uea7c'),
        cmd_smoke_detector('\uea7d'),
        cmd_smoking('\uea7f'),
        cmd_smoking_off('\uea7e'),
        cmd_snapchat('\uea80'),
        cmd_snowflake('\uea84'),
        cmd_snowflake_alert('\uea81'),
        cmd_snowflake_melt('\uea82'),
        cmd_snowflake_variant('\uea83'),
        cmd_snowman('\uea85'),
        cmd_soccer('\uea87'),
        cmd_soccer_field('\uea86'),
        cmd_sofa('\uea88'),
        cmd_solar_panel('\uea8a'),
        cmd_solar_panel_large('\uea89'),
        cmd_solar_power('\uea8b'),
        cmd_soldering_iron('\uea8c'),
        cmd_solid('\uea8d'),
        cmd_sort('\uea98'),
        cmd_sort_alphabetical('\uea90'),
        cmd_sort_alphabetical_ascending('\uea8e'),
        cmd_sort_alphabetical_descending('\uea8f'),
        cmd_sort_ascending('\uea91'),
        cmd_sort_descending('\uea92'),
        cmd_sort_numeric('\uea93'),
        cmd_sort_variant('\uea97'),
        cmd_sort_variant_lock('\uea95'),
        cmd_sort_variant_lock_open('\uea94'),
        cmd_sort_variant_remove('\uea96'),
        cmd_soundcloud('\uea99'),
        cmd_source_branch('\uea9a'),
        cmd_source_commit('\ueaa1'),
        cmd_source_commit_end('\uea9c'),
        cmd_source_commit_end_local('\uea9b'),
        cmd_source_commit_local('\uea9d'),
        cmd_source_commit_next_local('\uea9e'),
        cmd_source_commit_start('\ueaa0'),
        cmd_source_commit_start_next_local('\uea9f'),
        cmd_source_fork('\ueaa2'),
        cmd_source_merge('\ueaa3'),
        cmd_source_pull('\ueaa4'),
        cmd_source_repository('\ueaa6'),
        cmd_source_repository_multiple('\ueaa5'),
        cmd_soy_sauce('\ueaa7'),
        cmd_spa('\ueaa9'),
        cmd_spa_outline('\ueaa8'),
        cmd_space_invaders('\ueaaa'),
        cmd_spade('\ueaab'),
        cmd_speaker('\ueab0'),
        cmd_speaker_bluetooth('\ueaac'),
        cmd_speaker_multiple('\ueaad'),
        cmd_speaker_off('\ueaae'),
        cmd_speaker_wireless('\ueaaf'),
        cmd_speedometer('\ueab3'),
        cmd_speedometer_medium('\ueab1'),
        cmd_speedometer_slow('\ueab2'),
        cmd_spellcheck('\ueab4'),
        cmd_spider('\ueab7'),
        cmd_spider_thread('\ueab5'),
        cmd_spider_web('\ueab6'),
        cmd_spotify('\ueab8'),
        cmd_spotlight('\ueaba'),
        cmd_spotlight_beam('\ueab9'),
        cmd_spray('\ueabc'),
        cmd_spray_bottle('\ueabb'),
        cmd_sprinkler('\ueabe'),
        cmd_sprinkler_variant('\ueabd'),
        cmd_sprout('\ueac0'),
        cmd_sprout_outline('\ueabf'),
        cmd_square('\ueaca'),
        cmd_square_edit_outline('\ueac1'),
        cmd_square_inc('\ueac3'),
        cmd_square_inc_cash('\ueac2'),
        cmd_square_medium('\ueac5'),
        cmd_square_medium_outline('\ueac4'),
        cmd_square_outline('\ueac6'),
        cmd_square_root('\ueac8'),
        cmd_square_root_box('\ueac7'),
        cmd_square_small('\ueac9'),
        cmd_squeegee('\ueacb'),
        cmd_ssh('\ueacc'),
        cmd_stack_exchange('\ueacd'),
        cmd_stack_overflow('\ueace'),
        cmd_stackpath('\ueacf'),
        cmd_stadium('\uead1'),
        cmd_stadium_variant('\uead0'),
        cmd_stairs('\uead4'),
        cmd_stairs_down('\uead2'),
        cmd_stairs_up('\uead3'),
        cmd_stamper('\uead5'),
        cmd_standard_definition('\uead6'),
        cmd_star('\ueae5'),
        cmd_star_box('\ueada'),
        cmd_star_box_multiple('\uead8'),
        cmd_star_box_multiple_outline('\uead7'),
        cmd_star_box_outline('\uead9'),
        cmd_star_circle('\ueadc'),
        cmd_star_circle_outline('\ueadb'),
        cmd_star_face('\ueadd'),
        cmd_star_four_points('\ueadf'),
        cmd_star_four_points_outline('\ueade'),
        cmd_star_half('\ueae0'),
        cmd_star_off('\ueae1'),
        cmd_star_outline('\ueae2'),
        cmd_star_three_points('\ueae4'),
        cmd_star_three_points_outline('\ueae3'),
        cmd_state_machine('\ueae6'),
        cmd_steam('\ueae8'),
        cmd_steam_box('\ueae7'),
        cmd_steering('\ueaea'),
        cmd_steering_off('\ueae9'),
        cmd_step_backward('\ueaec'),
        cmd_step_backward_2('\ueaeb'),
        cmd_step_forward('\ueaee'),
        cmd_step_forward_2('\ueaed'),
        cmd_stethoscope('\ueaef'),
        cmd_sticker('\ueaf1'),
        cmd_sticker_emoji('\ueaf0'),
        cmd_stocking('\ueaf2'),
        cmd_stomach('\ueaf3'),
        cmd_stop('\ueaf6'),
        cmd_stop_circle('\ueaf5'),
        cmd_stop_circle_outline('\ueaf4'),
        cmd_store('\ueaf8'),
        cmd_store_24_hour('\ueaf7'),
        cmd_storefront('\ueaf9'),
        cmd_stove('\ueafa'),
        cmd_strategy('\ueafb'),
        cmd_strava('\ueafc'),
        cmd_stretch_to_page('\ueafe'),
        cmd_stretch_to_page_outline('\ueafd'),
        cmd_string_lights('\ueb00'),
        cmd_string_lights_off('\ueaff'),
        cmd_subdirectory_arrow_left('\ueb01'),
        cmd_subdirectory_arrow_right('\ueb02'),
        cmd_subtitles('\ueb04'),
        cmd_subtitles_outline('\ueb03'),
        cmd_subway('\ueb07'),
        cmd_subway_alert_variant('\ueb05'),
        cmd_subway_variant('\ueb06'),
        cmd_summit('\ueb08'),
        cmd_sunglasses('\ueb09'),
        cmd_surround_sound('\ueb0e'),
        cmd_surround_sound_2_0('\ueb0a'),
        cmd_surround_sound_3_1('\ueb0b'),
        cmd_surround_sound_5_1('\ueb0c'),
        cmd_surround_sound_7_1('\ueb0d'),
        cmd_svg('\ueb0f'),
        cmd_swap_horizontal('\ueb14'),
        cmd_swap_horizontal_bold('\ueb10'),
        cmd_swap_horizontal_circle('\ueb12'),
        cmd_swap_horizontal_circle_outline('\ueb11'),
        cmd_swap_horizontal_variant('\ueb13'),
        cmd_swap_vertical('\ueb19'),
        cmd_swap_vertical_bold('\ueb15'),
        cmd_swap_vertical_circle('\ueb17'),
        cmd_swap_vertical_circle_outline('\ueb16'),
        cmd_swap_vertical_variant('\ueb18'),
        cmd_swim('\ueb1a'),
        cmd_switch('\ueb1b'),
        cmd_sword('\ueb1d'),
        cmd_sword_cross('\ueb1c'),
        cmd_symfony('\ueb1e'),
        cmd_sync('\ueb21'),
        cmd_sync_alert('\ueb1f'),
        cmd_sync_off('\ueb20'),
        cmd_tab('\ueb26'),
        cmd_tab_minus('\ueb22'),
        cmd_tab_plus('\ueb23'),
        cmd_tab_remove('\ueb24'),
        cmd_tab_unselected('\ueb25'),
        cmd_table('\ueb41'),
        cmd_table_border('\ueb27'),
        cmd_table_chair('\ueb28'),
        cmd_table_column('\ueb2d'),
        cmd_table_column_plus_after('\ueb29'),
        cmd_table_column_plus_before('\ueb2a'),
        cmd_table_column_remove('\ueb2b'),
        cmd_table_column_width('\ueb2c'),
        cmd_table_edit('\ueb2e'),
        cmd_table_eye('\ueb2f'),
        cmd_table_headers_eye('\ueb31'),
        cmd_table_headers_eye_off('\ueb30'),
        cmd_table_large('\ueb34'),
        cmd_table_large_plus('\ueb32'),
        cmd_table_large_remove('\ueb33'),
        cmd_table_merge_cells('\ueb35'),
        cmd_table_of_contents('\ueb36'),
        cmd_table_plus('\ueb37'),
        cmd_table_remove('\ueb38'),
        cmd_table_row('\ueb3d'),
        cmd_table_row_height('\ueb39'),
        cmd_table_row_plus_after('\ueb3a'),
        cmd_table_row_plus_before('\ueb3b'),
        cmd_table_row_remove('\ueb3c'),
        cmd_table_search('\ueb3e'),
        cmd_table_settings('\ueb3f'),
        cmd_table_tennis('\ueb40'),
        cmd_tablet('\ueb46'),
        cmd_tablet_android('\ueb42'),
        cmd_tablet_cellphone('\ueb43'),
        cmd_tablet_dashboard('\ueb44'),
        cmd_tablet_ipad('\ueb45'),
        cmd_taco('\ueb47'),
        cmd_tag('\ueb57'),
        cmd_tag_faces('\ueb48'),
        cmd_tag_heart('\ueb4a'),
        cmd_tag_heart_outline('\ueb49'),
        cmd_tag_minus('\ueb4c'),
        cmd_tag_minus_outline('\ueb4b'),
        cmd_tag_multiple('\ueb4d'),
        cmd_tag_off('\ueb4f'),
        cmd_tag_off_outline('\ueb4e'),
        cmd_tag_outline('\ueb50'),
        cmd_tag_plus('\ueb52'),
        cmd_tag_plus_outline('\ueb51'),
        cmd_tag_remove('\ueb54'),
        cmd_tag_remove_outline('\ueb53'),
        cmd_tag_text('\ueb56'),
        cmd_tag_text_outline('\ueb55'),
        cmd_tank('\ueb58'),
        cmd_tanker_truck('\ueb59'),
        cmd_tape_measure('\ueb5a'),
        cmd_target('\ueb5d'),
        cmd_target_account('\ueb5b'),
        cmd_target_variant('\ueb5c'),
        cmd_taxi('\ueb5e'),
        cmd_tea('\ueb60'),
        cmd_tea_outline('\ueb5f'),
        cmd_teach('\ueb61'),
        cmd_teamviewer('\ueb62'),
        cmd_telegram('\ueb63'),
        cmd_telescope('\ueb64'),
        cmd_television('\ueb6e'),
        cmd_television_box('\ueb65'),
        cmd_television_classic('\ueb67'),
        cmd_television_classic_off('\ueb66'),
        cmd_television_clean('\ueb68'),
        cmd_television_guide('\ueb69'),
        cmd_television_off('\ueb6a'),
        cmd_television_pause('\ueb6b'),
        cmd_television_play('\ueb6c'),
        cmd_television_stop('\ueb6d'),
        cmd_temperature_celsius('\ueb6f'),
        cmd_temperature_fahrenheit('\ueb70'),
        cmd_temperature_kelvin('\ueb71'),
        cmd_tennis('\ueb73'),
        cmd_tennis_ball('\ueb72'),
        cmd_tent('\ueb74'),
        cmd_terraform('\ueb75'),
        cmd_terrain('\ueb76'),
        cmd_test_tube('\ueb79'),
        cmd_test_tube_empty('\ueb77'),
        cmd_test_tube_off('\ueb78'),
        cmd_text('\ueb80'),
        cmd_text_recognition('\ueb7a'),
        cmd_text_shadow('\ueb7b'),
        cmd_text_short('\ueb7c'),
        cmd_text_subject('\ueb7d'),
        cmd_text_to_speech('\ueb7f'),
        cmd_text_to_speech_off('\ueb7e'),
        cmd_textarea('\ueb81'),
        cmd_textbox('\ueb83'),
        cmd_textbox_password('\ueb82'),
        cmd_texture('\ueb85'),
        cmd_texture_box('\ueb84'),
        cmd_theater('\ueb86'),
        cmd_theme_light_dark('\ueb87'),
        cmd_thermometer('\ueb90'),
        cmd_thermometer_alert('\ueb88'),
        cmd_thermometer_chevron_down('\ueb89'),
        cmd_thermometer_chevron_up('\ueb8a'),
        cmd_thermometer_high('\ueb8b'),
        cmd_thermometer_lines('\ueb8c'),
        cmd_thermometer_low('\ueb8d'),
        cmd_thermometer_minus('\ueb8e'),
        cmd_thermometer_plus('\ueb8f'),
        cmd_thermostat('\ueb92'),
        cmd_thermostat_box('\ueb91'),
        cmd_thought_bubble('\ueb94'),
        cmd_thought_bubble_outline('\ueb93'),
        cmd_thumb_down('\ueb96'),
        cmd_thumb_down_outline('\ueb95'),
        cmd_thumb_up('\ueb98'),
        cmd_thumb_up_outline('\ueb97'),
        cmd_thumbs_up_down('\ueb99'),
        cmd_ticket('\ueb9e'),
        cmd_ticket_account('\ueb9a'),
        cmd_ticket_confirmation('\ueb9b'),
        cmd_ticket_outline('\ueb9c'),
        cmd_ticket_percent('\ueb9d'),
        cmd_tie('\ueb9f'),
        cmd_tilde('\ueba0'),
        cmd_timelapse('\ueba1'),
        cmd_timeline('\uebad'),
        cmd_timeline_alert('\ueba3'),
        cmd_timeline_alert_outline('\ueba2'),
        cmd_timeline_clock('\ueba5'),
        cmd_timeline_clock_outline('\ueba4'),
        cmd_timeline_help('\ueba7'),
        cmd_timeline_help_outline('\ueba6'),
        cmd_timeline_outline('\ueba8'),
        cmd_timeline_plus('\uebaa'),
        cmd_timeline_plus_outline('\ueba9'),
        cmd_timeline_text('\uebac'),
        cmd_timeline_text_outline('\uebab'),
        cmd_timer('\uebb4'),
        cmd_timer_10('\uebaf'),
        cmd_timer_3('\uebae'),
        cmd_timer_off('\uebb0'),
        cmd_timer_sand('\uebb3'),
        cmd_timer_sand_empty('\uebb1'),
        cmd_timer_sand_full('\uebb2'),
        cmd_timetable('\uebb5'),
        cmd_toaster('\uebb8'),
        cmd_toaster_off('\uebb6'),
        cmd_toaster_oven('\uebb7'),
        cmd_toggle_switch('\uebbc'),
        cmd_toggle_switch_off('\uebba'),
        cmd_toggle_switch_off_outline('\uebb9'),
        cmd_toggle_switch_outline('\uebbb'),
        cmd_toilet('\uebbd'),
        cmd_toolbox('\uebbf'),
        cmd_toolbox_outline('\uebbe'),
        cmd_tools('\uebc0'),
        cmd_tooltip('\uebcb'),
        cmd_tooltip_account('\uebc1'),
        cmd_tooltip_edit('\uebc3'),
        cmd_tooltip_edit_outline('\uebc2'),
        cmd_tooltip_image('\uebc5'),
        cmd_tooltip_image_outline('\uebc4'),
        cmd_tooltip_outline('\uebc6'),
        cmd_tooltip_plus('\uebc8'),
        cmd_tooltip_plus_outline('\uebc7'),
        cmd_tooltip_text('\uebca'),
        cmd_tooltip_text_outline('\uebc9'),
        cmd_tooth('\uebcd'),
        cmd_tooth_outline('\uebcc'),
        cmd_toothbrush('\uebd0'),
        cmd_toothbrush_electric('\uebce'),
        cmd_toothbrush_paste('\uebcf'),
        cmd_tor('\uebd1'),
        cmd_tortoise('\uebd2'),
        cmd_toslink('\uebd3'),
        cmd_tournament('\uebd4'),
        cmd_tower_beach('\uebd5'),
        cmd_tower_fire('\uebd6'),
        cmd_towing('\uebd7'),
        cmd_toy_brick('\uebe3'),
        cmd_toy_brick_marker('\uebd9'),
        cmd_toy_brick_marker_outline('\uebd8'),
        cmd_toy_brick_minus('\uebdb'),
        cmd_toy_brick_minus_outline('\uebda'),
        cmd_toy_brick_outline('\uebdc'),
        cmd_toy_brick_plus('\uebde'),
        cmd_toy_brick_plus_outline('\uebdd'),
        cmd_toy_brick_remove('\uebe0'),
        cmd_toy_brick_remove_outline('\uebdf'),
        cmd_toy_brick_search('\uebe2'),
        cmd_toy_brick_search_outline('\uebe1'),
        cmd_track_light('\uebe4'),
        cmd_trackpad('\uebe6'),
        cmd_trackpad_lock('\uebe5'),
        cmd_tractor('\uebe7'),
        cmd_trademark('\uebe8'),
        cmd_traffic_light('\uebe9'),
        cmd_train('\uebec'),
        cmd_train_car('\uebea'),
        cmd_train_variant('\uebeb'),
        cmd_tram('\uebee'),
        cmd_tram_side('\uebed'),
        cmd_transcribe('\uebf0'),
        cmd_transcribe_close('\uebef'),
        cmd_transfer('\uebf5'),
        cmd_transfer_down('\uebf1'),
        cmd_transfer_left('\uebf2'),
        cmd_transfer_right('\uebf3'),
        cmd_transfer_up('\uebf4'),
        cmd_transit_connection('\uebf7'),
        cmd_transit_connection_variant('\uebf6'),
        cmd_transit_detour('\uebf8'),
        cmd_transit_transfer('\uebf9'),
        cmd_transition('\uebfb'),
        cmd_transition_masked('\uebfa'),
        cmd_translate('\uebfd'),
        cmd_translate_off('\uebfc'),
        cmd_transmission_tower('\uebfe'),
        cmd_trash_can('\uec00'),
        cmd_trash_can_outline('\uebff'),
        cmd_tray('\uec06'),
        cmd_tray_alert('\uec01'),
        cmd_tray_full('\uec02'),
        cmd_tray_minus('\uec03'),
        cmd_tray_plus('\uec04'),
        cmd_tray_remove('\uec05'),
        cmd_treasure_chest('\uec07'),
        cmd_tree('\uec09'),
        cmd_tree_outline('\uec08'),
        cmd_trello('\uec0a'),
        cmd_trending_down('\uec0b'),
        cmd_trending_neutral('\uec0c'),
        cmd_trending_up('\uec0d'),
        cmd_triangle('\uec0f'),
        cmd_triangle_outline('\uec0e'),
        cmd_triforce('\uec10'),
        cmd_trophy('\uec16'),
        cmd_trophy_award('\uec11'),
        cmd_trophy_broken('\uec12'),
        cmd_trophy_outline('\uec13'),
        cmd_trophy_variant('\uec15'),
        cmd_trophy_variant_outline('\uec14'),
        cmd_truck('\uec1f'),
        cmd_truck_check('\uec18'),
        cmd_truck_check_outline('\uec17'),
        cmd_truck_delivery('\uec1a'),
        cmd_truck_delivery_outline('\uec19'),
        cmd_truck_fast('\uec1c'),
        cmd_truck_fast_outline('\uec1b'),
        cmd_truck_outline('\uec1d'),
        cmd_truck_trailer('\uec1e'),
        cmd_trumpet('\uec20'),
        cmd_tshirt_crew('\uec22'),
        cmd_tshirt_crew_outline('\uec21'),
        cmd_tshirt_v('\uec24'),
        cmd_tshirt_v_outline('\uec23'),
        cmd_tumble_dryer('\uec27'),
        cmd_tumble_dryer_alert('\uec25'),
        cmd_tumble_dryer_off('\uec26'),
        cmd_tumblr('\uec2a'),
        cmd_tumblr_box('\uec28'),
        cmd_tumblr_reblog('\uec29'),
        cmd_tune('\uec2c'),
        cmd_tune_vertical('\uec2b'),
        cmd_turnstile('\uec2e'),
        cmd_turnstile_outline('\uec2d'),
        cmd_turtle('\uec2f'),
        cmd_twitch('\uec30'),
        cmd_twitter('\uec34'),
        cmd_twitter_box('\uec31'),
        cmd_twitter_circle('\uec32'),
        cmd_twitter_retweet('\uec33'),
        cmd_two_factor_authentication('\uec35'),
        cmd_typewriter('\uec36'),
        cmd_uber('\uec37'),
        cmd_ubisoft('\uec38'),
        cmd_ubuntu('\uec39'),
        cmd_ufo('\uec3b'),
        cmd_ufo_outline('\uec3a'),
        cmd_ultra_high_definition('\uec3c'),
        cmd_umbraco('\uec3d'),
        cmd_umbrella('\uec40'),
        cmd_umbrella_closed('\uec3e'),
        cmd_umbrella_outline('\uec3f'),
        cmd_undo('\uec42'),
        cmd_undo_variant('\uec41'),
        cmd_unfold_less_horizontal('\uec43'),
        cmd_unfold_less_vertical('\uec44'),
        cmd_unfold_more_horizontal('\uec45'),
        cmd_unfold_more_vertical('\uec46'),
        cmd_ungroup('\uec47'),
        cmd_unicode('\uec48'),
        cmd_unity('\uec49'),
        cmd_unreal('\uec4a'),
        cmd_untappd('\uec4b'),
        cmd_update('\uec4c'),
        cmd_upload('\uec53'),
        cmd_upload_multiple('\uec4d'),
        cmd_upload_network('\uec4f'),
        cmd_upload_network_outline('\uec4e'),
        cmd_upload_off('\uec51'),
        cmd_upload_off_outline('\uec50'),
        cmd_upload_outline('\uec52'),
        cmd_usb('\uec57'),
        cmd_usb_flash_drive('\uec55'),
        cmd_usb_flash_drive_outline('\uec54'),
        cmd_usb_port('\uec56'),
        cmd_valve('\uec5a'),
        cmd_valve_closed('\uec58'),
        cmd_valve_open('\uec59'),
        cmd_van_passenger('\uec5b'),
        cmd_van_utility('\uec5c'),
        cmd_vanish('\uec5d'),
        cmd_vanity_light('\uec5e'),
        cmd_variable('\uec60'),
        cmd_variable_box('\uec5f'),
        cmd_vector_arrange_above('\uec61'),
        cmd_vector_arrange_below('\uec62'),
        cmd_vector_bezier('\uec63'),
        cmd_vector_circle('\uec65'),
        cmd_vector_circle_variant('\uec64'),
        cmd_vector_combine('\uec66'),
        cmd_vector_curve('\uec67'),
        cmd_vector_difference('\uec6a'),
        cmd_vector_difference_ab('\uec68'),
        cmd_vector_difference_ba('\uec69'),
        cmd_vector_ellipse('\uec6b'),
        cmd_vector_intersection('\uec6c'),
        cmd_vector_line('\uec6d'),
        cmd_vector_link('\uec6e'),
        cmd_vector_point('\uec6f'),
        cmd_vector_polygon('\uec70'),
        cmd_vector_polyline('\uec75'),
        cmd_vector_polyline_edit('\uec71'),
        cmd_vector_polyline_minus('\uec72'),
        cmd_vector_polyline_plus('\uec73'),
        cmd_vector_polyline_remove('\uec74'),
        cmd_vector_radius('\uec76'),
        cmd_vector_rectangle('\uec77'),
        cmd_vector_selection('\uec78'),
        cmd_vector_square('\uec79'),
        cmd_vector_triangle('\uec7a'),
        cmd_vector_union('\uec7b'),
        cmd_venmo('\uec7c'),
        cmd_vhs('\uec7d'),
        cmd_vibrate('\uec7f'),
        cmd_vibrate_off('\uec7e'),
        cmd_video('\uec96'),
        cmd_video_3d('\uec81'),
        cmd_video_3d_variant('\uec80'),
        cmd_video_4k_box('\uec82'),
        cmd_video_account('\uec83'),
        cmd_video_check('\uec85'),
        cmd_video_check_outline('\uec84'),
        cmd_video_image('\uec86'),
        cmd_video_input_antenna('\uec87'),
        cmd_video_input_component('\uec88'),
        cmd_video_input_hdmi('\uec89'),
        cmd_video_input_scart('\uec8a'),
        cmd_video_input_svideo('\uec8b'),
        cmd_video_minus('\uec8c'),
        cmd_video_off('\uec8e'),
        cmd_video_off_outline('\uec8d'),
        cmd_video_outline('\uec8f'),
        cmd_video_plus('\uec90'),
        cmd_video_stabilization('\uec91'),
        cmd_video_switch('\uec92'),
        cmd_video_vintage('\uec93'),
        cmd_video_wireless('\uec95'),
        cmd_video_wireless_outline('\uec94'),
        cmd_view_agenda('\uec98'),
        cmd_view_agenda_outline('\uec97'),
        cmd_view_array('\uec99'),
        cmd_view_carousel('\uec9a'),
        cmd_view_column('\uec9b'),
        cmd_view_comfy('\uec9c'),
        cmd_view_compact('\uec9e'),
        cmd_view_compact_outline('\uec9d'),
        cmd_view_dashboard('\ueca1'),
        cmd_view_dashboard_outline('\uec9f'),
        cmd_view_dashboard_variant('\ueca0'),
        cmd_view_day('\ueca2'),
        cmd_view_grid('\ueca6'),
        cmd_view_grid_outline('\ueca3'),
        cmd_view_grid_plus('\ueca5'),
        cmd_view_grid_plus_outline('\ueca4'),
        cmd_view_headline('\ueca7'),
        cmd_view_list('\ueca8'),
        cmd_view_module('\ueca9'),
        cmd_view_parallel('\uecaa'),
        cmd_view_quilt('\uecab'),
        cmd_view_sequential('\uecac'),
        cmd_view_split_horizontal('\uecad'),
        cmd_view_split_vertical('\uecae'),
        cmd_view_stream('\uecaf'),
        cmd_view_week('\uecb0'),
        cmd_vimeo('\uecb1'),
        cmd_violin('\uecb2'),
        cmd_virtual_reality('\uecb3'),
        cmd_visual_studio('\uecb5'),
        cmd_visual_studio_code('\uecb4'),
        cmd_vk('\uecb8'),
        cmd_vk_box('\uecb6'),
        cmd_vk_circle('\uecb7'),
        cmd_vlc('\uecb9'),
        cmd_voice('\uecbb'),
        cmd_voice_off('\uecba'),
        cmd_voicemail('\uecbc'),
        cmd_volleyball('\uecbd'),
        cmd_volume_high('\uecbe'),
        cmd_volume_low('\uecbf'),
        cmd_volume_medium('\uecc0'),
        cmd_volume_minus('\uecc1'),
        cmd_volume_mute('\uecc2'),
        cmd_volume_off('\uecc3'),
        cmd_volume_plus('\uecc4'),
        cmd_volume_source('\uecc5'),
        cmd_volume_variant_off('\uecc6'),
        cmd_volume_vibrate('\uecc7'),
        cmd_vote('\uecc9'),
        cmd_vote_outline('\uecc8'),
        cmd_vpn('\uecca'),
        cmd_vuejs('\ueccb'),
        cmd_vuetify('\ueccc'),
        cmd_walk('\ueccd'),
        cmd_wall('\uecd1'),
        cmd_wall_sconce('\uecd0'),
        cmd_wall_sconce_flat('\uecce'),
        cmd_wall_sconce_variant('\ueccf'),
        cmd_wallet('\uecd8'),
        cmd_wallet_giftcard('\uecd2'),
        cmd_wallet_membership('\uecd3'),
        cmd_wallet_outline('\uecd4'),
        cmd_wallet_plus('\uecd6'),
        cmd_wallet_plus_outline('\uecd5'),
        cmd_wallet_travel('\uecd7'),
        cmd_wallpaper('\uecd9'),
        cmd_wan('\uecda'),
        cmd_wardrobe('\uecdc'),
        cmd_wardrobe_outline('\uecdb'),
        cmd_warehouse('\uecdd'),
        cmd_washing_machine('\uece0'),
        cmd_washing_machine_alert('\uecde'),
        cmd_washing_machine_off('\uecdf'),
        cmd_watch('\uece8'),
        cmd_watch_export('\uece2'),
        cmd_watch_export_variant('\uece1'),
        cmd_watch_import('\uece4'),
        cmd_watch_import_variant('\uece3'),
        cmd_watch_variant('\uece5'),
        cmd_watch_vibrate('\uece7'),
        cmd_watch_vibrate_off('\uece6'),
        cmd_water('\uecf4'),
        cmd_water_boiler('\ueceb'),
        cmd_water_boiler_alert('\uece9'),
        cmd_water_boiler_off('\uecea'),
        cmd_water_off('\uecec'),
        cmd_water_outline('\ueced'),
        cmd_water_percent('\uecee'),
        cmd_water_polo('\uecef'),
        cmd_water_pump('\uecf1'),
        cmd_water_pump_off('\uecf0'),
        cmd_water_well('\uecf3'),
        cmd_water_well_outline('\uecf2'),
        cmd_watermark('\uecf5'),
        cmd_wave('\uecf6'),
        cmd_waves('\uecf7'),
        cmd_waze('\uecf8'),
        cmd_weather_cloudy('\uecfb'),
        cmd_weather_cloudy_alert('\uecf9'),
        cmd_weather_cloudy_arrow_right('\uecfa'),
        cmd_weather_fog('\uecfc'),
        cmd_weather_hail('\uecfd'),
        cmd_weather_hazy('\uecfe'),
        cmd_weather_hurricane('\uecff'),
        cmd_weather_lightning('\ued01'),
        cmd_weather_lightning_rainy('\ued00'),
        cmd_weather_night('\ued03'),
        cmd_weather_night_partly_cloudy('\ued02'),
        cmd_weather_partly_cloudy('\ued04'),
        cmd_weather_partly_lightning('\ued05'),
        cmd_weather_partly_rainy('\ued06'),
        cmd_weather_partly_snowy('\ued08'),
        cmd_weather_partly_snowy_rainy('\ued07'),
        cmd_weather_pouring('\ued09'),
        cmd_weather_rainy('\ued0a'),
        cmd_weather_snowy('\ued0d'),
        cmd_weather_snowy_heavy('\ued0b'),
        cmd_weather_snowy_rainy('\ued0c'),
        cmd_weather_sunny('\ued0f'),
        cmd_weather_sunny_alert('\ued0e'),
        cmd_weather_sunset('\ued12'),
        cmd_weather_sunset_down('\ued10'),
        cmd_weather_sunset_up('\ued11'),
        cmd_weather_tornado('\ued13'),
        cmd_weather_windy('\ued15'),
        cmd_weather_windy_variant('\ued14'),
        cmd_web('\ued18'),
        cmd_web_box('\ued16'),
        cmd_web_clock('\ued17'),
        cmd_webcam('\ued19'),
        cmd_webhook('\ued1a'),
        cmd_webpack('\ued1b'),
        cmd_webrtc('\ued1c'),
        cmd_wechat('\ued1d'),
        cmd_weight('\ued22'),
        cmd_weight_gram('\ued1e'),
        cmd_weight_kilogram('\ued1f'),
        cmd_weight_lifter('\ued20'),
        cmd_weight_pound('\ued21'),
        cmd_whatsapp('\ued23'),
        cmd_wheelchair_accessibility('\ued24'),
        cmd_whistle('\ued26'),
        cmd_whistle_outline('\ued25'),
        cmd_white_balance_auto('\ued27'),
        cmd_white_balance_incandescent('\ued28'),
        cmd_white_balance_iridescent('\ued29'),
        cmd_white_balance_sunny('\ued2a'),
        cmd_widgets('\ued2b'),
        cmd_wifi('\ued3f'),
        cmd_wifi_off('\ued2c'),
        cmd_wifi_star('\ued2d'),
        cmd_wifi_strength_1('\ued30'),
        cmd_wifi_strength_1_alert('\ued2e'),
        cmd_wifi_strength_1_lock('\ued2f'),
        cmd_wifi_strength_2('\ued33'),
        cmd_wifi_strength_2_alert('\ued31'),
        cmd_wifi_strength_2_lock('\ued32'),
        cmd_wifi_strength_3('\ued36'),
        cmd_wifi_strength_3_alert('\ued34'),
        cmd_wifi_strength_3_lock('\ued35'),
        cmd_wifi_strength_4('\ued39'),
        cmd_wifi_strength_4_alert('\ued37'),
        cmd_wifi_strength_4_lock('\ued38'),
        cmd_wifi_strength_alert_outline('\ued3a'),
        cmd_wifi_strength_lock_outline('\ued3b'),
        cmd_wifi_strength_off('\ued3d'),
        cmd_wifi_strength_off_outline('\ued3c'),
        cmd_wifi_strength_outline('\ued3e'),
        cmd_wii('\ued40'),
        cmd_wiiu('\ued41'),
        cmd_wikipedia('\ued42'),
        cmd_wind_turbine('\ued43'),
        cmd_window_close('\ued44'),
        cmd_window_closed('\ued46'),
        cmd_window_closed_variant('\ued45'),
        cmd_window_maximize('\ued47'),
        cmd_window_minimize('\ued48'),
        cmd_window_open('\ued4a'),
        cmd_window_open_variant('\ued49'),
        cmd_window_restore('\ued4b'),
        cmd_window_shutter('\ued4e'),
        cmd_window_shutter_alert('\ued4c'),
        cmd_window_shutter_open('\ued4d'),
        cmd_windows('\ued50'),
        cmd_windows_classic('\ued4f'),
        cmd_wiper('\ued52'),
        cmd_wiper_wash('\ued51'),
        cmd_wordpress('\ued53'),
        cmd_worker('\ued54'),
        cmd_wrap('\ued56'),
        cmd_wrap_disabled('\ued55'),
        cmd_wrench('\ued58'),
        cmd_wrench_outline('\ued57'),
        cmd_wunderlist('\ued59'),
        cmd_xamarin('\ued5b'),
        cmd_xamarin_outline('\ued5a'),
        cmd_xaml('\ued5c'),
        cmd_xbox('\ued68'),
        cmd_xbox_controller('\ued67'),
        cmd_xbox_controller_battery_alert('\ued5d'),
        cmd_xbox_controller_battery_charging('\ued5e'),
        cmd_xbox_controller_battery_empty('\ued5f'),
        cmd_xbox_controller_battery_full('\ued60'),
        cmd_xbox_controller_battery_low('\ued61'),
        cmd_xbox_controller_battery_medium('\ued62'),
        cmd_xbox_controller_battery_unknown('\ued63'),
        cmd_xbox_controller_menu('\ued64'),
        cmd_xbox_controller_off('\ued65'),
        cmd_xbox_controller_view('\ued66'),
        cmd_xda('\ued69'),
        cmd_xing('\ued6c'),
        cmd_xing_box('\ued6a'),
        cmd_xing_circle('\ued6b'),
        cmd_xml('\ued6d'),
        cmd_xmpp('\ued6e'),
        cmd_yahoo('\ued6f'),
        cmd_yammer('\ued70'),
        cmd_yeast('\ued71'),
        cmd_yelp('\ued72'),
        cmd_yin_yang('\ued73'),
        cmd_yoga('\ued74'),
        cmd_youtube('\ued79'),
        cmd_youtube_creator_studio('\ued75'),
        cmd_youtube_gaming('\ued76'),
        cmd_youtube_subscription('\ued77'),
        cmd_youtube_tv('\ued78'),
        cmd_z_wave('\ued7a'),
        cmd_zend('\ued7b'),
        cmd_zigbee('\ued7c'),
        cmd_zip_box('\ued7e'),
        cmd_zip_box_outline('\ued7d'),
        cmd_zip_disk('\ued7f'),
        cmd_zodiac_aquarius('\ued80'),
        cmd_zodiac_aries('\ued81'),
        cmd_zodiac_cancer('\ued82'),
        cmd_zodiac_capricorn('\ued83'),
        cmd_zodiac_gemini('\ued84'),
        cmd_zodiac_leo('\ued85'),
        cmd_zodiac_libra('\ued86'),
        cmd_zodiac_pisces('\ued87'),
        cmd_zodiac_sagittarius('\ued88'),
        cmd_zodiac_scorpio('\ued89'),
        cmd_zodiac_taurus('\ued8a'),
        cmd_zodiac_virgo('\ued8b');

        override val typeface: ITypeface by lazy { CommunityMaterial }
    }
}
